<?php
class SharedFilesFileHandling {
  
  public static function add_file__premium_only($file, $cat_slug, $media_library_post_id = 0, $subdir = '', $add_featured_image = 0) {

    $media_library_post_id = intval( $media_library_post_id );

    if (isset($file)) {
      
      if ($media_library_post_id) {

        $file = get_attached_file($media_library_post_id);

      } else {
        
        if ($subdir) {
          $subdir .= '/';
        }
        
        $file = self::getBaseDir() . $subdir . $file;
      }
      
      $new_post = array( 'post_type'    => 'shared_file',
                         'post_status'  => 'publish',
                         'post_title'   => '',
                         'post_content' => '');
      
      $id = wp_insert_post($new_post);

//            update_post_meta($id, '_sf_not_public', 1);

      if (isset($cat_slug)) {
        
        $cat_slug = sanitize_title( $cat_slug );
        $cat = get_term_by('slug', $cat_slug, 'shared-file-category');

        if ($cat) {
          wp_set_object_terms($id, intval( $cat->term_id ), 'shared-file-category');
        }

      }

      if (is_user_logged_in()) {
        $user = wp_get_current_user();
        update_post_meta($id, '_sf_user_id', intval( $user->ID ));
      }

      update_post_meta($id, '_sf_description', '');

      $filename = substr(strrchr($file, "/"), 1);

      $file_url = '';
                
      if ($media_library_post_id) {

        $file_url = wp_get_attachment_url($media_library_post_id);            

      } else {

        $file_url = self::getFileUrlByName($filename, $subdir);

      }

      $file_type = '';

      $file_type_array = wp_check_filetype($file);

      if ( isset( $file_type_array['type'] ) ) {
        $file_type = $file_type_array['type'];
      }
      
      $file_info = ['file' => $file, 'url' => $file_url, 'type' => $file_type];  

      add_post_meta($id, '_sf_file', $file_info);
      update_post_meta($id, '_sf_file', $file_info);

      update_post_meta($id, '_sf_filename', $filename);
      update_post_meta($id, '_sf_filesize', filesize($file));
      update_post_meta($id, '_sf_load_cnt', 0);
      update_post_meta($id, '_sf_bandwidth_usage', 0);
      update_post_meta($id, '_sf_file_added', current_time('Y-m-d H:i:s'));
      update_post_meta($id, '_sf_main_date', '');

      if ($subdir) {
        update_post_meta($id, '_sf_subdir', rtrim( $subdir, '/' ));
      } else {
//            update_post_meta($id, '_sf_subdir', '');
      }

      if ($media_library_post_id) {
        update_post_meta($id, '_sf_media_library_post_id', $media_library_post_id);
      }

      $my_post = array(
        'ID'           => $id,
        'post_title'   => $filename,
      );

      wp_update_post($my_post);
      
      $file_array['file'] = $file;

      $file_type_array = wp_check_filetype($file);
      $uploaded_type = $file_type_array['type'];

      SharedFilesHelpers::addFeaturedImage($id, $file_array, $uploaded_type, $filename, 1);
    
    }
    
    return 1;
  }

  public static function activate_file__premium_only() {

    if (current_user_can('administrator') && isset($_POST['shared-files-op']) && $_POST['shared-files-op'] == 'sync-files' && isset($_POST['add_file'])) {

      $sf_nonce = '';

      if ( isset( $_POST['sf-sync-files-nonce'] ) ) {
        $sf_nonce = sanitize_text_field( $_POST['sf-sync-files-nonce'] );
      }

      if (!isset($sf_nonce) || !wp_verify_nonce($sf_nonce, 'sf-sync-files')) {
        wp_die('Error in processing form data.');
      }

      $cat_slug = '';
      
      if (isset($_POST['shared-file-category'])) {
        $cat_slug = sanitize_title( $_POST['shared-file-category'] );
      }

      if ($_POST['add_file'] == 'all_files') {

        $path = self::getBaseDir();
        $files = array_diff(scandir($path), array('.', '..'));

        $count = 0;

        foreach ($files as $file) {
  
          $item = self::getBaseDir() . $file;
          
          if ($file == 'index.php') {

            continue;

          // Item a directory under wp-content/uploads/shared-files/
          } elseif (is_dir($item)) {
            
            $files_in_subdir = array_diff(scandir($item), array('.', '..'));

            // All files under wp-content/uploads/shared-files/SUBDIR/
            foreach ($files_in_subdir as $file_in_subdir) {

              $sub_item = $item . '/' . $file_in_subdir;

              $item_array = explode('/', $sub_item);
              $item_array_sliced = array_slice($item_array, -2, 2);
              $subdir = '';
              
              if (is_array($item_array_sliced) && $item_array_sliced[0] == 'shared-files') {
                \array_splice($item_array_sliced, 0, 1);
              } elseif (is_array($item_array_sliced)) {
                $subdir = $item_array_sliced[0];
              }

              if ($subdir) {

                $meta_query = array('relation' => 'AND');
                
                $meta_query[] = array(
                  'key'		  => '_sf_filename',
                  'compare'	=> '=',
                  'value'   => $file_in_subdir
                );
  
                $meta_query[] = array(
                  'key'		  => '_sf_subdir',
                  'compare'	=> '=',
                  'value'   => $subdir
                );
                
                $wp_query = new WP_Query(array(
                  'post_type' => 'shared_file',
                  'post_status' => 'publish',
                  'posts_per_page' => 1,
                  'meta_query' => $meta_query,
                ));
                
                $file_active = 0;
                
                if ($wp_query->have_posts()) {
                  while ($wp_query->have_posts()) {
                    $wp_query->the_post();
                    $file_active = 1;
                  };
                  wp_reset_postdata();
                };
                
                if (!$file_active) {
  
                  if (SharedFilesFileHandling::add_file__premium_only($file_in_subdir, $cat_slug, 0, $subdir, 0)) {
                    $count++;
                  }
                  
                }
              
              }
              
            }
            
          
          // Item is a file directly under wp-content/uploads/shared-files/
          } else {

            $subdir = '';
  
            $meta_query = array('relation' => 'AND');
        
            $meta_query[] = array(
        			'key'		  => '_sf_filename',
        			'compare'	=> '=',
        			'value'   => $file
        		);
  
            $meta_query[] = array(
              'key'		  => '_sf_subdir',
              'compare'	=> 'NOT EXISTS',
              'value'   => ''
            );
    
            $wp_query = new WP_Query(array(
              'post_type' => 'shared_file',
              'post_status' => 'publish',
              'posts_per_page' => 1,
              'meta_query' => $meta_query,
            ));
            
            $file_active = 0;
    
            if ($wp_query->have_posts()) {
              while ($wp_query->have_posts()) {
                $wp_query->the_post();
                $file_active = 1;
              };
              wp_reset_postdata();
            };
  
            if (!$file_active) {
  
              if (SharedFilesFileHandling::add_file__premium_only($file, $cat_slug)) {
                $count++;
              }
  
            }
                      
          }
          
        }
        
        SharedFilesHelpers::writeLog('Activated all inactive files: ' . $count . ' files', '');

        wp_redirect(admin_url('edit.php?post_type=shared_file&page=shared-files-sync-files&files=' . $count));
        exit;

      // Activate a single file, "Activate" button on file row @ Sync files & Media Library page
      } else {

        $filename = sanitize_text_field($_POST['add_file']);
        
        $page = 'shared-files-sync-files';
        $media_library_post_id = 0;
        $subdir = '';
  
        if (isset($_POST['_sf_media_library_post_id'])) {
          $page = 'shared-files-sync-media-library';
          $media_library_post_id = intval( $_POST['_sf_media_library_post_id'] );
        }

        if (isset($_POST['_SF_SUBDIR'])) {
          $subdir = sanitize_file_name( $_POST['_SF_SUBDIR'] );
        }
  
        if (SharedFilesFileHandling::add_file__premium_only($filename, $cat_slug, $media_library_post_id, $subdir)) {
          wp_redirect( esc_url_raw( admin_url('edit.php?post_type=shared_file&page=' . $page . '&files=1') ) );
          exit;
        } else {
          echo '<p>' . sanitize_text_field( __('Error processing file(s).', 'shared-files') ) . '</p>';
          wp_redirect( esc_url_raw( admin_url('edit.php?post_type=shared_file&page=' . $page . '&files=error') ) );
          exit;
        }
        
      }
        
    }

  }
    
  public static function getBaseDir() {

    $base_dir = wp_get_upload_dir()['basedir'] . '/shared-files/';

    return $base_dir;

  }

  public static function getFileUrlByName($filename, $subdir = '') {

    $wp_upload_dir = parse_url( wp_upload_dir()['baseurl'] );

    $file_url = $wp_upload_dir['path'] . '/shared-files/' . $subdir . $filename;

    return $file_url;

  }

  public static function human_filesize($bytes, $decimals = 2) {

    $size = array('bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB');

    $factor = floor((strlen($bytes) - 1) / 3);

    return $bytes ? sprintf("%.{$decimals}f", $bytes / pow(1024, $factor)) . ' ' . @$size[$factor] : 0;

  }

}
