<?php

class SharedFilesAdminList {

  /**
   * Custom columns for shared file.
   *
   * @since    1.0.0
   */
  public function shared_file_custom_columns($defaults) {

    $s = get_option('shared_files_settings');

    if (SharedFilesHelpers::isPremium() == 0) {
      $defaults['_category']          = sanitize_text_field( __('Category', 'shared-files') );
    }

    $defaults['file_url']           = sanitize_text_field( __('Shortcode', 'shared-files') );
    $defaults['filesize']           = sanitize_text_field( __('File size', 'shared-files') );
    $defaults['load_cnt']           = sanitize_text_field( __('Downloads', 'shared-files') );

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $defaults['restriction']             = sanitize_text_field( __('Restriction', 'shared-files') );

      }
    }

    if (!isset($s['hide_limit_downloads'])) {
      $defaults['limit_downloads']    = sanitize_text_field( __('Limit', 'shared-files') );
    }

    if (!isset($s['hide_file_added'])) {
      $defaults['file_added']         = sanitize_text_field( __('File added', 'shared-files') );
    }

    if (!isset($s['hide_last_access'])) {
      $defaults['last_access']        = sanitize_text_field( __('Last access', 'shared-files') );
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (!isset($s['hide_bandwidth_usage'])) {
          $defaults['bandwidth_usage']    = sanitize_text_field( __('Bandwidth usage (estimate)', 'shared-files') );
        }

        if (!isset($s['hide_expiration_date'])) {
          $defaults['expiration_date']    = sanitize_text_field( __('Expires', 'shared-files') );
        }

      }
    }

    return $defaults;
  }

  public function set_custom_shared_files_sortable_columns($columns) {

    $columns['taxonomy-shared-file-category'] = 'shared-file-category';
    $columns['expiration_date'] = '_sf_expiration_date';
    $columns['file_added'] = '_sf_file_added';
    $columns['last_access'] = '_sf_last_access';
    $columns['load_cnt'] = '_sf_load_cnt';
    $columns['limit_downloads'] = '_sf_limit_downloads';
    $columns['filesize'] = '_sf_filesize';

    return $columns;

  }

  public function sort_posts_by_meta_value($query) {

    if (!is_admin() || !$query->is_main_query()) {
      return;
    }

    global $pagenow;

    if (is_admin() && $pagenow == 'edit.php' && isset($_GET['post_type']) && $_GET['post_type'] == 'shared_file' &&

      isset($_GET['orderby']) && $_GET['orderby'] != 'None') {

      if ($_GET['orderby'] == '_sf_expiration_date') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );

      } elseif ($_GET['orderby'] == '_sf_file_added') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );
        $query->query_vars['meta_type'] = 'DATETIME';

      } elseif ($_GET['orderby'] == '_sf_last_access') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );
        $query->query_vars['meta_type'] = 'DATETIME';

      } elseif ($_GET['orderby'] == '_sf_load_cnt') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );
        $query->query_vars['meta_type'] = 'numeric';

      } elseif ($_GET['orderby'] == '_sf_limit_downloads') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );
        $query->query_vars['meta_type'] = 'numeric';

      } elseif ($_GET['orderby'] == '_sf_filesize') {

        $query->query_vars['orderby'] = 'meta_value';
        $query->query_vars['meta_key'] = sanitize_title( $_GET['orderby'] );
        $query->query_vars['meta_type'] = 'numeric';

      }

    }

  }

  /**
   * Custom column content for shared file.
   *
   * @since    1.0.0
   */
  public function shared_file_custom_columns_content($column_name, $post_ID) {

    $post_ID = intval( $post_ID );

    $file_id = intval( get_the_ID() );

    switch ($column_name) {

      case '_category':
        echo '<a href="' . esc_url_raw( get_admin_url() ) . 'options-general.php?page=shared-files-pricing"><div class="shared-files-pro-only">' . esc_html__('All Plans') . '</div></a>';
        break;

      case 'file_url':

        echo '<span class="shared-files-shortcode-admin-list shared-files-shortcode-admin-list-file shared-files-shortcode-' . esc_attr( $post_ID ) . '" title="[shared_files file_id=' . esc_attr( $post_ID ) . ']">[shared_files file_id=' . esc_attr( $post_ID ) . ']</span>';

        echo '<button class="shared-files-copy shared-files-copy-single shared-files-copy-admin-list" data-clipboard-action="copy" data-clipboard-target=".shared-files-shortcode-' . esc_attr( $post_ID ) . '">' . esc_html__('Copy', 'shared-files') . '</button>';

        $folder_name = get_post_meta($file_id, '_sf_subdir', true);

        if ($folder_name) {
          echo '<hr class="clear" /><div class="shared-files-admin-folder-name">' . esc_html( $folder_name ) . '/</div>';
        }

//        $file_url = SharedFilesAdminHelpers::sf_root() . '/shared-files/' . $post_ID . '/' . SharedFilesHelpers::wp_engine() . sanitize_text_field( get_post_meta($post_ID, '_sf_filename', true) );

        $file_url = SharedFilesPublicHelpers::getFileURL( $file_id );

        echo '<hr class="clear" /><a href="' . esc_url( $file_url ) . '" class="shared-files-admin-file-url" target="_blank">' . esc_url( $file_url ) . '</a>';

        break;

      case 'filesize':

        if (get_post_meta($post_ID, '_sf_external_url', true)) {

          echo 'n/a';

        } else {

          echo esc_html( SharedFilesAdminHelpers::human_filesize( sanitize_text_field( get_post_meta($post_ID, '_sf_filesize', true) ) ) );

        }

        break;

      case 'restriction':

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $restriction_active = 0;

            if (get_post_meta($post_ID, '_sf_password', true)) {

              $restriction_active = 1;

              echo '<div><span class="shared-files-restr-file-password">' . esc_html__('File password', 'shared-files') . '</span></div>';

            }

            $cat_password = SharedFilesHelpers::getCatPassword__premium_only($post_ID);

            if ( $cat_password ) {

              $restriction_active = 1;

              echo '<div><span class="shared-files-restr-cat-password">' . esc_html__('Cat password', 'shared-files') . '</span></div>';
            }

            $sf_permission_user_id = get_post_meta($post_ID, '_sf_permission_user_id', true);

            if ( $sf_permission_user_id ) {

              $restriction_active = 1;

              echo '<div><span class="shared-files-restr-users">' . esc_html__('User', 'shared-files') . '</span></div>';

            }

            global $wp_roles;

            $roles = $wp_roles->get_names();

            $restricted_by_roles = 0;

            foreach ($roles as $key => $value) {

              if ($key && $value) {

                $field_name = '_sf_permission_user_role_' . sanitize_title( $key );

                $checked = intval( get_post_meta($post_ID, $field_name, true) );

                if ($checked) {
                  $restricted_by_roles = 1;
                }

              }

            }

            if ( $restricted_by_roles ) {

              $restriction_active = 1;

              echo '<div><span class="shared-files-restr-roles">' . esc_html__('Role', 'shared-files') . '</span></div>';
            }

            if ( !$restriction_active ) {
              echo '<div><span class="shared-files-restr-none">' . esc_html__('None', 'shared-files') . '</span></div>';
            }

          }
        }

        break;

      case 'load_cnt':

        echo esc_html( get_post_meta($post_ID, '_sf_load_cnt', true) );

        break;

      case 'limit_downloads':

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            echo esc_html( get_post_meta($post_ID, '_sf_limit_downloads', true) );

          }
        }

        if (SharedFilesHelpers::isPremium() == 0) {
          echo '<a href="' . esc_url_raw( get_admin_url() ) . 'options-general.php?page=shared-files-pricing"><div class="shared-files-pro-only">' . esc_html__('All Plans') . '</div></a>';
        }

        break;

      case 'file_added':

        echo esc_html( get_post_meta($post_ID, '_sf_file_added', true) );

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $fe_uploader = get_post_meta($post_ID, '_sf_frontend_uploader', true);

            $media_library_post_id = intval( get_post_meta($post_ID, '_sf_media_library_post_id', true) );

            echo $fe_uploader ? '<div style="margin-top: 4px; background: #fff; border: 1px solid #eee; font-size: 9px; text-align: center; color: green;">' . esc_html__('Front-end uploader', 'shared-files') . '</div>' : '';

            echo $media_library_post_id ? '<a href="' . esc_url( admin_url() ) . 'upload.php?item=' . intval( $media_library_post_id ) . '" style="display: block;" target="_blank"><div style="margin-top: 4px; background: #fff; border: 1px solid #eee; font-size: 9px; text-align: center; color: green;">' . esc_html__('Media Library', 'shared-files') . '</div></a>' : '';

          }
        }

        break;

      case 'last_access':

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            echo esc_html( get_post_meta($post_ID, '_sf_last_access', true) );

          }
        }

        if (SharedFilesHelpers::isPremium() == 0) {
          echo '<a href="' . esc_url_raw( get_admin_url() ) . 'options-general.php?page=shared-files-pricing"><div class="shared-files-pro-only">' . esc_html__('All Plans') . '</div></a>';
        }

        break;

      case 'bandwidth_usage':

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            if (get_post_meta($post_ID, '_sf_external_url', true)) {
              echo 'n/a';
            } else {
              echo esc_html( SharedFilesAdminHelpers::human_filesize( sanitize_text_field( get_post_meta($post_ID, '_sf_bandwidth_usage', true) ) ) );
            }

          }
        }

        if (SharedFilesHelpers::isPremium() == 0) {
          echo '<a href="' . esc_url_raw( get_admin_url() ) . 'options-general.php?page=shared-files-pricing"><div class="shared-files-pro-only">' . esc_html__('All Plans') . '</div></a>';
        }

        break;

      case 'expiration_date':

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $expiration_date = get_post_meta($post_ID, '_sf_expiration_date', true);
            $expiration_date_formatted = '';
            $expiration_date_alert = 0;

            if ($expiration_date instanceof DateTime) {
              $expiration_date_formatted = $expiration_date->format('Y-m-d');
            }

            if ($expiration_date) {
              $dt_now = new DateTime('now');

              if ($expiration_date <= $dt_now) {
                $expiration_date_alert = 1;
              }

            }

            if ($expiration_date_alert) {
              echo '<span class="shared-files-expiration-date-alert">' . esc_html( $expiration_date_formatted ) . '</span>';
            } else {
              echo esc_html( $expiration_date_formatted );
            }

          }

        }

        if (SharedFilesHelpers::isPremium() == 0) {
          echo '<a href="' . esc_url_raw( get_admin_url() ) . 'options-general.php?page=shared-files-pricing"><div class="shared-files-pro-only">' . esc_html__('All Plans') . '</div></a>';
        }

        break;
    }

  }

  function filter_files_by_taxonomies($post_type, $which) {

  	// Apply this only on a specific post type
  	if ($post_type !== 'shared_file') {
  		return;
    }

    $taxonomy_slug = 'shared-file-category';
    $current_category_slug = isset($_GET['shared-file-category']) ? sanitize_title( $_GET['shared-file-category'] ) : '';

    if (get_taxonomy($taxonomy_slug)) {

      wp_dropdown_categories([
        'show_option_all' => get_taxonomy($taxonomy_slug)->labels->all_items,
        'hide_empty'      => 1,
        'hierarchical'    => 1,
        'show_count'      => 1,
        'orderby'         => 'name',
        'name'            => $taxonomy_slug,
        'value_field'     => 'slug',
        'taxonomy'        => $taxonomy_slug,
        'selected'        => $current_category_slug
      ]);

    }

  }

  public function sort_by_custom_taxonomy($clauses, $wp_query) {

  	global $wpdb;

  	if (isset( $wp_query->query['orderby'] ) && $wp_query->query['orderby'] == 'shared-file-category') {

  		$clauses['join'] .= "
        LEFT OUTER JOIN {$wpdb->term_relationships} ON {$wpdb->posts}.ID={$wpdb->term_relationships}.object_id
        LEFT OUTER JOIN {$wpdb->term_taxonomy} USING (term_taxonomy_id)
        LEFT OUTER JOIN {$wpdb->terms} USING (term_id)
        ";

  		$clauses['where'] .= " AND (taxonomy = 'shared-file-category' OR taxonomy IS NULL)";
  		$clauses['groupby'] = "object_id";
  		$clauses['orderby']  = "GROUP_CONCAT({$wpdb->terms}.name ORDER BY name ASC) ";
  		$clauses['orderby'] .= ('ASC' == strtoupper($wp_query->get('order'))) ? 'ASC' : 'DESC';
  	}

  	return $clauses;
  }

  function show_user_permission_filter__premium_only($post_type) {

    global $typenow;

    if ( $typenow == 'shared_file' ) { // Your custom post type slug

      global $wpdb;

      $query = $wpdb->prepare('
          SELECT DISTINCT pm.meta_value FROM %1$s pm
          LEFT JOIN %2$s p ON p.ID = pm.post_id
          WHERE pm.meta_key = "%3$s"
          AND p.post_type = "%4$s"
          ORDER BY "%5$s"',
          $wpdb->postmeta,
          $wpdb->posts,
          '_sf_permission_user_id', // Meta key
          sanitize_title( $post_type ),
          '_sf_permission_user_id'
      );

      $results = $wpdb->get_col($query);

      $users_for_filter = [];

      foreach($results as $result) {

        $permission_user_id = intval( $result );

        if ( !in_array($permission_user_id, $users_for_filter) ) {

          $user = get_user_by('id', $permission_user_id );

          if ( $user ) {

            $user_fullname = $user->user_login;

            if ($user->first_name && $user->last_name) {
              $user_fullname = $user->first_name . ' ' . $user->last_name;
            } elseif ($user->last_name) {
              $user_fullname = $user->last_name;
            } elseif ($user->first_name) {
              $user_fullname = $user->first_name;
            }

            $users_for_filter[$permission_user_id] = sanitize_text_field( $user_fullname );

          }

        }

      }

      $current_sel = '';

      if ( isset($_GET['_sf_permission_user_id']) && $_GET['_sf_permission_user_id'] ) {

        $current_sel = intval( $_GET['_sf_permission_user_id'] );

      }

      ?>

      <select name="_sf_permission_user_id" id="slug">

        <option value=""><?php echo esc_html__( 'All users', 'shared-files' ); ?></option>

        <?php foreach ( $users_for_filter as $key => $value ): ?>

          <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $current_sel ); ?>><?php echo esc_attr( $value ); ?></option>

        <?php endforeach; ?>

      </select>

    <?php
    }

  }

  function filter_files_by_user_permission__premium_only( $query ) {

    global $pagenow;

    // Get the post type
    $post_type = isset( $_GET['post_type'] ) ? sanitize_title( $_GET['post_type'] ) : '';

    if ( is_admin() && $pagenow == 'edit.php' && $post_type == 'shared_file' && isset( $_GET['_sf_permission_user_id'] ) && $_GET['_sf_permission_user_id'] ) {

      $query->query_vars['meta_key'] = '_sf_permission_user_id';
      $query->query_vars['meta_value'] = intval( $_GET['_sf_permission_user_id'] );
      $query->query_vars['meta_compare'] = '=';

    }

  }

}
