<?php

class SharedFilesAdminSendMail {

  public static function file_load_send_email__premium_only($post_id, $post) {

    $post_id = intval( $post_id );

    $post_title = sanitize_text_field( get_the_title($post_id) );
    $s = get_option('shared_files_settings');

    $recipient_email = '';

    $file_email = sanitize_email( get_post_meta($post_id, '_sf_notify_email', true) );
    $settings_email = '';

    if ( isset($s['recipient_email']) ) {
      $settings_email = sanitize_email( $s['recipient_email'] );
    }

    if ( $file_email ) {
      $recipient_email = $file_email;
    } elseif ( $settings_email ) {
      $recipient_email = $settings_email;
    }

    if (isset($s['send_email']) && is_email($recipient_email) && is_object($post) && $post->post_type == 'shared_file') {

      $headers = ['Content-Type: text/html; charset=UTF-8'];
      $subject = sanitize_text_field( __('File downloaded:', 'shared-files') ) . ' ' . $post_title;

      $body_html = '';
      $body_html .= '<html><head><title></title></head><body>';
      $body_html .= '<h3 style="color: #000;">' . sanitize_text_field( __('A file was downloaded:', 'shared-files') ) . ' ' . sanitize_text_field( $post_title ) . '</h3>';

      $ip_text = '';

      if (isset($s['add_ip_to_file_downloaded_email']) && isset($_SERVER['REMOTE_ADDR']) && $_SERVER['REMOTE_ADDR']) {
        $ip_text = ' (IP ' . $_SERVER['REMOTE_ADDR'] . ')';
      }

      if (is_user_logged_in()) {

        $user = wp_get_current_user();
        $user_fullname = $user->user_login;

        if ($user->first_name && $user->last_name) {
          $user_fullname = $user->first_name . ' ' . $user->last_name;
        } elseif ($user->last_name) {
          $user_fullname = $user->last_name;
        } elseif ($user->first_name) {
          $user_fullname = $user->first_name;
        }

        $body_html .= '<p>' . sanitize_text_field( __('Downloaded by:', 'shared-files') ) . ' ' . sanitize_text_field( $user_fullname . $ip_text ) . '</p>';
      } else {
        $body_html .= '<p>' . sanitize_text_field( __('Downloaded by:', 'shared-files') ) . ' ' . sanitize_text_field( __('a visitor', 'shared-files') ) . ' ' . sanitize_text_field( $ip_text ) . '</p>';
      }

      $is_premium = 0;

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          if (!isset($s['remove_email_footer'])) {
            $body_html .=  '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
                            <tr>
                              <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
                                ' . sanitize_text_field( __('Sent by Shared Files Pro', 'shared-files') ) . '
                              </td>
                            </tr>
                            </table>';
          }

          $is_premium = 1;

        }
      }

      if (!$is_premium) {

        $body_html .= '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
        <tr>
          <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
            ' . sanitize_text_field( __('Sent by Shared Files for WordPress', 'shared-files') ) . '
          </td>
        </tr>
        </table>';

      }

      $body_html .= '</body></html>';

      if ($recipient_email) {
        $resp = wp_mail($recipient_email, $subject, $body_html, $headers);
      }

    }

  }

  public static function file_upload_send_email__premium_only($post_id, $post, $container_url) {

    $post_id = intval( $post_id );

    $post_title = sanitize_text_field( get_the_title($post_id) );
    $s = get_option('shared_files_settings');
    $email_sent_to = [];

    // Preprocess mail content

    $headers = ['Content-Type: text/html; charset=UTF-8'];
    $subject = sanitize_text_field( __('File uploaded:', 'shared-files') ) . ' ' . sanitize_text_field( $post_title );

    $body_html = '';
    $body_html .= '<html><head><title></title></head><body>';
    $body_html .= '<h3 style="color: #000;">' . sanitize_text_field( __('File was uploaded:', 'shared-files') ) . ' ' . sanitize_text_field( $post_title ) . '</h3>';

    if ($container_url) {
      $body_html .= sanitize_text_field( __('On page:', 'shared-files') ) . '<br /><a href="' . esc_url_raw( $container_url ) . '">' . esc_url_raw( $container_url ) . '</a>';
    }

    if ($post_id) {
      $file_edit_url = get_edit_post_link( $post_id );
      $body_html .= '<br /><br /><a href="' . esc_url_raw( $file_edit_url ) . '">' . sanitize_text_field( __('Edit file &raquo;', 'shared-files') ) . '</a>';
    }

    $is_premium = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (!isset($s['remove_email_footer'])) {
          $body_html .=  '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%; margin-top: 20px;">
                          <tr>
                            <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
                              ' . sanitize_text_field( __('Sent by Shared Files Pro', 'shared-files') ) . '
                            </td>
                          </tr>
                          </table>';
        }

        $is_premium = 1;

      }
    }

    if (!$is_premium) {

      $body_html .= '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%; margin-top: 20px;">
      <tr>
        <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
          ' . sanitize_text_field( __('Sent by Shared Files for WordPress', 'shared-files') ) . '
        </td>
      </tr>
      </table>';

    }

    $body_html .= '</body></html>';


    // Send mail to a single recipient
    if ( isset($s['file_upload_send_email']) && is_email($s['file_upload_send_email']) && is_object($post) && $post->post_type == 'shared_file' ) {

      $resp = wp_mail($s['file_upload_send_email'], $subject, $body_html, $headers);

      $email_sent_to []= sanitize_email( $s['file_upload_send_email'] );

    // Multiple recipients
    } elseif ( isset($s['file_upload_send_email']) && $s['file_upload_send_email'] && is_object($post) && $post->post_type == 'shared_file' ) {

      $emails_arr = explode( ',', sanitize_email( $s['file_upload_send_email'] ) );

      foreach ( $emails_arr as $email ) {

        if ( is_email($email) ) {

          $resp = wp_mail($email, $subject, $body_html, $headers);

          $email_sent_to []= $email;

        }

      }

    }

    // Send mail to all users having a specific role by settings

    global $wp_roles;

    $roles = $wp_roles->get_names();

    foreach ($roles as $key => $value) {

      if ($key && $value) {

        $setting = 'notify_on_file_upload_' . $key;

        if (isset($s[$setting])) {

          $args = array(
            'role' => $key,
          );

          $users = get_users($args);

          foreach ( $users as $user ) {

            $email = $user->user_email;

            if (is_email($email) && !in_array($email, $email_sent_to)) {

              $resp = wp_mail($email, $subject, $body_html, $headers);
              $email_sent_to []= $email;

            }

          }

        }

      }

    }

  }

  public static function file_limit_send_email__premium_only($post_id, $post) {

    $post_id = intval( $post_id );

    $post_title = sanitize_text_field( get_the_title($post_id) );
    $s = get_option('shared_files_settings');

    $recipient_email = '';

    $file_email = sanitize_email( get_post_meta($post_id, '_sf_notify_email', true) );
    $settings_email = '';

    if ( isset($s['recipient_email']) ) {
      $settings_email = sanitize_email( $s['recipient_email'] );
    }

    if ( $file_email ) {
      $recipient_email = $file_email;
    } elseif ( $settings_email ) {
      $recipient_email = $settings_email;
    }

    if ($recipient_email && is_email($recipient_email) && $post->post_type == 'shared_file') {

      $headers = ['Content-Type: text/html; charset=UTF-8'];
      $subject = sanitize_text_field( __('Download limit reached for', 'shared-files') ) . ' ' . sanitize_text_field( $post_title );

      $body_html = '';
      $body_html .= '<html><head><title></title></head><body>';
      $body_html .= '<h3 style="color: #000;">' . sanitize_text_field( __('Download limit reached for', 'shared-files') ) . ' ' . $post_title . '</h3>';

      $body_url = esc_url_raw( admin_url('edit.php?post_type=shared_file') );
      $body_html .= '<p><a href="' . $body_url . '" target="_blank">' . sanitize_text_field( __('File manager &raquo;', 'shared-files') ) . '</a></p>';

      $is_premium = 0;

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          if (!isset($s['remove_email_footer'])) {
            $body_html .=  '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
                            <tr>
                              <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
                                ' . sanitize_text_field( __('Sent by Shared Files Pro', 'shared-files') ) . '
                              </td>
                            </tr>
                            </table>';
          }

          $is_premium = 1;

        }
      }

      if (!$is_premium) {

        $body_html .= '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
        <tr>
          <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
            ' . sanitize_text_field( __('Sent by Shared Files for WordPress', 'shared-files') ) . '
          </td>
        </tr>
        </table>';

      }

      $body_html .= '</body></html>';

      $resp = wp_mail($recipient_email, $subject, $body_html, $headers);

    }

  }

  public function file_expired_send_email__premium_only() {

    $s = get_option('shared_files_settings');

    $recipient_email = '';

    if ( isset($s['recipient_email']) ) {
      $recipient_email = sanitize_email( $s['recipient_email'] );
    }

    if (is_email($recipient_email)) {

      $wpb_all_query_all_files = new WP_Query(array(
        'post_type'       => 'shared_file',
        'post_status'     => 'publish',
        'posts_per_page'  => -1,

        'meta_query' => array(
          'relation' => 'AND',
            array(
              'key'     => '_sf_expiration_date',
              'compare' => 'EXISTS'
            ),
        )
      ));

      if (isset($wpb_all_query_all_files) && $wpb_all_query_all_files->have_posts()):
        while ($wpb_all_query_all_files->have_posts()): $wpb_all_query_all_files->the_post();

          $id = intval( get_the_id() );
          $c = get_post_custom($id);

          $filename = sanitize_text_field( $c['_sf_filename'][0] );
          $post_title = get_the_title($id) . ' / ' . $filename;

          $expiration_date = get_post_meta($id, '_sf_expiration_date', true);
          $expiration_date_formatted = '';
          $expiration_date_alert = 0;

          if ($expiration_date instanceof DateTime) {
            $dt_now = new DateTime('now');

            if ($expiration_date <= $dt_now) {

              $headers = ['Content-Type: text/html; charset=UTF-8'];
              $subject = sanitize_text_field( __('File expired:', 'shared-files') ) . ' ' . sanitize_text_field( $post_title );

              $body_html = '';
              $body_html .= '<html><head><title></title></head><body>';
              $body_html .= '<h3 style="color: #000;">' . sanitize_text_field( __('File expired:', 'shared-files') ) . ' ' . sanitize_text_field( $post_title ) . '</h3>';

              $body_url = admin_url('edit.php?post_type=shared_file');
              $body_html .= '<p><a href="' . esc_url_raw( $body_url ) . '" target="_blank">' . sanitize_text_field( __('File manager &raquo;', 'shared-files') ) . '</a></p>';

              $is_premium = 0;

              if (shared_files_fs()->is__premium_only()) {
                if (shared_files_fs()->can_use_premium_code()) {

                  if (!isset($s['remove_email_footer'])) {
                    $body_html .=  '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
                                    <tr>
                                      <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
                                        ' . sanitize_text_field( __('Sent by Shared Files Pro', 'shared-files') ) . '
                                      </td>
                                    </tr>
                                    </table>';
                  }

                  $is_premium = 1;

                }
              }

              if (!$is_premium) {

                $body_html .= '<table cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
                <tr>
                  <td style="border-top: 1px solid #eee; color: #bbb; padding-top: 3px; width: 100%;">
                    ' . sanitize_text_field( __('Sent by Shared Files for WordPress', 'shared-files') ) . '
                  </td>
                </tr>
                </table>';

              }

              $body_html .= '</body></html>';

              $resp = wp_mail($recipient_email, $subject, $body_html, $headers);

            }

          }

        endwhile;
      endif;

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        // Delete expired files

        if (isset($s['delete_expired_files'])) {

          $wpb_all_query_all_files = new WP_Query(array(
            'post_type' => 'shared_file',
            'post_status' => 'publish',
            'posts_per_page' => -1,

            'meta_query' => array(
              'relation' => 'AND',
                array(
                  'key' => '_sf_expiration_date',
                  'compare' => 'EXISTS'
                ),
            )
          ));

          if (isset($wpb_all_query_all_files) && $wpb_all_query_all_files->have_posts()):

            $count = 0;

            while ($wpb_all_query_all_files->have_posts()): $wpb_all_query_all_files->the_post();

              $id = intval( get_the_id() );
              $c = get_post_custom($id);

              $filename = sanitize_text_field( $c['_sf_filename'][0] );
              $post_title = sanitize_text_field( get_the_title($id) ) . ' / ' . $filename;

              $expiration_date = get_post_meta($id, '_sf_expiration_date', true);

              if ($expiration_date instanceof DateTime) {
                $dt_now = new DateTime('now');

                if ($expiration_date <= $dt_now) {

                  wp_trash_post($id);

                  $count++;

                }

              }

            endwhile;

            if ($count > 0) {
              SharedFilesHelpers::writeLog($count . ' expired file(s) moved to trash', '');
            }

          endif;

        }

      }
    }

  }

}
