<?php

class SharedFilesAdminTaxonomy {

  public function create_shared_files_custom_taxonomy() {

    if ( SHARED_FILES_TAG_SLUG != 'post_tag' ) {

      $labels_tag = array(
        'name'              => sanitize_text_field( __('Tag', 'shared-files') ),
        'singular_name'     => sanitize_text_field( __('Tag', 'shared-files') ),
        'search_items'      => sanitize_text_field( __('Search Tags', 'shared-files') ),
        'all_items'         => sanitize_text_field( __('All Tags', 'shared-files') ),
        'parent_item'       => sanitize_text_field( __('Parent Tag', 'shared-files') ),
        'parent_item_colon' => sanitize_text_field( __('Parent Tag:', 'shared-files') ),
        'edit_item'         => sanitize_text_field( __('Edit Tag', 'shared-files') ),
        'update_item'       => sanitize_text_field( __('Update Tag', 'shared-files') ),
        'add_new_item'      => sanitize_text_field( __('Add New Tag', 'shared-files') ),
        'new_item_name'     => sanitize_text_field( __('New Type Name', 'shared-files') ),
        'menu_name'         => sanitize_text_field( __('Tags', 'shared-files') ),
      );

      register_taxonomy(SHARED_FILES_TAG_SLUG, array('shared_file'), array(
        'hierarchical'        => false,
        'labels'              => $labels_tag,
        'show_ui'             => true,
        'show_admin_column'   => true,
        'query_var'           => true,
        'rewrite'             => array('slug' => 'tag'),
        'publicly_queryable'  => false
      ));

    }

    $labels_category = array(
      'name'              => sanitize_text_field( __('Category', 'shared-files') ),
      'singular_name'     => sanitize_text_field( __('Category', 'shared-files') ),
      'search_items'      => sanitize_text_field( __('Search Categories', 'shared-files') ),
      'all_items'         => sanitize_text_field( __('All Categories', 'shared-files') ),
      'parent_item'       => sanitize_text_field( __('Parent Category', 'shared-files') ),
      'parent_item_colon' => sanitize_text_field( __('Parent Category:', 'shared-files') ),
      'edit_item'         => sanitize_text_field( __('Edit Category', 'shared-files') ),
      'update_item'       => sanitize_text_field( __('Update Category', 'shared-files') ),
      'add_new_item'      => sanitize_text_field( __('Add New Category', 'shared-files') ),
      'new_item_name'     => sanitize_text_field( __('New Type Name', 'shared-files') ),
      'menu_name'         => sanitize_text_field( __('Categories', 'shared-files') ),
    );

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        register_taxonomy('shared-file-category', array('shared_file'), array(
          'hierarchical'        => true,
          'labels'              => $labels_category,
          'show_ui'             => true,
          'show_admin_column'   => true,
          'query_var'           => true,
          'rewrite'             => array('slug' => 'category'),
          'publicly_queryable'  => false
        ));

      }
    }

  }

  public function register_categories_info_page() {
    add_submenu_page(
      'edit.php?post_type=shared_file',
      sanitize_text_field( __('Categories', 'shared-files') ),
      sanitize_text_field( __('Categories', 'shared-files') ),
      'manage_options',
      'shared-files-categories-info',
      [$this, 'register_categories_info_page_callback'],
      3
    );
  }

  public function register_categories_info_page_callback() {
    ?>

    <div class="wrap shared-files-admin-page">
      <h1><?php echo esc_html__('Categories', 'shared-files'); ?></h1>

      <?php echo SharedFilesAdminHelpers::sfProFeatureMarkup() ?>

      <h2 style="margin-top: 24px;"><?php echo esc_html__('Category password protection and file sync in Pro:') ?></h2>

      <img src="<?php echo esc_url_raw( SHARED_FILES_URI ) ?>img/category-password-protection.png" style="max-width: 770px; height: auto; border: 1px solid #bbb;" />

    </div>
    <?php
  }

  function taxonomy_custom_fields($term) {
    ?>

    <tr class="form-field">
      <th scope="row" valign="top">
      </th>
      <td>
        <div class="shared-files-category-description-info"><b><?php echo esc_html__('The description field above can be used to alter the order of the categories in [shared_files_categories]-shortcode.', 'shared-files') ?></b><br /><br /><?php echo esc_html__('If a value is entered, the categories are sorted by that.', 'shared-files') ?></div>
      </td>
    </tr>

    <?php if (shared_files_fs()->is__premium_only()) {  ?>
      <?php if (shared_files_fs()->can_use_premium_code()) { ?>

        <tr>
          <td style="padding: 0;" colspan="2">
            <div class="sync-files-title" style="font-size: 18px; font-weight: 700; margin-top: 30px; padding-bottom: 10px; margin-bottom: 10px; border-bottom: 1px solid #000;"><?php echo esc_html__('Sync files', 'shared-files') ?></div>
          </td>
        </tr>

        <?php $value = sanitize_file_name( get_term_meta( $term->term_id, '_sf_cat_folder_name', true ) ); ?>

        <?php $path = SharedFilesFileHandling::getBaseDir(); ?>

        <tr class="form-field">
          <th scope="row" valign="top">
            <label for="_sf_cat_folder_name"><?php echo esc_html__('Folder name', 'shared-files') ?></label>
          </th>
          <td>
            <div class="form-field">
              <input type="text" name="_sf_cat_folder_name" id="_sf_cat_folder_name" class="shared-files-category-folder-name" value="<?php echo esc_attr( $value ) ?>" />

              <?php if ($value): ?>

                <?php $folder_path = $path . $value ?>

                <?php if ( file_exists( $folder_path ) ): ?>
                  <span class="shared-files-sync-category-active">[ <?php echo esc_html__('OK – SYNC ACTIVE', 'shared-files') ?> ]</span>
                <?php else: ?>
                  <span class="shared-files-sync-category-error">[ <?php echo esc_html__('ERROR – folder not found', 'shared-files') ?> ]</span>
                <?php endif; ?>

              <?php endif; ?>

              <?php if ( $ts = wp_next_scheduled('cron_sync_folders_and_files') ): ?>
                <hr class="clear" />
                <div class="shared-files-taxonomy-next-sync">
                  Next sync: <?php echo esc_html( wp_date('Y-m-d H:i:s', $ts) ) ?>
                </div>
              <?php endif; ?>

              <div class="shared-files-category-password-info"><?php echo esc_html__('If a single folder name is defined here, any files found in this folder will be automatically activated for the plugin.', 'shared-files') ?><br /><br />
              <?php echo esc_html__("The folder's actual location on the server would be like so:", 'shared-files') ?>

              <?php $folder_name_sample = 'folder-name'; ?>
              <?php $folder_name_sample_class = 'shared-files-folder-name-sample-black'; ?>

              <?php if ($value): ?>

                <?php $folder_name_sample = $value; ?>

                <?php if ( file_exists( $folder_path ) ): ?>
                  <?php $folder_name_sample_class = 'shared-files-folder-name-sample-green'; ?>
                <?php else: ?>
                  <?php $folder_name_sample_class = 'shared-files-folder-name-sample-red'; ?>
                <?php endif; ?>

              <?php endif; ?>

              <span class="shared-files-category-sync-folder-path"><?php echo esc_html( $path ) ?><span class="<?php echo esc_attr( $folder_name_sample_class ) ?>"><?php echo esc_attr( $folder_name_sample ) ?></span>/</span>

              <div style="height: 15px;"></div>

              <?php echo esc_html__("If you would like to host the files in some other location on the server, you could create a symbolic link like so:", 'shared-files') ?><br />

              <span class="shared-files-category-sync-folder-path">ln -s /path/to/new/folder <?php echo esc_html( $path ) ?><?php echo esc_attr( $folder_name_sample ) ?></span></div>

            </div>
          </td>
        </tr>

        <tr>
          <td style="padding: 0;" colspan="2">
            <div class="password-protection-title" style="font-size: 18px; font-weight: 700; margin-top: 30px; padding-bottom: 10px; margin-bottom: 10px; border-bottom: 1px solid #000;"><?php echo esc_html__('Password protection', 'shared-files') ?></div>
          </td>
        </tr>

        <?php $value = sanitize_text_field( get_term_meta( $term->term_id, '_sf_cat_password', true ) ); ?>

        <tr class="form-field">
          <th scope="row" valign="top">
            <label for="_sf_cat_password"><?php echo esc_html__('Password', 'shared-files') ?></label>
          </th>
          <td>
            <div class="form-field">
              <input type="password" name="_sf_cat_password" id="_sf_cat_password" class="shared-files-category-password" value="<?php echo esc_attr( $value ) ?>" autofill="off" autocomplete="new-password" /> <input type="button" value="<?php echo esc_attr__('Show', 'shared-files') ?>" class="shared-files-show-cat-password" />
              <div class="shared-files-category-password-info"><?php echo esc_html__('If a password is defined here, all files in this category will require a password to open.', 'shared-files') ?></div>
            </div>
          </td>
        </tr>

        <?php $type_value = sanitize_text_field( get_term_meta( $term->term_id, '_sf_cat_password_protection_type', true ) ); ?>

        <tr class="form-field">
          <th scope="row" valign="top">
            <label><?php echo esc_html__('Type of password protection (only active when the password is set above)', 'shared-files') ?></label>
          </th>
          <td>
            <div class="form-field">

              <label><input type="radio" name="_sf_cat_password_protection_type" id="_sf_cat_password_protection_type" value="" <?php if (!$type_value) echo 'checked' ?> class="shared-files-category-protection-type" /> <?php echo esc_html__('The files in this category can be listed by anyone.', 'shared-files') ?><br /><?php echo esc_html__('The password is required only when opening a file from this category.', 'shared-files') ?></label><br /><br />

              <label><input type="radio" name="_sf_cat_password_protection_type" id="_sf_cat_password_protection_type" value="cookie" <?php if ($type_value == 'cookie') echo 'checked' ?> class="shared-files-category-protection-type" /> <?php echo esc_html__('The password is required also for browsing the file list, meaning that the password is asked when this category is selected.', 'shared-files') ?><br />

              <?php echo esc_html__('When the correct password is given, the user can open any file in this category and the password is not asked again in 30 minutes.', 'shared-files') ?>

            </label>

            <div class="shared-files-category-password-info">

              <?php echo esc_html__('The password protection is always recursive, meaning that any subcategories will also be password protected.', 'shared-files') ?><br /><br />

              <strong><?php echo esc_html__('When the password protection for browsing the file list is enabled, the following should be noted:', 'shared-files') ?></strong>

              <ul style="list-style: inside; padding-left: 5px;">
                <li><?php echo esc_html__('Use the shortcode [shared_files_categories] or [shared_files hide_files_first=1 hide_search_for_all_files=1]. This way the user will be always forced to choose a category.', 'shared-files') ?></li>
                <li><?php echo esc_html__('Listing files by a tag is not password protected (you may want to disable the tag dropdown and not use tags at all).', 'shared-files') ?></li>
              </ul>

            </div>

            </div>
          </td>
        </tr>

      <?php } ?>
    <?php } ?>

  <?php
  }

  public function theme_columns($theme_columns) {

    $new_columns = [];
    $columns_set = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $new_columns = array(
          'cb'          => '<input type="checkbox" />',
          'name'        => sanitize_text_field( __('Name') ),
          'description' => sanitize_text_field( __('Description') ),
          'restriction' => sanitize_text_field( __('Restriction', 'shared-files') ),
          'shortcode'   => sanitize_text_field( __('Shortcode', 'shared-files') ),
          'slug'        => sanitize_text_field( __('Slug') ),
          'posts'       => sanitize_text_field( __('Posts') )
        );

        $columns_set = 1;

      }
    }

    if ( !$columns_set ) {

      $new_columns = array(
        'cb'          => '<input type="checkbox" />',
        'name'        => sanitize_text_field( __('Name') ),
        'description' => sanitize_text_field( __('Description') ),
        'shortcode'   => sanitize_text_field( __('Shortcode', 'shared-files') ),
        'slug'        => sanitize_text_field( __('Slug') ),
        'posts'       => sanitize_text_field( __('Posts') )
      );

    }

    return $new_columns;
  }

  function save_term_fields($term_id) {

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $term_id = intval( $term_id );

        if (isset($_POST['_sf_cat_folder_name']) && $_POST['_sf_cat_folder_name']) {

          update_term_meta(
            $term_id,
            '_sf_cat_folder_name',
            sanitize_file_name( $_POST['_sf_cat_folder_name'] )
          );

        } elseif (isset($_POST['_sf_cat_folder_name']) && !$_POST['_sf_cat_folder_name']) {

          update_term_meta(
            $term_id,
            '_sf_cat_folder_name',
            ''
          );

        }

        if (isset($_POST['_sf_cat_password']) && $_POST['_sf_cat_password']) {

          update_term_meta(
            $term_id,
            '_sf_cat_password',
            sanitize_text_field( $_POST['_sf_cat_password'] )
          );

        } elseif (isset($_POST['_sf_cat_password']) && !$_POST['_sf_cat_password']) {

          update_term_meta(
            $term_id,
            '_sf_cat_password',
            ''
          );

        }

        if (isset($_POST['_sf_cat_password_protection_type']) && $_POST['_sf_cat_password_protection_type']) {

          update_term_meta(
            $term_id,
            '_sf_cat_password_protection_type',
            sanitize_text_field( $_POST['_sf_cat_password_protection_type'] )
          );

        } elseif (isset($_POST['_sf_cat_password_protection_type']) && !$_POST['_sf_cat_password_protection_type']) {

          update_term_meta(
            $term_id,
            '_sf_cat_password_protection_type',
            ''
          );

        }

      }
    }

  }

  public function add_shared_file_category_column_content($content, $column_name, $term_id) {

    $term = get_term($term_id, 'shared-file-category');

    switch ($column_name) {
      case 'restriction':

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          $cat_password = sanitize_text_field( get_term_meta( $term->term_id, '_sf_cat_password', true ) );
          $cat_protection_type = sanitize_text_field( get_term_meta( $term->term_id, '_sf_cat_password_protection_type', true ) );

          $content = '';

          $restriction_active = 0;

          if ( $cat_password ) {
            $content .= '<div><span class="shared-files-tax-password-set">' . sanitize_text_field( __('Password set', 'shared-files') ) . '</span></div>';

            $restriction_active = 1;

            if ( $cat_protection_type == 'cookie' ) {
              $content .= '<div><span class="shared-files-tax-list-blocked">' . sanitize_text_field( __('List blocked', 'shared-files') ) . '</span></div>';
            } else {
              $content .= '<div><span class="shared-files-tax-list-browsable">' . sanitize_text_field( __('List browsable', 'shared-files') ) . '</span></div>';
            }

          }

          if ( !$restriction_active ) {
            echo '<div><span class="shared-files-restr-none">' . esc_html__('None', 'shared-files') . '</span></div>';
          }

        }
      }

      break;

      case 'shortcode':
        $content = '<span class="shared-files-shortcode-admin-list shared-files-shortcode-' . sanitize_title( $term->slug ) . '" title="[shared_files category=' . sanitize_title( $term->slug ) . ']">[shared_files category=' . sanitize_title( $term->slug ) . ']</span>' .
          '<button class="shared-files-copy shared-files-copy-admin-list" data-clipboard-action="copy" data-clipboard-target=".shared-files-shortcode-' . sanitize_title( $term->slug ) . '">' . sanitize_text_field( __('Copy', 'shared-files') ) . '</button>';
        break;
      default:
        break;
    }

    return $content;

  }

}
