<?php

class SharedFilesPublicFileCardMinimal {

  public static function fileListItem($c, $imagefile, $hide_description, $show_tags = 0, $atts = [], $favorites = 0) {

    $s = get_option('shared_files_settings');
    $file_id = intval( get_the_id() );
    $file_url = SharedFilesPublicHelpers::getFileURL($file_id);
    $date_format = get_option('date_format');

    $file_metadata = get_post_meta($file_id, '_sf_file', true);

    $file_realpath = '';

    if (isset($file_metadata['file']) && $file_metadata['file']) {
      $file_realpath = SharedFilesFileOpen::getUpdatedPathAndFilename( sanitize_text_field( $file_metadata['file'] ) );
    }

    if (!isset($s['bypass_file_exists_check']) && $file_realpath && !is_readable($file_realpath)) {
      $html = '<div class="shared-files-permission-denied-for"><b>' . sanitize_text_field( __("Can't read file (permission denied or file not found):", 'shared-files') ) . '</b><br />' . sanitize_text_field( $file_realpath ) . '</div>';
      return $html;
    }

    $password = '';
    $cat_password = '';
    $file_password = '';

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $cat_password = SharedFilesHelpers::getCatPassword__premium_only($file_id);
        $file_password = sanitize_text_field( get_post_meta($file_id, '_sf_password', true) );

        if ($file_password) {
          $password = $file_password;
        } elseif ($cat_password) {
          $password = $cat_password;
        }

      }
    }

    $file_access_logged_in_only = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if ( isset( $s['file_access_logged_in_only'] ) && !is_user_logged_in() ) {
          $file_access_logged_in_only = 1;
        }

      }
    }

    $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';

    $html = '';

    $left_style = '';

    if ( isset( $s['hide_file_type_icon_from_card'] ) ) {
      $left_style = 'width: 6px; background: none;';
    } elseif ( !$file_access_logged_in_only || isset( $s['file_access_logged_in_only_show_featured_image'] ) ) {
      $left_style = 'background: url(' . esc_attr( $imagefile ) . ') right top no-repeat; background-size: 24px;';
    }

    $html .= '<li>';
    $html .= '<div class="shared-files-main-elements shared-files-minimal">';

    $html .= '<div class="shared-files-main-elements-left shared-files-minimal" style="' . esc_attr( $left_style ) . '"></div>';

    $html .= '<div class="shared-files-main-elements-right shared-files-minimal">';

    $data_file_type = '';
    $data_file_url = '';
    $data_video_url_redir = '';
    $data_external_url = '';
    $data_image_url = '';

    if (
        !$password &&
        !SharedFilesPublicHelpers::limitActive( $file_id ) &&
        !$file_access_logged_in_only
        ) {

      $this_file_type = SharedFilesPublicHelpers::getFileType($file_id);

      $data_file_type = ' data-file-type="' . esc_attr( SharedFilesPublicHelpers::getFileType($file_id) ) . '" ';
      $data_file_url = ' data-file-url="' . esc_url_raw( SharedFilesPublicHelpers::getFileURL($file_id) ) . '" ';
      $data_external_url = ' data-external-url="' . esc_url_raw( $external_url ) . '" ';
      $data_image_url = ' data-image-url="' . esc_url_raw( get_the_post_thumbnail_url($file_id, 'large') ) . '" ';

      if (isset($s['file_open_method']) && $s['file_open_method'] == 'redirect') {

        if ( substr($this_file_type, 0, strlen('video')) === 'video' ) {

          $file_uri = SharedFilesFileOpen::getRedirectTarget( $file_id );

          $data_video_url_redir = ' data-video-url-redir="' . esc_url_raw( $file_uri ) . '" ';

        }

      }

    }

    $nofollow = '';

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if ( isset( $c['_sf_frontend_uploader'] ) && isset($s['prevent_search_engines_from_indexing_uploaded_file_urls']) ) {
          $nofollow = 'rel="ugc nofollow" ';
        } elseif ( isset($s['prevent_search_engines_from_indexing_file_urls']) ) {
          $nofollow = 'rel="nofollow" ';
        }

      }
    }

    $html .= '<a class="shared-files-file-title" ' .
      $data_file_type .
      $data_file_url .
      $data_video_url_redir .
      $data_external_url .
      $data_image_url .
      'href="' . esc_url( $file_url ) . '" target="_blank" ' . $nofollow . '>' . sanitize_text_field( get_the_title() ) . '</a>';

    if (isset($c['_sf_filesize']) && !isset($s['hide_file_size_from_card'])) {
      $html .= '<span class="shared-file-size">' . sanitize_text_field( SharedFilesAdminHelpers::human_filesize($c['_sf_filesize'][0]) ) . '</span>';
    }

    $html .= '</div>';

    $html .= '</div>';
    $html .= '</li>';

    return $html;

  }

}
