<?php

class SharedFilesFileUpload {

  public static function fileUploadMarkup($atts, $restrict_access = 0) {

    $html = '';

    $s = get_option('shared_files_settings');

    if (!function_exists('wp_terms_checklist')) {
      include ABSPATH . 'wp-admin/includes/template.php';
    }

    $upload_id = '';


    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if ( isset( $atts['upload_id'] ) && $atts['upload_id'] ) {
          $upload_id = $atts['upload_id'];
        }

      }
    }

    $post_id = intval( get_the_id() );
    $post_title = sanitize_text_field( get_the_title() );

    if ( isset($_GET) && isset($_GET['shared-files-upload']) ) {

      $multiple_files_upload_active = 0;

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          $multiple_files_upload_active = 1;

          $html .= '<div class="shared-files-upload-complete">' . sanitize_text_field( __('File(s) successfully uploaded.', 'shared-files') ) . '</div>';

        }
      }

      if ( !$multiple_files_upload_active ) {

        $html .= '<div class="shared-files-upload-complete">' . sanitize_text_field( __('File successfully uploaded.', 'shared-files') ) . '</div>';

      }

    } elseif (isset($_GET) && isset($_GET['_sf_delete_file']) && isset($_GET['sc'])) {
      $html .= '<div class="shared-files-file-deleted">' . sanitize_text_field( __('File successfully deleted.', 'shared-files') ) . '</div>';
    }

    $exclude_cat = [];

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($atts['file_upload_exclude_cat'])) {
          $terms = explode(',', sanitize_text_field( $atts['file_upload_exclude_cat'] ));

          foreach ($terms as $term_slug) {
            $term = get_term_by('slug', $term_slug, 'shared-file-category');

            if ($term && isset($term->term_id)) {
              $exclude_cat []= intval( $term->term_id );
            }

          }

        }

      }
    }

    $exclude_tag = [];

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($atts['file_upload_exclude_tag'])) {
          $terms = explode(',', sanitize_text_field( $atts['file_upload_exclude_tag'] ));

          foreach ($terms as $term_slug) {
            $term = get_term_by('slug', $term_slug, SHARED_FILES_TAG_SLUG);

            if ($term && isset($term->term_id)) {
              $exclude_tag []= intval( $term->term_id );
            }

          }

        }

      }
    }

    $ajax_class = '';

    if ( !isset($s['file_upload_disable_progress_bar']) ) {
      $ajax_class = ' shared-files-frontend-file-upload-ajax-active';
    }

    $html .= '<div class="sf-public-file-upload-container">';
    $html .= '<form method="post" enctype="multipart/form-data" class="shared-files-frontend-file-upload' . $ajax_class . '">';

    $html .= wp_nonce_field('sf_insert_file', 'secret_code', true, false);

    $html .= '<input name="shared-files-upload" value="1" type="hidden" />';

    $html .= '<input name="_sf_embed_post_id" value="' . esc_attr( $post_id ) . '" type="hidden" />';
    $html .= '<input name="_sf_embed_post_title" value="' . esc_attr( $post_title ) . '" type="hidden" />';

    if ( isset( $atts['only_uploaded_files'] ) && $post_id ) {
      $html .= '<input name="_SF_ONLY_UPLOADED_FILES" value="1" type="hidden" />';
    } else {
      $html .= '<input name="_SF_ONLY_UPLOADED_FILES" value="0" type="hidden" />';
    }

    $html .= '<input name="_sf_upload_id" value="' . esc_attr( $upload_id ) . '" type="hidden" />';

    if ( $restrict_access ) {
      $html .= '<input name="_sf_restrict_access" value="1" type="hidden" />';
    }

    $html .= '<input name="_SF_GOTO" value="' . esc_url_raw( get_permalink() ) . '" type="hidden" />';

    $accept = '';

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($s['file_upload_restrict_file_extensions']) && $s['file_upload_restrict_file_extensions']) {

          $accept .= sanitize_text_field( $s['file_upload_restrict_file_extensions'] );

        } elseif (isset($s['file_upload_restrict_file_types']) && $s['file_upload_restrict_file_types']) {

          switch ($s['file_upload_restrict_file_types']) {

            case 'any_sound_file':
              $accept .= 'audio/*';
              break;

            case 'any_video_file':
              $accept .= 'video/*';
              break;

            case 'any_image_file':
              $accept .= 'image/*';
              break;

          }

        }

      }
    }

    $multiple_files_upload_active = 0;

    $file_required = 'required';

    if ( isset( $s['file_upload_file_not_required'] ) ) {
      $file_required = '';
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $multiple_files_upload_active = 1;

        $html .= '<input type="hidden" name="_sf_insert_multiple_files_frontend" value="1" />';
        $html .= '<input type="file" name="_sf_files[]" multiple ' . $file_required . ' /><hr class="clear" />';

      }
    }

    if ( !$multiple_files_upload_active ) {

      $html .= '<input type="file" id="sf_file" accept="' . esc_attr( $accept ) . '" name="_sf_file" size="25" ' . $file_required . ' /><hr class="clear" />';

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($s['file_upload_allow_featured_image'])) {
          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Featured image', 'shared-files') ) . '</span>';
          $html .= '<input type="file" accept=".jpg, .jpeg, .png, .gif, .webp, .avif" name="_sf_featured_image" size="25" /><hr class="clear" />';
        }

      }
    }

    $html .= '<p style="margin-top: 10px; margin-bottom: 8px;">' . sanitize_text_field( __('Maximum file size:', 'shared-files') ) . ' <strong>' . sanitize_text_field( SharedFilesHelpers::maxUploadSize() ) . '</strong></p>';

    if (isset($s['file_upload_show_external_url'])) {

      $html .= '<div class="shared-files-file-upload-youtube-container">';

      $external_url_title = sanitize_text_field( __('Or enter a YouTube URL:', 'shared-files') );

      if (isset($s['file_upload_external_url_title']) && $s['file_upload_external_url_title']) {
        $external_url_title = sanitize_text_field( $s['file_upload_external_url_title'] );
      }

      $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( $external_url_title ) . '</span>';
      $html .= '<input type="text" name="_sf_external_url" class="shared-files-external-url" value="" />';

      $html .= '</div>';

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if ( isset( $s['file_upload_enable_restrict_access_for_users'] ) || isset( $s['file_upload_enable_restrict_access_for_roles'] ) ) {

          if ( is_user_logged_in() ) {

            $html .= '<div class="shared-files-file-upload-permissions">';

            if ( isset( $s['file_upload_enable_restrict_access_for_users'] ) ) {

              $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Restrict access for users', 'shared-files') ) . '</span>';

              $html .= '<div class="shared-files-file-upload-permissions-user-select">';

              $users = get_users( 'orderby=display_name&order=ASC' );

              $html .= '<select class="shared-files-upload-user-select" name="_sf_permission_user_id[]" multiple="multiple">';

              foreach ($users as $user) {

                $selected = '';

                $full_name = '';

                if ( $user->last_name || $user->first_name ) {

                  $full_name .= ' (';

                  if ( $user->first_name ) {
                    $full_name .= sanitize_text_field( $user->first_name );
                  }

                  if ( $user->last_name ) {

                    if ( $user->first_name ) {
                      $full_name .= ' ';
                    }

                    $full_name .= sanitize_text_field( $user->last_name );
                  }

                  $full_name .= ')';

                }

                $html .= '<option ' . esc_attr( $selected ) . ' value="' . intval( $user->ID ) . '">' . esc_html( $user->display_name . $full_name ) . '</option>';

              }

              $html .= '</select>';

              $html .= '</div>';

            }

            if ( isset( $s['file_upload_enable_restrict_access_for_roles'] ) ) {

              $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Restrict access for roles', 'shared-files') ) . '</span>';

              global $wp_roles;

              $roles = $wp_roles->get_names();

              $html .= '<div class="shared-files-upload-role-checkboxes">';

              foreach ($roles as $key => $value) {

                if ($key && $value) {

                  $field_name = '_sf_permission_user_role_' . sanitize_title( $key );

                  $checked = intval( get_post_meta($post_id, $field_name, true) );

                  $checked_markup = '';

                  if ($checked) {
                    $checked_markup = 'checked';
                  }

                  $html .= '<div class="shared-files-upload-role-checkbox-container"><label><input type="checkbox" class="shared-files-upload-role-checkbox" name="_sf_permission_user_role_' . esc_attr( $key ) . '" value="' . esc_attr( $key ) . '" ' . esc_attr( $checked_markup ) . ' />' . esc_html( $value ) . '</label></div>';

                }

              }

              $html .= '</div>';

            }

            $html .= '</div>';

          }

        }

      }
    }


    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($atts['category'])) {

          $category_slug = sanitize_title( $atts['category'] );
          $html .= '<input name="shared-file-category" type="hidden" value="' . $category_slug . '" />';

        } else {

          $taxonomy_slug = 'shared-file-category';

          if (isset($atts['category_checkboxes']) || isset($s['show_category_checkboxes_on_file_upload'])) {

            if (is_array($exclude_cat) && sizeof($exclude_cat) > 0) {

              $html .= '<style>';

              foreach ($exclude_cat as $cat) {
                $html .= '#shared-file-category-' . sanitize_title( $cat ) . ' { display: none; } ';
              }

              $html .= '</style>';

            }

            $termlist_args = ['taxonomy' => $taxonomy_slug, 'echo' => 0 ];
            $html .= '<span class="sf-termlist-title">' . sanitize_text_field( __('Categories', 'shared-files') ) . '</span><ul class="sf-termlist">' . wp_terms_checklist(0, $termlist_args) . '</ul>';

          } elseif (!isset($atts['hide_category_dropdown'])) {

            $required = 0;

            if ( isset($s['file_upload_category_required']) ) {
              $required = 1;
            }

            if (get_taxonomy($taxonomy_slug)) {

              $html .= wp_dropdown_categories([
                'hide_empty'      => 0,
                'hierarchical'    => 1,
                'show_count'      => 0,
                'orderby'         => 'name',
                'name'            => $taxonomy_slug,
                'value_field'     => 'slug',
                'taxonomy'        => $taxonomy_slug,
                'echo'            => 0,
                'class'           => 'select_v2',
                'exclude'         => $exclude_cat,

                'required'        => $required,

                'show_option_none'  => esc_html__('Choose category', 'shared-files'),
                'option_none_value' => '',

              ]);

            }

          }

        }

      }
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($atts['new_category']) || isset($s['file_upload_new_category'])) {

          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Name for a new category', 'shared-files') ) . '</span>';
          $html .= '<span class="new-category-info">' . sanitize_text_field( __('A new category will be created and the uploaded file is assigned to it.', 'shared-files') ) . '</span>';

          $taxonomy_slug = 'shared-file-category';

          if (get_taxonomy($taxonomy_slug)) {

            $html .= wp_dropdown_categories([
              'show_option_all' => ' ',
              'hide_empty'      => 0,
              'hierarchical'    => 1,
              'show_count'      => 0,
              'orderby'         => 'name',
              'name'            => '_sf_new_category_parent_id',
              'value_field'     => 'id',
              'taxonomy'        => $taxonomy_slug,
              'echo'            => 0,
              'class'           => 'select_v2 shared-files-parent-category',
              'show_option_all' => esc_html__('Choose a parent category for the new category (optional)', 'shared-files')
            ]);

          }

          $html .= '<hr class="clear" /><input type="text" name="_sf_new_category_name" class="shared-files-title" value="" />';

        }

        if ( isset($s['file_upload_multiple_new_categories']) ) {

          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('New categories (comma separated)', 'shared-files') ) . '</span>';
          $html .= '<span class="new-category-info">' . sanitize_text_field( __('New categories will be created and the uploaded file is assigned to them.', 'shared-files') ) . '</span>';
          $html .= '<hr class="clear" /><input type="text" name="_SF_NEW_CATEGORIES" class="shared-files-title" value="" />';

        }

        if ( isset($s['file_upload_multiple_new_tags']) || isset($atts['new_tags']) ) {

          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('New tags (comma separated)', 'shared-files') ) . '</span>';
          $html .= '<span class="new-category-info">' . sanitize_text_field( __('New tags will be created and the uploaded file is assigned to them.', 'shared-files') ) . '</span>';
          $html .= '<hr class="clear" /><input type="text" name="_sf_new_tags" class="shared-files-title" value="" />';

        }

      }
    }

    $tag_slug_for_dropdown = SHARED_FILES_TAG_SLUG;

    $tag_count = wp_count_terms( SHARED_FILES_TAG_SLUG, array(
      'hide_empty'  => false,
    ) );

    if ( $tag_count ) {

      if (isset($atts['tag_dropdown']) || isset($s['show_tag_dropdown_on_file_upload'])) {

        if (get_taxonomy($tag_slug_for_dropdown)) {

          $html .= wp_dropdown_categories([
            'show_option_all' => ' ',
            'hide_empty'      => 0,
            'hierarchical'    => 0,
            'show_count'      => 0,
            'orderby'         => 'name',
            'name'            => $tag_slug_for_dropdown,
            'value_field'     => 'slug',
            'taxonomy'        => $tag_slug_for_dropdown,
            'echo'            => 0,
            'class'           => 'select_v2',
            'show_option_all' => sanitize_text_field( __('Choose tag', 'shared-files') ),
            'exclude'         => $exclude_tag
          ]);

        }

      } else if (isset($atts['tag_checkboxes']) || isset($s['show_tag_checkboxes_on_file_upload'])) {

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            if (is_array($exclude_tag) && sizeof($exclude_tag) > 0) {

              $html .= '<style>';

              foreach ($exclude_tag as $tag) {
                $html .= '.sf-taglist #' . sanitize_title( SHARED_FILES_TAG_SLUG ) . '-' . intval( $tag ) . ' { display: none; } ';
              }

              $html .= '</style>';

            }

          }
        }

        $taglist_args = ['taxonomy' => SHARED_FILES_TAG_SLUG, 'echo' => 0];
        $html .= '<span class="sf-taglist-title">' . sanitize_text_field( __('Tags', 'shared-files') ) . '</span><ul class="sf-taglist">' . wp_terms_checklist(0, $taglist_args) . '</ul>';

      }

    }

    $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Title', 'shared-files') ) . '</span>';
    $html .= '<input type="text" name="_sf_title" class="shared-files-title" value="" ' . SharedFilesHelpers::fieldAttrRequired('file_upload_title_required') . ' />';

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($s['file_upload_password'])) {
          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Password', 'shared-files') ) . '</span>';
          $html .= '<input type="password" name="_sf_password" class="shared-files-password" value="" autofill="off" autocomplete="new-password" />';
        }

      }
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($s['file_upload_show_expiration_date'])) {
          $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Expiration date', 'shared-files') ) . '</span>';
          $html .= '<input type="date" name="_sf_expiration_date" class="shared-files-password" value="" />';
        }

      }
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $custom_fields_cnt = 3 + 1;

        if (isset($s['custom_fields_cnt'])) {
          $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
        } else {
          $custom_fields_cnt = 5 + 1;
        }

        for ($n = 1; $n < $custom_fields_cnt; $n++) {

          $file_upload_cf = sanitize_text_field( get_post_meta($post_id, '_sf_file_upload_cf_' . $n, true) );

          if (isset($s['file_upload_custom_field_' . $n]) && $s['file_upload_custom_field_' . $n] && !isset($s['cf_' . $n . '_hide_from_frontend_uploader']) && $cf_title = $s['file_upload_custom_field_' . $n]) {

            $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( $s['file_upload_custom_field_' . $n] ) . '</span>';
            $html .= '<input type="text" name="_sf_file_upload_cf_' . $n . '" value="" />';

          }

        }

      }
    }

    if ( !isset($s['file_upload_hide_description']) ) {
      $html .= '<span class="shared-files-upload-field-title">' . sanitize_text_field( __('Description', 'shared-files') ) . '</span>';
      $html .= '<textarea name="_sf_description" class="shared-files-description" ' . SharedFilesHelpers::fieldAttrRequired('file_upload_description_required') . '></textarea>';
    }

    if ( !isset($s['file_upload_disable_progress_bar']) ) {
      $html .= SharedFilesHelpers::ajaxUploadMarkup();
    }

    $html .= '<hr class="clear" /><input type="submit" value="' . esc_attr__('Submit', 'shared-files') . '" class="sf-public-file-upload-submit" />';

    $html .= '</form>';

    // .sf-public-file-upload-container
    $html .= '</div>';

    return $html;

  }

  public function file_upload_single_free($request) {

    $s = get_option('shared_files_settings');

    if (isset($_GET) && isset($_GET['_sf_delete_file'])) {

      $user = wp_get_current_user();

      $sc = '';

      if ( isset($_GET['sc']) ) {
        $sc = sanitize_text_field( $_GET['sc'] );
      }

      if (!$sc || !wp_verify_nonce($sc, 'sf_delete_file_' . intval( $user->ID ) )) {
        wp_die('Error in processing form data.');
      }

      $file_id = (int) $_GET['_sf_delete_file'];
      $file = get_post($file_id);
      $post_type = get_post_type($file_id);
      $c = get_post_custom($file_id);

      if ($file && $user->ID == $c['_sf_user_id'][0] && $post_type == 'shared_file') {
        wp_trash_post($file_id);
      }

    }

    if ( isset($_POST) && isset($_POST['shared-files-upload']) ) {

      if (!isset($_POST['secret_code']) || !wp_verify_nonce($_POST['secret_code'], 'sf_insert_file')) {
        wp_die('Error in processing form data.');
      }

      $post_status = isset($s['file_upload_set_to_pending']) && $s['file_upload_set_to_pending'] ? 'pending' : 'publish';

      $new_post = array( 'post_type'    => 'shared_file',
                         'post_status'  => $post_status,
                         'post_title'   => '',
                         'post_content' => '');

      $id = wp_insert_post($new_post);

      update_post_meta($id, '_sf_frontend_uploader', 1);

      update_post_meta($id, '_sf_embed_post_id', intval( $_POST['_sf_embed_post_id'] ));
      update_post_meta($id, '_sf_embed_post_title', sanitize_text_field( $_POST['_sf_embed_post_title'] ));

      if ( isset($_POST['_sf_upload_id']) && $_POST['_sf_upload_id'] ) {

        update_post_meta($id, '_sf_upload_id', sanitize_text_field( $_POST['_sf_upload_id'] ) );
        update_post_meta($id, '_sf_not_public', 1);

      } elseif (!isset($s['uncheck_hide_from_other_pages'])) {

        update_post_meta($id, '_sf_not_public', 1);

      } else {

        update_post_meta($id, '_sf_not_public', '');

      }

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          update_post_meta($id, '_sf_password', isset($_POST['_sf_password']) ? sanitize_text_field( $_POST['_sf_password'] ) : '');

          $expiration_date = '';

          if (isset($_POST['_sf_expiration_date']) && $_POST['_sf_expiration_date']) {
            $dt = DateTime::createFromFormat("Y-m-d", sanitize_text_field( $_POST['_sf_expiration_date'] ));

            $errors = $dt::getLastErrors();

            if ($dt !== false && !array_sum( (array) $errors )) {
              $expiration_date = $dt;
            }
          }

          update_post_meta($id, '_sf_expiration_date', $expiration_date);

          $custom_fields_cnt = 3 + 1;

          if (isset($s['custom_fields_cnt'])) {
            $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
          } else {
            $custom_fields_cnt = 5 + 1;
          }

          for ($n = 1; $n < $custom_fields_cnt; $n++) {

            if (isset($_POST['_sf_file_upload_cf_' . $n]) && $_POST['_sf_file_upload_cf_' . $n]) {
              update_post_meta($id, '_sf_file_upload_cf_' . $n, sanitize_text_field( $_POST['_sf_file_upload_cf_' . $n] ));
            }

          }

          if (isset($_POST['shared-file-category'])) {
            $cat_slug = $_POST['shared-file-category'];
            $cat = get_term_by('slug', sanitize_title( $cat_slug ), 'shared-file-category');

            if ($cat) {
              wp_set_object_terms($id, intval( $cat->term_id ), 'shared-file-category');
            }

          }

          if (isset($_POST['_sf_new_category_name']) && $_POST['_sf_new_category_name']) {

            $new_cat_args = [];

            if (isset($_POST['_sf_new_category_parent_id']) && $parent_id = intval( $_POST['_sf_new_category_parent_id'] )) {
              $new_cat_args = [ 'parent' => intval( $parent_id ) ];
            }

            $cat_name = sanitize_text_field( $_POST['_sf_new_category_name'] );
            $new_cat = wp_insert_term($cat_name, 'shared-file-category', $new_cat_args);

            if (isset($new_cat['term_id']) && $term_id = $new_cat['term_id']) {
              wp_set_object_terms($id, intval( $term_id ), 'shared-file-category', true);
            }

          }

          if (isset($_POST['_SF_NEW_CATEGORIES']) && $_POST['_SF_NEW_CATEGORIES']) {

            $new_cat_args = [];
            $new_cat_names = explode(',', sanitize_text_field( $_POST['_SF_NEW_CATEGORIES'] ));

            foreach ($new_cat_names as $new_cat_name) {
              $new_cat = wp_insert_term($new_cat_name, 'shared-file-category', $new_cat_args);

              if (isset($new_cat['term_id']) && $term_id = intval( $new_cat['term_id'] ) ) {
                wp_set_object_terms($id, intval( $term_id ), 'shared-file-category', true);
              }

            }

          }

          if (isset($_POST['_sf_new_tags']) && $_POST['_sf_new_tags']) {

            $new_tag_args = [];
            $tags = explode(',', sanitize_text_field( $_POST['_sf_new_tags'] ));

            foreach ($tags as $tag) {

              $tag_name = sanitize_text_field( $tag );
              $new_tag = wp_insert_term($tag_name, SHARED_FILES_TAG_SLUG, $new_tag_args);

              if (isset($new_tag['term_id']) && $term_id = intval( $new_tag['term_id'] ) ) {
                wp_set_object_terms($id, intval( $term_id ), SHARED_FILES_TAG_SLUG, true);
              }

            }

          }

          if (isset($_POST['tax_input']['shared-file-category']) && $cats = $_POST['tax_input']['shared-file-category']) {

            if (is_array($cats)) {
              wp_set_post_terms($id, $cats, 'shared-file-category');
            }

          }

        }
      }

      if (isset($_POST[SHARED_FILES_TAG_SLUG])) {
        $cat_slug = sanitize_title( $_POST[SHARED_FILES_TAG_SLUG] );
        $cat = get_term_by('slug', sanitize_title( $cat_slug ), SHARED_FILES_TAG_SLUG);

        if ($cat) {
          wp_set_object_terms($id, intval( $cat->term_id ), SHARED_FILES_TAG_SLUG);
        }

      }

      if (isset($_POST['tax_input'][SHARED_FILES_TAG_SLUG]) && $tags = $_POST['tax_input'][SHARED_FILES_TAG_SLUG]) {

        $tags_int = array_map(
          function($value) { return (int) $value; },
          $tags
        );

        wp_set_post_terms($id, $tags_int, SHARED_FILES_TAG_SLUG);
      }

      if (is_user_logged_in()) {
        $user = wp_get_current_user();
        update_post_meta($id, '_sf_user_id', intval( $user->ID ));

        if ( isset($_POST['_sf_restrict_access']) && $_POST['_sf_restrict_access'] ) {
          update_post_meta($id, '_sf_permission_user_id', intval( $user->ID ));
        }

      }

      if (isset($_POST['_sf_description']) && $_POST['_sf_description']) {

        $description = wp_strip_all_tags( balanceTags(wp_kses_post($_POST['_sf_description']), 1) );

        if (!isset($s['textarea_for_file_description'])) {
          $description = nl2br( $description );
        }

        update_post_meta($id, '_sf_description', $description);

      } else {
        update_post_meta($id, '_sf_description', '');
      }

      if (isset($_FILES['_sf_file']['tmp_name']) && $tmp_name = $_FILES['_sf_file']['tmp_name']) {

        // Get the file type of the upload
        $arr_file_type = wp_check_filetype(basename($_FILES['_sf_file']['name']));
        $uploaded_type = $arr_file_type['type'];

        $file_contents_sanitized = SharedFilesAdminAllowMoreFileTypes::sanitize_file( $tmp_name );

        add_filter('upload_dir', [ $this, 'set_upload_dir' ]);
        add_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );

        // Use the WordPress API to upload the file
        $upload = wp_upload_bits($_FILES['_sf_file']['name'], null, $file_contents_sanitized);

        remove_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );
        remove_filter('upload_dir', [$this, 'set_upload_dir']);

        if (isset($upload['error']) && $upload['error']) {
          wp_die('There was an error uploading your file. The error is: ' . esc_html( $upload['error'] ) );
        }

        add_post_meta($id, '_sf_file', $upload);
        update_post_meta($id, '_sf_file', $upload);

        $filename = substr(strrchr($upload['file'], "/"), 1);

        update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

        $sf_file_size = 0;
        $upload_file = '';

        if ( isset($_FILES['_sf_file']['size']) && $_FILES['_sf_file']['size'] ) {
          $sf_file_size = sanitize_text_field( $_FILES['_sf_file']['size'] );
        }

        if ( isset($upload['file']) && $upload['file'] ) {
          $upload_file = sanitize_text_field( $upload['file'] );
        }

        SharedFilesFileUpdate::uFilesize($id, $sf_file_size, $upload_file);

        $featured_image_already_added = 0;

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            if (isset($s['file_upload_allow_featured_image'])) {
              if (isset($_FILES['_sf_featured_image']['tmp_name']) && $_FILES['_sf_featured_image']['tmp_name']) {

                // Get the file type of the upload
                $fi_arr_file_type = wp_check_filetype(basename($_FILES['_sf_featured_image']['name']));
                $fi_uploaded_type = $fi_arr_file_type['type'];

                // Use the WordPress API to upload the featured image
                $fi_upload = wp_upload_bits($_FILES['_sf_featured_image']['name'], null, file_get_contents($_FILES['_sf_featured_image']['tmp_name']));

                if (isset($fi_upload['error']) && $fi_upload['error']) {
                  wp_die('There was an error uploading your file. The error is: ' . $fi_upload['error']);
                }

                $fi_filename = substr(strrchr($fi_upload['file'], "/"), 1);

                SharedFilesHelpers::addFeaturedImage($id, $fi_upload, $fi_uploaded_type, $fi_filename, 0);

                $featured_image_already_added = 1;

              }
            }

          }
        }

        if (!$featured_image_already_added) {
          SharedFilesHelpers::addFeaturedImage($id, $upload, $uploaded_type, $filename, 1);
        }

      } elseif (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {

        $external_url = esc_url_raw($_POST['_sf_external_url']);
        update_post_meta($id, '_sf_external_url', $external_url);

        $filename = basename($external_url);
        update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

      } elseif ( !isset( $s['file_upload_file_not_required'] ) ) {

        $error_msg = sanitize_text_field( __('File was not successfully uploaded. Please note the maximum file size.', 'shared_files') );
        wp_die($error_msg);

      }

      update_post_meta($id, '_sf_load_cnt', 0);
      update_post_meta($id, '_sf_bandwidth_usage', 0);
      update_post_meta($id, '_sf_file_added', current_time('Y-m-d H:i:s'));
      update_post_meta($id, '_sf_main_date', '');

      $post_title = $filename;

      if (isset($_POST['_sf_title']) && $_POST['_sf_title']) {
        $post_title = sanitize_text_field( $_POST['_sf_title'] );
      } elseif (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {
        $post_title = sanitize_text_field( __('External URL', 'shared-files') );
      }

      $my_post = array(
        'ID'           => $id,
        'post_title'   => sanitize_text_field( $post_title ),
      );

      wp_update_post($my_post);

      do_action( 'shared_files_frontend_file_uploaded', $id );

      $goto_url = esc_url_raw( get_site_url() );

      if (isset($_POST['_SF_GOTO']) && $_POST['_SF_GOTO']) {
        $goto_url = esc_url_raw( $_POST['_SF_GOTO'] );
      }

      $container_url = $goto_url;

      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {

          SharedFilesAdminSendMail::file_upload_send_email__premium_only($id, get_post($id), $container_url);

        }
      }

      wp_redirect($goto_url . '?shared-files-upload=1');
      exit;

    }

    return $request;
  }

  public function file_upload_multiple__premium_only($request) {

    $s = get_option('shared_files_settings');

    if (isset($_GET) && isset($_GET['_sf_delete_file'])) {

      $user = wp_get_current_user();

      $sc = '';

      if ( isset($_GET['sc']) ) {
        $sc = sanitize_text_field( $_GET['sc'] );
      }

      if (!$sc || !wp_verify_nonce($sc, 'sf_delete_file_' . intval( $user->ID ) )) {
        wp_die('Error in processing form data.');
      }

      $file_id = (int) $_GET['_sf_delete_file'];
      $file = get_post($file_id);
      $post_type = get_post_type($file_id);
      $c = get_post_custom($file_id);

      if ($file && $user->ID == $c['_sf_user_id'][0] && $post_type == 'shared_file') {
        wp_trash_post($file_id);
      }

    }

    if ( isset($_POST) && isset($_POST['shared-files-upload']) ) {

      if (!isset($_POST['secret_code']) || !wp_verify_nonce($_POST['secret_code'], 'sf_insert_file')) {
        wp_die('Error in processing form data.');
      }


      // NEW START

      if (isset($_POST) && isset($_POST['_sf_insert_multiple_files_frontend'])) {

        $new_cat_term_id = 0;

        if (isset($_POST['_sf_new_category_name']) && $_POST['_sf_new_category_name']) {

          $new_cat_args = [];

          if (isset($_POST['_sf_new_category_parent_id']) && $parent_id = intval( $_POST['_sf_new_category_parent_id'] )) {
            $new_cat_args = [ 'parent' => intval( $parent_id ) ];
          }

          $cat_name = sanitize_text_field( $_POST['_sf_new_category_name'] );
          $new_cat = wp_insert_term($cat_name, 'shared-file-category', $new_cat_args);

          if ( isset( $new_cat->errors['term_exists'] ) ) {

            // category already exists

          } elseif ( isset($new_cat['term_id']) && $new_cat['term_id'] ) {
            $new_cat_term_id = intval( $new_cat['term_id'] );
          }

        }

        $new_cats_term_ids = [];

        if (isset($_POST['_SF_NEW_CATEGORIES']) && $_POST['_SF_NEW_CATEGORIES']) {

          $new_cat_args = [];
          $new_cat_names = explode(',', sanitize_text_field( $_POST['_SF_NEW_CATEGORIES'] ));

          foreach ($new_cat_names as $new_cat_name) {
            $new_cat = wp_insert_term($new_cat_name, 'shared-file-category', $new_cat_args);

            if ( isset( $new_cat->errors['term_exists'] ) ) {

              // category already exists

            } elseif ( isset($new_cat['term_id']) && $new_cat['term_id'] ) {
              $new_cats_term_ids [] = intval( $new_cat['term_id'] );
            }

          }

        }

        $new_tags_term_ids = [];

        if (isset($_POST['_sf_new_tags']) && $_POST['_sf_new_tags']) {

          $new_tag_args = [];
          $tags = explode(',', sanitize_text_field( $_POST['_sf_new_tags'] ));

          foreach ($tags as $tag) {

            $tag_name = sanitize_text_field( $tag );
            $new_tag = wp_insert_term($tag_name, SHARED_FILES_TAG_SLUG, $new_tag_args);

            if ( isset( $new_tag->errors['term_exists'] ) ) {

              // tag already exists

            } elseif ( isset($new_tag['term_id']) && $new_tag['term_id'] ) {
              $new_tags_term_ids []= intval( $new_tag['term_id'] );
            }

          }

        }

        $goto_url = '';

        if ( isset( $s['file_upload_file_not_required'] ) ||
            (
              isset($_FILES['_sf_files']['name']) &&
              isset($_FILES['_sf_files']['tmp_name'][0]) &&
              $_FILES['_sf_files']['tmp_name'][0]
            )
           ) {

          $num = sizeof($_FILES['_sf_files']['name']);

          if ( !$num && isset( $s['file_upload_file_not_required'] ) ) {
            $num = 1;
          }

          for ($i = 0; $i < $num; $i++) {

            // SINGLE -> MULTIPLE START

            $post_status = isset($s['file_upload_set_to_pending']) && $s['file_upload_set_to_pending'] ? 'pending' : 'publish';

            $new_post = array( 'post_type'    => 'shared_file',
                               'post_status'  => $post_status,
                               'post_title'   => '',
                               'post_content' => '');

            $id = wp_insert_post($new_post);

            update_post_meta($id, '_sf_frontend_uploader', 1);

            update_post_meta($id, '_sf_embed_post_id', intval( $_POST['_sf_embed_post_id'] ));
            update_post_meta($id, '_sf_embed_post_title', sanitize_text_field( $_POST['_sf_embed_post_title'] ));

            if ( isset($_POST['_sf_upload_id']) && $_POST['_sf_upload_id'] ) {

              update_post_meta($id, '_sf_upload_id', sanitize_text_field( $_POST['_sf_upload_id'] ) );
              update_post_meta($id, '_sf_not_public', 1);

            } elseif (!isset($s['uncheck_hide_from_other_pages'])) {

              update_post_meta($id, '_sf_not_public', 1);

            } else {

              update_post_meta($id, '_sf_not_public', '');

            }

            if (shared_files_fs()->is__premium_only()) {
              if (shared_files_fs()->can_use_premium_code()) {

                update_post_meta($id, '_sf_password', isset($_POST['_sf_password']) ? sanitize_text_field( $_POST['_sf_password'] ) : '');

                $expiration_date = '';

                if (isset($_POST['_sf_expiration_date']) && $_POST['_sf_expiration_date']) {
                  $dt = DateTime::createFromFormat("Y-m-d", sanitize_text_field( $_POST['_sf_expiration_date'] ));

                  $errors = $dt::getLastErrors();

                  if ($dt !== false && !array_sum( (array) $errors )) {
                    $expiration_date = $dt;
                  }
                }

                update_post_meta($id, '_sf_expiration_date', $expiration_date);

                $custom_fields_cnt = 3 + 1;

                if (isset($s['custom_fields_cnt'])) {
                  $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
                } else {
                  $custom_fields_cnt = 5 + 1;
                }

                for ($n = 1; $n < $custom_fields_cnt; $n++) {

                  if (isset($_POST['_sf_file_upload_cf_' . $n]) && $_POST['_sf_file_upload_cf_' . $n]) {
                    update_post_meta($id, '_sf_file_upload_cf_' . $n, sanitize_text_field( $_POST['_sf_file_upload_cf_' . $n] ));
                  }

                }

                if (isset($_POST['shared-file-category'])) {
                  $cat_slug = $_POST['shared-file-category'];
                  $cat = get_term_by('slug', sanitize_title( $cat_slug ), 'shared-file-category');

                  if ($cat) {
                    wp_set_object_terms($id, intval( $cat->term_id ), 'shared-file-category');
                  }

                }

                if ($new_cat_term_id) {
                  wp_set_object_terms($id, intval( $new_cat_term_id ), 'shared-file-category', true);
                }

                if ($new_cats_term_ids) {

                  foreach ($new_cats_term_ids as $term_id) {
                    wp_set_object_terms($id, intval( $term_id ), 'shared-file-category', true);
                  }

                }

                if ($new_tags_term_ids) {

                  foreach ($new_tags_term_ids as $term_id) {
                    wp_set_object_terms($id, intval( $term_id ), SHARED_FILES_TAG_SLUG, true);
                  }

                }

                if (isset($_POST['tax_input']['shared-file-category']) && $cats = $_POST['tax_input']['shared-file-category']) {

                  if (is_array($cats)) {
                    wp_set_post_terms($id, $cats, 'shared-file-category');
                  }

                }

              }
            }

            if (isset($_POST[SHARED_FILES_TAG_SLUG])) {
              $cat_slug = sanitize_title( $_POST[SHARED_FILES_TAG_SLUG] );
              $cat = get_term_by('slug', sanitize_title( $cat_slug ), SHARED_FILES_TAG_SLUG);

              if ($cat) {
                wp_set_object_terms($id, intval( $cat->term_id ), SHARED_FILES_TAG_SLUG);
              }

            }

            if (isset($_POST['tax_input'][SHARED_FILES_TAG_SLUG]) && $tags = $_POST['tax_input'][SHARED_FILES_TAG_SLUG]) {

              $tags_int = array_map(
                function($value) { return (int) $value; },
                $tags
              );

              wp_set_post_terms($id, $tags_int, SHARED_FILES_TAG_SLUG);
            }

            if (is_user_logged_in()) {
              $user = wp_get_current_user();
              update_post_meta($id, '_sf_user_id', intval( $user->ID ));

              if ( isset($_POST['_sf_restrict_access']) && $_POST['_sf_restrict_access'] ) {
                update_post_meta($id, '_sf_permission_user_id', intval( $user->ID ));
              }

            }

            if (shared_files_fs()->is__premium_only()) {
              if (shared_files_fs()->can_use_premium_code()) {

                $permissions_updated = $this->update_permissions__premium_only($id);

              }
            }

            if (isset($_POST['_sf_description']) && $_POST['_sf_description']) {

              $description = wp_strip_all_tags( balanceTags(wp_kses_post($_POST['_sf_description']), 1) );

              if (!isset($s['textarea_for_file_description'])) {
                $description = nl2br( $description );
              }

              update_post_meta($id, '_sf_description', $description);

            } else {
              update_post_meta($id, '_sf_description', '');
            }

//            $filename = $_FILES['_sf_files']['name'][$i];

            $filename = '';

            $at_least_one_file_uploaded = 0;

            if (isset($_FILES['_sf_files']['tmp_name'][$i]) && $tmp_name = $_FILES['_sf_files']['tmp_name'][$i]) {

              // Get the file type of the upload
              $arr_file_type = wp_check_filetype(basename($_FILES['_sf_files']['name'][$i]));
              $uploaded_type = $arr_file_type['type'];

              $file_contents_sanitized = SharedFilesAdminAllowMoreFileTypes::sanitize_file( $tmp_name );

              add_filter('upload_dir', [ $this, 'set_upload_dir' ]);
              add_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );

              // Use the WordPress API to upload the file
              $upload = wp_upload_bits($_FILES['_sf_files']['name'][$i], null, $file_contents_sanitized);

              remove_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );
              remove_filter('upload_dir', [$this, 'set_upload_dir']);

              if (isset($upload['error']) && $upload['error']) {
                wp_die('There was an error uploading your file. The error is: ' . esc_html( $upload['error'] ) );
              }

              $at_least_one_file_uploaded = 1;

              add_post_meta($id, '_sf_file', $upload);
              update_post_meta($id, '_sf_file', $upload);

              $filename = substr(strrchr($upload['file'], "/"), 1);

              update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

              $sf_file_size = 0;
              $upload_file = '';

              if ( isset($_FILES['_sf_files']['size'][$i]) && $_FILES['_sf_files']['size'][$i] ) {
                $sf_file_size = sanitize_text_field( $_FILES['_sf_files']['size'][$i] );
              }

              if ( isset($upload['file']) && $upload['file'] ) {
                $upload_file = sanitize_text_field( $upload['file'] );
              }

              SharedFilesFileUpdate::uFilesize($id, $sf_file_size, $upload_file);

              $featured_image_already_added = 0;

              if (shared_files_fs()->is__premium_only()) {
                if (shared_files_fs()->can_use_premium_code()) {

                  if (isset($s['file_upload_allow_featured_image'])) {
                    if (isset($_FILES['_sf_featured_image']['tmp_name']) && $_FILES['_sf_featured_image']['tmp_name']) {

                      // Get the file type of the upload
                      $fi_arr_file_type = wp_check_filetype(basename($_FILES['_sf_featured_image']['name']));
                      $fi_uploaded_type = $fi_arr_file_type['type'];

                      // Use the WordPress API to upload the featured image
                      $fi_upload = wp_upload_bits($_FILES['_sf_featured_image']['name'], null, file_get_contents($_FILES['_sf_featured_image']['tmp_name']));

                      if (isset($fi_upload['error']) && $fi_upload['error']) {
                        wp_die('There was an error uploading your file. The error is: ' . $fi_upload['error']);
                      }

                      $fi_filename = substr(strrchr($fi_upload['file'], "/"), 1);

                      SharedFilesHelpers::addFeaturedImage($id, $fi_upload, $fi_uploaded_type, $fi_filename, 0);

                      $featured_image_already_added = 1;

                    }
                  }

                }
              }

              if (!$featured_image_already_added) {

                SharedFilesHelpers::addFeaturedImage($id, $upload, $uploaded_type, $filename, 1);

              }

            } elseif ( !isset( $s['file_upload_file_not_required'] ) ) {

              $error_msg = sanitize_text_field( __('File was not successfully uploaded. Please note the maximum file size.', 'shared_files') );
              wp_die($error_msg);

            }

            update_post_meta($id, '_sf_load_cnt', 0);
            update_post_meta($id, '_sf_bandwidth_usage', 0);
            update_post_meta($id, '_sf_file_added', current_time('Y-m-d H:i:s'));
            update_post_meta($id, '_sf_main_date', '');

            $post_title = $filename;

            if (isset($_POST['_sf_title']) && $_POST['_sf_title']) {
              $post_title = sanitize_text_field( $_POST['_sf_title'] );
            } elseif (!$at_least_one_file_uploaded && isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {
              $post_title = sanitize_text_field( __('External URL', 'shared-files') );
            }

            if (!$at_least_one_file_uploaded && isset($_POST['_sf_external_url']) && $_POST['_sf_external_url'] ) {
              $external_url = esc_url_raw($_POST['_sf_external_url']);
              update_post_meta($id, '_sf_external_url', $external_url);

              $filename = basename($external_url);
              update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));
            }

            $my_post = array(
              'ID'           => $id,
              'post_title'   => sanitize_text_field( $post_title ),
            );

            wp_update_post($my_post);

            do_action( 'shared_files_frontend_file_uploaded', $id );

            $goto_url = esc_url_raw( get_site_url() );

            if (isset($_POST['_SF_GOTO']) && $_POST['_SF_GOTO']) {
              $goto_url = esc_url_raw( $_POST['_SF_GOTO'] );
            }

            $container_url = $goto_url;

            if (shared_files_fs()->is__premium_only()) {
              if (shared_files_fs()->can_use_premium_code()) {

                SharedFilesAdminSendMail::file_upload_send_email__premium_only($id, get_post($id), $container_url);

              }
            }

            // SINGLE -> MULTIPLE END

          }

        } elseif (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {

          $post_status = isset($s['file_upload_set_to_pending']) && $s['file_upload_set_to_pending'] ? 'pending' : 'publish';

          $new_post = array( 'post_type'    => 'shared_file',
                             'post_status'  => $post_status,
                             'post_title'   => '',
                             'post_content' => '');

          $id = wp_insert_post($new_post);

          update_post_meta($id, '_sf_frontend_uploader', 1);

          update_post_meta($id, '_sf_embed_post_id', intval( $_POST['_sf_embed_post_id'] ));
          update_post_meta($id, '_sf_embed_post_title', sanitize_text_field( $_POST['_sf_embed_post_title'] ));

          if ( isset($_POST['_sf_upload_id']) && $_POST['_sf_upload_id'] ) {

            update_post_meta($id, '_sf_upload_id', sanitize_text_field( $_POST['_sf_upload_id'] ) );
            update_post_meta($id, '_sf_not_public', 1);

          } elseif (!isset($s['uncheck_hide_from_other_pages'])) {

            update_post_meta($id, '_sf_not_public', 1);

          } else {

            update_post_meta($id, '_sf_not_public', '');

          }

          if (shared_files_fs()->is__premium_only()) {
            if (shared_files_fs()->can_use_premium_code()) {

              update_post_meta($id, '_sf_password', isset($_POST['_sf_password']) ? sanitize_text_field( $_POST['_sf_password'] ) : '');

              $expiration_date = '';

              if (isset($_POST['_sf_expiration_date']) && $_POST['_sf_expiration_date']) {
                $dt = DateTime::createFromFormat("Y-m-d", sanitize_text_field( $_POST['_sf_expiration_date'] ));

                $errors = $dt::getLastErrors();

                if ($dt !== false && !array_sum( (array) $errors )) {
                  $expiration_date = $dt;
                }
              }

              update_post_meta($id, '_sf_expiration_date', $expiration_date);

              $custom_fields_cnt = 3 + 1;

              if (isset($s['custom_fields_cnt'])) {
                $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
              } else {
                $custom_fields_cnt = 5 + 1;
              }

              for ($n = 1; $n < $custom_fields_cnt; $n++) {

                if (isset($_POST['_sf_file_upload_cf_' . $n]) && $_POST['_sf_file_upload_cf_' . $n]) {
                  update_post_meta($id, '_sf_file_upload_cf_' . $n, sanitize_text_field( $_POST['_sf_file_upload_cf_' . $n] ));
                }

              }

              if (isset($_POST['shared-file-category'])) {
                $cat_slug = $_POST['shared-file-category'];
                $cat = get_term_by('slug', sanitize_title( $cat_slug ), 'shared-file-category');

                if ($cat) {
                  wp_set_object_terms($id, intval( $cat->term_id ), 'shared-file-category');
                }

              }

              if ($new_cat_term_id) {
                wp_set_object_terms($id, intval( $new_cat_term_id ), 'shared-file-category', true);
              }

              if ($new_cats_term_ids) {

                foreach ($new_cats_term_ids as $term_id) {
                  wp_set_object_terms($id, intval( $term_id ), 'shared-file-category', true);
                }

              }

              if ($new_tags_term_ids) {

                foreach ($new_tags_term_ids as $term_id) {
                  wp_set_object_terms($id, intval( $term_id ), SHARED_FILES_TAG_SLUG, true);
                }

              }

              if (isset($_POST['tax_input']['shared-file-category']) && $cats = $_POST['tax_input']['shared-file-category']) {

                if (is_array($cats)) {
                  wp_set_post_terms($id, $cats, 'shared-file-category');
                }

              }

            }
          }

          if (isset($_POST[SHARED_FILES_TAG_SLUG])) {
            $cat_slug = sanitize_title( $_POST[SHARED_FILES_TAG_SLUG] );
            $cat = get_term_by('slug', sanitize_title( $cat_slug ), SHARED_FILES_TAG_SLUG);

            if ($cat) {
              wp_set_object_terms($id, intval( $cat->term_id ), SHARED_FILES_TAG_SLUG);
            }

          }

          if (isset($_POST['tax_input'][SHARED_FILES_TAG_SLUG]) && $tags = $_POST['tax_input'][SHARED_FILES_TAG_SLUG]) {

            $tags_int = array_map(
              function($value) { return (int) $value; },
              $tags
            );

            wp_set_post_terms($id, $tags_int, SHARED_FILES_TAG_SLUG);
          }

          if (is_user_logged_in()) {
            $user = wp_get_current_user();
            update_post_meta($id, '_sf_user_id', intval( $user->ID ));

            if ( isset($_POST['_sf_restrict_access']) && $_POST['_sf_restrict_access'] ) {
              update_post_meta($id, '_sf_permission_user_id', intval( $user->ID ));
            }

          }

          if (shared_files_fs()->is__premium_only()) {
            if (shared_files_fs()->can_use_premium_code()) {

              $permissions_updated = $this->update_permissions__premium_only($id);

            }
          }

          if (isset($_POST['_sf_description']) && $_POST['_sf_description']) {

            $description = wp_strip_all_tags( balanceTags(wp_kses_post($_POST['_sf_description']), 1) );

            if (!isset($s['textarea_for_file_description'])) {
              $description = nl2br( $description );
            }

            update_post_meta($id, '_sf_description', $description);

          } else {
            update_post_meta($id, '_sf_description', '');
          }


          $external_url = esc_url_raw($_POST['_sf_external_url']);
          update_post_meta($id, '_sf_external_url', $external_url);

          $filename = basename($external_url);
          update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

          update_post_meta($id, '_sf_load_cnt', 0);
          update_post_meta($id, '_sf_bandwidth_usage', 0);
          update_post_meta($id, '_sf_file_added', current_time('Y-m-d H:i:s'));
          update_post_meta($id, '_sf_main_date', '');

          $post_title = $filename;

          if (isset($_POST['_sf_title']) && $_POST['_sf_title']) {
            $post_title = sanitize_text_field( $_POST['_sf_title'] );
          } elseif (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {
            $post_title = sanitize_text_field( __('External URL', 'shared-files') );
          }

          $my_post = array(
            'ID'           => $id,
            'post_title'   => sanitize_text_field( $post_title ),
          );

          wp_update_post($my_post);

          do_action( 'shared_files_frontend_file_uploaded', $id );

          $goto_url = esc_url_raw( get_site_url() );

          if (isset($_POST['_SF_GOTO']) && $_POST['_SF_GOTO']) {
            $goto_url = esc_url_raw( $_POST['_SF_GOTO'] );
          }

          $container_url = $goto_url;

          if (shared_files_fs()->is__premium_only()) {
            if (shared_files_fs()->can_use_premium_code()) {

              SharedFilesAdminSendMail::file_upload_send_email__premium_only($id, get_post($id), $container_url);

            }
          }

        }

        wp_redirect($goto_url . '?shared-files-upload=1');
        exit;

      }

    }

    return $request;
  }


  public function file_update__premium_only($request) {

    $s = get_option('shared_files_settings');

    if (isset($_GET) && isset($_GET['_sf_delete_editable_file'])) {

      $user = wp_get_current_user();

      $sc = '';

      if ( isset($_GET['sc']) ) {
        $sc = sanitize_text_field( $_GET['sc'] );
      }

      if (!$sc || !wp_verify_nonce($sc, '_sf_delete_editable_file_' . intval( $user->ID ))) {
        wp_die('Error in processing form data.');
      }

      $file_id = (int) $_GET['_sf_delete_editable_file'];
      $file = get_post($file_id);
      $post_type = get_post_type($file_id);

      $can_edit_files = 0;

      if (!is_user_logged_in()) {
        wp_die('Insufficient permissions.');
      }

      $user = wp_get_current_user();
      $roles = (array) $user->roles;

      foreach ($roles as $role) {

        $setting = 'can_edit_files_' . $role;

        if (isset($s[$setting])) {
          $can_edit_files = 1;
        }

      }

      if (!$can_edit_files) {
        wp_die('Insufficient permissions.');
      }

      if ($file && $file_id && $post_type == 'shared_file') {
        wp_trash_post($file_id);
      }

    }

    if (isset($_POST) && isset($_POST['shared-files-update-file']) && isset($_POST['_sf_file_id'])) {

      $can_edit_files = 0;

      if (!is_user_logged_in()) {
        wp_die('Insufficient permissions.');
      }

      $user = wp_get_current_user();
      $roles = (array) $user->roles;

      foreach ($roles as $role) {

        $setting = 'can_edit_files_' . $role;

        if (isset($s[$setting])) {
          $can_edit_files = 1;
        }

      }

      if (!$can_edit_files) {
        wp_die('Insufficient permissions.');
      }

      $secret_code = '';

      if ( isset($_POST['secret_code']) ) {
        $secret_code = sanitize_text_field( $_POST['secret_code'] );
      }

      if (!$secret_code || !wp_verify_nonce($secret_code, 'sf_update_file')) {
        wp_die('Error in processing form data.');
      }

      $id = intval( $_POST['_sf_file_id'] );

      if (isset($_POST['tax_input']['shared-file-category']) && $cats = $_POST['tax_input']['shared-file-category']) {

        if (is_array($cats)) {
          wp_set_post_terms($id, $cats, 'shared-file-category');
        }

      }

      if (isset($_POST['_SF_NEW_CATEGORIES']) && $_POST['_SF_NEW_CATEGORIES']) {

        $new_cat_args = [];
        $new_cat_names = explode(',', sanitize_text_field( $_POST['_SF_NEW_CATEGORIES'] ));

        foreach ($new_cat_names as $new_cat_name) {
          $new_cat = wp_insert_term($new_cat_name, 'shared-file-category', $new_cat_args);

          if (isset($new_cat['term_id']) && $term_id = intval( $new_cat['term_id'] ) ) {
            wp_set_object_terms($id, intval( $term_id ), 'shared-file-category', true);
          }

        }

      }

      if (isset($_POST['tax_input'][SHARED_FILES_TAG_SLUG]) && $tags = $_POST['tax_input'][SHARED_FILES_TAG_SLUG]) {

        $tags_int = array_map(
          function($value) { return (int) $value; },
          $tags
        );

        wp_set_post_terms($id, $tags_int, SHARED_FILES_TAG_SLUG);
      }

      if (isset($_POST['_SF_NEW_TAGS']) && $_POST['_SF_NEW_TAGS']) {

        $new_tag_args = [];
        $new_tag_names = explode(',', sanitize_text_field( $_POST['_SF_NEW_TAGS'] ));

        foreach ($new_tag_names as $new_tag_name) {
          $new_tag = wp_insert_term($new_tag_name, SHARED_FILES_TAG_SLUG, $new_tag_args);

          if (isset($new_tag['term_id']) && $term_id = intval( $new_tag['term_id'] )) {
            wp_set_object_terms($id, intval( $term_id ), SHARED_FILES_TAG_SLUG, true);
          }

        }

      }

      if (is_user_logged_in()) {
        $user = wp_get_current_user();
        update_post_meta($id, '_sf_user_id', intval( $user->ID ));
      }

      if (isset($_FILES['_sf_file']['name']) && $tmp_name = $_FILES['_sf_file']['tmp_name']) {

        // Get the file type of the upload
        $arr_file_type = wp_check_filetype(basename($_FILES['_sf_file']['name']));
        $uploaded_type = $arr_file_type['type'];

        $file_contents_sanitized = SharedFilesAdminAllowMoreFileTypes::sanitize_file( $tmp_name );

        add_filter('upload_dir', [ $this, 'set_upload_dir' ]);
        add_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );

        // Use the WordPress API to upload the file
        $upload = wp_upload_bits($_FILES['_sf_file']['name'], null, $file_contents_sanitized);

        if (isset($upload['error']) && $upload['error']) {
          wp_die('There was an error uploading your file. The error is: ' . $upload['error']);
        }

        remove_filter('upload_mimes', [ 'SharedFilesAdminAllowMoreFileTypes', 'add_file_types' ] );
        remove_filter('upload_dir', [$this, 'set_upload_dir']);

        add_post_meta($id, '_sf_file', $upload);
        update_post_meta($id, '_sf_file', $upload);

        $filename = substr(strrchr($upload['file'], "/"), 1);

        update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

        $sf_file_size = 0;
        $upload_file = '';

        if ( isset($_FILES['_sf_file']['size']) && $_FILES['_sf_file']['size'] ) {
          $sf_file_size = sanitize_text_field( $_FILES['_sf_file']['size'] );
        }

        if ( isset($upload['file']) && $upload['file'] ) {
          $upload_file = sanitize_text_field( $upload['file'] );
        }

        SharedFilesFileUpdate::uFilesize($id, $sf_file_size, $upload_file);

        SharedFilesHelpers::addFeaturedImage($id, $upload, $uploaded_type, $filename, 1);

        update_post_meta($id, '_sf_file_added', current_time('Y-m-d H:i:s'));

      }

      if (isset($_POST['_sf_description']) && $_POST['_sf_description']) {

        $description = balanceTags(wp_kses_post($_POST['_sf_description']), 1);
        update_post_meta($id, '_sf_description', $description);

      } else {

        update_post_meta($id, '_sf_description', '');

      }

      if (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url']) {

        $external_url = esc_url_raw($_POST['_sf_external_url']);
        update_post_meta($id, '_sf_external_url', $external_url);

        $filename = basename($external_url);
        update_post_meta($id, '_sf_filename', sanitize_text_field( $filename ));

      } elseif (isset($_POST['_sf_external_url']) && $_POST['_sf_external_url'] == '') {

        update_post_meta($id, '_sf_external_url', '');

      }

      if (isset($_POST['_sf_title']) && $_POST['_sf_title']) {
        $post_title = sanitize_text_field( $_POST['_sf_title'] );

        $my_post = array(
          'ID'           => $id,
          'post_title'   => sanitize_text_field( $post_title ),
        );

        wp_update_post($my_post);

      }

      $goto_url = get_site_url();

      if (isset($_POST['_SF_GOTO']) && $_POST['_SF_GOTO']) {
        $goto_url = esc_url( $_POST['_SF_GOTO'] );
      }

      /*
      if (isset($s['file_upload_send_email']) && is_email($s['file_upload_send_email'])) {
        $container_url = $goto_url;
        SharedFilesAdminSendMail::file_upload_send_email__premium_only($id, get_post($id), $container_url);
      }
      */

      if (strpos($goto_url, 'shared-files-update') !== false) {

        wp_redirect($goto_url);

      } elseif (strpos($goto_url, '?') !== false){

        $goto_url .= '&shared-files-update=1';
        wp_redirect($goto_url);

      } else {

        $goto_url .= '?shared-files-update=1';
        wp_redirect($goto_url);

      }

      exit;

    }

    return $request;
  }

  /**
   * Set the custom upload directory.
   *
   * @since    1.0.0
   */
  public function set_upload_dir($dir) {

    $s = get_option('shared_files_settings');

    $folder_for_new_files = '';

    if (isset($s['folder_for_new_files']) && $s['folder_for_new_files']) {
      $folder_for_new_files = '/' . sanitize_file_name($s['folder_for_new_files']);

      $full_path_new = realpath( $dir['basedir'] ) . '/shared-files' . $folder_for_new_files;

      if (!file_exists($full_path_new)) {
        mkdir($full_path_new);
      }
    }

    return array(
      'path'   => realpath( $dir['basedir'] ) . '/shared-files' . $folder_for_new_files,
      'url'    => $dir['baseurl'] . '/shared-files' . $folder_for_new_files,
      'subdir' => '/shared-files' . $folder_for_new_files,
    ) + $dir;
  }

  public function update_permissions__premium_only($file_id) {

    $s = get_option('shared_files_settings');

    $updated = 0;

    if ( is_user_logged_in() ) {

      $make_not_public = 0;

      /* RESTRICT USER START */

      if ( isset( $s['file_upload_enable_restrict_access_for_users'] ) ) {

        if ( isset($_POST['_sf_permission_user_id']) && $_POST['_sf_permission_user_id'] ) {

          $sf_permission_user_id = (array) $_POST['_sf_permission_user_id'];
          $sf_permission_user_id = array_map( 'intval', $sf_permission_user_id );

          update_post_meta($file_id, '_sf_permission_user_id', implode( ',', $sf_permission_user_id ));

          $make_not_public = 1;
          $updated = 1;

        } else {
          update_post_meta($file_id, '_sf_permission_user_id', 0 );
        }

      }

      /* RESTRICT USER END */

      /* RESTRICT ROLE START */

      if ( isset( $s['file_upload_enable_restrict_access_for_roles'] ) ) {

        global $wp_roles;

        $roles = $wp_roles->get_names();

        foreach ($roles as $key => $value) {

          if ($key && $value) {

            $role_field = '_sf_permission_user_role_' . $key;

            if ( isset($_POST[$role_field]) && $_POST[$role_field] ) {

              update_post_meta($file_id, $role_field, 1);
              $make_not_public = 1;
              $updated = 1;

            } else {

              update_post_meta($file_id, $role_field, 0);

            }

          }

        }

        $updated = 1;

      }

      /* RESTRICT ROLE END */

      if ($make_not_public) {
        update_post_meta($file_id, '_sf_not_public', $make_not_public);
      }

    }

    return $updated;

  }

}
