<?php

class SharedFilesShortcodeFilters {

  public static function getFilters( $className, $atts ) {

    if ( !class_exists($className) || !method_exists($className, 'setMetaQuery') || !method_exists($className, 'addToMetaQuery') ) {
      wp_die( 'Error in ' . $className );
    }

    $s = get_option('shared_files_settings');

    $custom_fields_active = 0;

    $meta_query_hide_not_public = [];

    $html = '';

    $is_premium = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $is_premium = 1;

        $html .= '<input type="hidden" name="atts" value=\'' . json_encode($atts) . '\' />';

        if (wp_count_terms('shared-file-category') > 1) {

          $exclude_cat = [];

          if (isset($atts['exclude_cat'])) {
            $terms = explode(',', $atts['exclude_cat']);

            foreach ($terms as $term_slug) {
              $term = get_term_by('slug', $term_slug, 'shared-file-category');
              $exclude_cat []= intval( $term->term_id );
            }

          }

          if (isset($atts['category']) && $atts['category']) {

            $cat = get_term_by('slug', sanitize_title( $atts['category'] ), 'shared-file-category');

            if (!$cat) {
              $html = '<div class="sf_error">' . esc_html__('Category not found:', 'shared-files') . ' ' . esc_html( $atts['category'] ) . '</div>';
              return $html;
            }

            if ($cat) {
              $terms = get_terms(array(
                'taxonomy'    => 'shared-file-category',
                'hide_empty'  => true,
                'parent'      => intval( $cat->term_id ),
                'exclude'     => $exclude_cat
              ));
            }

            if (isset($terms) && !isset($atts['hide_category_dropdown']) && !isset($s['hide_category_dropdown']) && sizeof($terms) > 0) {

              $html .= '<div class="shared-files-category-select-container">';

              $html .= '<select name="sf_category" class="shared-files-category-select select_v2">';

              $html .= '<option value="0">' . esc_html__('Choose category', 'shared-files') . '</option>';

              foreach ($terms as $term) {
                $html .= '<option value="' . sanitize_title( $term->slug ) . '" ' . (isset($_GET['c'] ) && $_GET['c'] == $term->slug ? 'selected' : '') . '>'. esc_html( $term->name ) .'</option>';
              }

              $html .= '</select>';

              $html .= '</div>';

            } else {

              $html .= '<input type="hidden" name="sf_category" value="' . esc_attr( $atts['category'] ) . '" />';

            }


          } elseif (!isset($atts['only_uploaded_files']) && !isset($atts['hide_category_dropdown']) && !isset($s['hide_category_dropdown'])) {

            $cat_selected = isset($_GET['sf_category']) ? sanitize_title( $_GET['sf_category'] ) : 0;

            $categories_orderby = '';
            $categories_order = 'ASC';

            if (isset($s['sort_categories_by']) && $s['sort_categories_by']) {
              $categories_orderby = sanitize_title( $s['sort_categories_by'] );
            }

            $args = array(
                      'taxonomy'        => 'shared-file-category',
                      'name'            => 'sf_category',
                      'show_option_all' => esc_attr__('Choose category', 'shared-files'),
                      'hierarchical'    => true,
                      'class'           => 'shared-files-category-select select_v2',
                      'echo'            => false,
                      'value_field'     => 'slug',
                      'exclude'         => $exclude_cat,
                      'selected'        => $cat_selected,

                      'orderby'         => $categories_orderby,
                      'order'           => $categories_order,

                    );

            $html .= '<div class="shared-files-category-select-container">';
            $html .= wp_dropdown_categories($args);
            $html .= '</div>';

          }

        }

      }
    }

    if (isset($s['show_tag_dropdown']) || isset($atts['show_tag_dropdown'])) {

      $tag_selected = isset($_GET['sf_tag']) ? sanitize_title( $_GET['sf_tag'] ) : '';

      $tags_orderby = '';
      $tags_order = 'ASC';

      if (isset($s['sort_tags_by']) && $s['sort_tags_by']) {
        $tags_orderby = sanitize_title( $s['sort_tags_by'] );
      }

      $tag_args = array(
                'taxonomy'          => SHARED_FILES_TAG_SLUG,
                'name'              => 'sf_tag',
                'show_option_none'   => esc_attr__('Choose tag', 'shared-files'),
                'hierarchical'      => true,
                'class'             => 'shared-files-tag-select select_v2',
                'echo'              => false,
                'value_field'       => 'slug',
                'selected'          => $tag_selected,
                'option_none_value' => '',

                'orderby'           => $tags_orderby,
                'order'             => $tags_order,

              );

      $html .= '<div class="shared-files-tag-select-container">';
      $html .= wp_dropdown_categories($tag_args);
      $html .= '</div>';

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $is_premium = 1;

        $custom_fields_cnt = 0;

        if (isset($s['custom_fields_cnt'])) {
          $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
        } else {
          $custom_fields_cnt = 5 + 1;
        }

        $custom_fields_search_filters_active = 0;

        for ($n = 1; $n < $custom_fields_cnt; $n++) {

          if (isset($s['cf_' . $n . '_use_as_search_filter']) && $s['cf_' . $n . '_use_as_search_filter']) {
            $custom_fields_search_filters_active = 1;
          }

        }

        if ($custom_fields_search_filters_active) {

          $tax_query = ['relation' => 'AND'];

          if (isset($atts['categories__and']) && $atts['categories__and']) {

            $cat_slugs_and = explode(',', $atts['categories__and']);

            $tax_query []= array(
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $cat_slugs_and,
              'operator'          => 'AND',
              'include_children'  => false
            );

          } elseif (isset($atts['exclude_cat'])) {

            $terms = explode(',', $atts['exclude_cat']);

            $tax_query []= [
              'taxonomy'  => 'shared-file-category',
              'terms'     => $terms,
              'field'     => 'slug',
              'operator'  => 'NOT IN'
            ];

          }

          if (isset($atts['categories__or']) && $atts['categories__or']) {

            $cat_slugs_or = explode(',', $atts['categories__or']);

            $tax_query []= array(
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $cat_slugs_or,
              'operator'          => 'IN',
              'include_children'  => false
            );

          }

          if (isset($atts['tags__and']) && $atts['tags__and']) {

            $tag_slugs_and = explode(',', $atts['tags__and']);

            $tax_query []= array(
              'taxonomy'          => SHARED_FILES_TAG_SLUG,
              'field'             => 'slug',
              'terms'             => $tag_slugs_and,
              'operator'          => 'AND',
              'include_children'  => false
            );

          }

          if (isset($atts['tags__or']) && $atts['tags__or']) {

            $tag_slugs_or = explode(',', $atts['tags__or']);

            $tax_query []= array(
              'taxonomy'          => SHARED_FILES_TAG_SLUG,
              'field'             => 'slug',
              'terms'             => $tag_slugs_or,
              'operator'          => 'IN',
              'include_children'  => false
            );

          }

          $wp_query_for_filter = new WP_Query(array(

            'post_type'       => 'shared_file',
            'post_status'     => 'publish',
            'posts_per_page'  => -1,

            'orderby'     => SharedFilesHelpers::getOrderBy($atts),
            'order'       => SharedFilesHelpers::getOrder($atts),
            'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

            'tax_query'   => $tax_query,

            'meta_query'  => $meta_query_hide_not_public,

          ));

          $meta_query = array('relation' => 'AND');

          for ($n = 1; $n < $custom_fields_cnt; $n++) {

            if (isset($s['cf_' . $n . '_use_as_search_filter']) && $s['cf_' . $n . '_use_as_search_filter']) {

              $field_name = 'cf_' . $n;

              if (isset($_GET[$field_name]) && $_GET[$field_name]) {

                $meta_query[] = array(
                  'key'		  => '_sf_file_upload_cf_' . $n,
                  'value'		=> sanitize_text_field( $_GET[$field_name] ),
                  'compare'	=> 'LIKE'
                );

              }

              $values = [];

              while ($wp_query_for_filter->have_posts()): $wp_query_for_filter->the_post();

                $id = intval( get_the_id() );
                $c = get_post_custom($id);

                if (isset($c['_sf_file_upload_cf_' . $n][0]) && $c['_sf_file_upload_cf_' . $n][0] && !in_array($c['_sf_file_upload_cf_' . $n][0], $values)) {
                  $values []= sanitize_text_field( $c['_sf_file_upload_cf_' . $n][0] );
                }

              endwhile;

              if (isset($values) && is_array($values)) {
                sort($values);
              }

              $field_name = 'cf_' . $n;

              $select_title = sanitize_text_field( __('Custom field', 'shared-files') ) . ' ' . $n;

              if (isset($s['cf_' . $n . '_select_title']) && $s['cf_' . $n . '_select_title']) {

                $select_title = sanitize_text_field( $s['cf_' . $n . '_select_title'] );

              } elseif (isset($s['file_upload_custom_field_' . $n]) && $s['file_upload_custom_field_' . $n]) {

                $select_title = sanitize_text_field( $s['file_upload_custom_field_' . $n] );

              }

              $html .= '<div class="shared-files-custom-field-select-container">';

              $html .= '<select name="' . esc_attr( $field_name ) . '" class="shared-files-custom-field-select select_v2" data-select-value="' . $select_title . '" data-current-value="' . (isset($_GET[$field_name]) ? esc_attr( $_GET[$field_name] ) : '') . '">';

              $html .= '<option value="">' . $select_title . '</option>';

              if (isset($values) && is_array($values)) {

                foreach ($values as $val) {
                  $html .= '<option value="' . esc_attr( $val ) . '" ' . (isset($_GET[$field_name]) && $_GET[$field_name] == $val ? 'selected="selected"' : '') . '>' . sanitize_text_field( $val ) . '</option>';
                }

              }

              $html .= '</select>';

              $html .= '</div>';

              $custom_fields_active = 1;

            }

          }

        }

        $html .= '<hr class="clear" />';

      }
    }

    if ($custom_fields_active) {

      $className::setMetaQuery( array('relation' => 'AND') );
      $className::addToMetaQuery( $meta_query_hide_not_public );
      $className::addToMetaQuery( $meta_query );

    } else {

      $className::setMetaQuery( $meta_query_hide_not_public );

    }

    return $html;

  }

}
