<?php

class ShortcodeSharedFiles {

  /**
   * Search view embeddable via shortcode.
   *
   * @since    1.0.0
   */
  public static function shared_files($atts = [], $content = null, $tag = '') {

    $html = '';

    $post_id = intval( get_the_id() );

    // normalize attribute keys, lowercase
    $atts = array_change_key_case( (array) $atts, CASE_LOWER);
    $s = get_option('shared_files_settings');

    $elem_class = SharedFilesHelpers::createElemClass();

    $meta_query = [];
    $meta_query_full = [];
    $custom_fields_active = 0;

    $embed_id = isset($atts['embed_id']) ? sanitize_title($atts['embed_id']) : 'default';

    $include_children = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if ( isset( $s['and_or_include_children'] ) ) {
          $include_children = 1;
        }

      }
    }

    if ( ( isset($atts['ask_for_email']) && $atts['ask_for_email'] == 1 ) || ( isset($atts['ask_for_contact_info']) && $atts['ask_for_contact_info'] == 1 ) ) {

      if ( is_super_admin() ) {

        $html .= SharedFilesPublicContacts::askForEmailInfo();

      } else {

        if ( isset($_POST['shared-files-add-contact']) ) {

          SharedFilesPublicContacts::saveEmail($embed_id, $atts);

        } else {

          $html = SharedFilesPublicContacts::askForEmail($embed_id, $atts);
          return $html;

        }

      }

    }

    $pagination_active = 0;

    if (isset($_GET['_paged']) && $_GET['_paged'] == $embed_id) {
      $pagination_active = 1;
    }

    $tag_slug = '';

    if (isset($_GET['sf_tag']) && $_GET['sf_tag'] != '0') {
      $tag_slug = sanitize_title( $_GET['sf_tag'] );
    }

    $limit_posts = 0;

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        if (isset($atts['limit'])) {
          $limit_posts = (int) $atts['limit'];
        }

      }
    }

    $meta_query_hide_not_public = array('relation' => 'OR');

    $meta_query_hide_not_public[] = array(
			'key'		  => '_sf_not_public',
			'compare'	=> '=',
			'value'   => ''
		);

    $meta_query_hide_not_public[] = array(
			'key'		  => '_sf_not_public',
			'compare'	=> 'NOT EXISTS',
		);

//    $meta_query_hide_not_public = array();

    $html .= '<div class="' . $elem_class . ' shared-files-main-container" data-elem-class="' . $elem_class . '">';

    if (isset($_GET) && isset($_GET['shared-files-update'])) {
      $html .= '<div class="shared-files-upload-complete">' . sanitize_text_field( __('File successfully updated.', 'shared-files') ) . '</div>';
    } elseif (isset($_GET) && isset($_GET['_sf_delete_editable_file']) && isset($_GET['sc'])) {
      $html .= '<div class="shared-files-file-deleted">' . sanitize_text_field( __('File successfully deleted.', 'shared-files') ) . '</div>';
    }

    if ( isset( $atts['file_upload'] ) ) {

      if ( isset( $atts['only_uploaded_files'] ) ) {

        $meta_query_hide_not_public = array('relation' => 'AND');

        $meta_query_hide_not_public[] = array(
    			'key'		  => '_sf_embed_post_id',
    			'compare'	=> '=',
    			'value'   => $post_id
    		);

        $meta_query_hide_not_public[] = array(
    			'key'		  => '_sf_not_public',
    			'compare' => 'EXISTS'
    		);

      } else {

        $meta_query_hide_not_public = array('relation' => 'OR');

        $meta_query_hide_not_public[] = array(
    			'key'		  => '_sf_embed_post_id',
    			'compare'	=> '=',
    			'value'   => $post_id
    		);

        $meta_query_hide_not_public[] = array(
    			'key'		  => '_sf_not_public',
    			'compare'	=> '=',
    			'value'   => ''
    		);

        $meta_query_hide_not_public[] = array(
    			'key'		  => '_sf_not_public',
    			'compare' => 'NOT EXISTS'
    		);

      }

      if ( is_user_logged_in() || !isset( $s['only_logged_in_users_can_add_files'] ) ) {

        $html .= SharedFilesFileUpload::fileUploadMarkup( $atts );

      }

    }

    if (isset($atts['file_id'])) {

      $file_id = (int) $atts['file_id'];

      $wpb_all_query = new WP_Query(array(
        'post_type'       => 'shared_file',
        'post_status'     => 'publish',
        'posts_per_page'  => -1,
        'p'               => $file_id
      ));

      $filetypes = SharedFilesHelpers::getFiletypes();
      $external_filetypes = SharedFilesHelpers::getExternalFiletypes();

      $extra_class = '';

      if ( isset($atts['layout']) && $atts['layout'] == 'minimal' ) {
        $extra_class = ' shared-files-minimal';
      }

      $html .= '<div class="shared-files-search">';
      $html .= '<ul class="shared-files-main-file-list' . $extra_class . '">';

      if ($wpb_all_query->have_posts()):
        while ($wpb_all_query->have_posts()): $wpb_all_query->the_post();

          $id = get_the_id();
          $c = get_post_custom($id);

          $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
          $filetype = '';

          $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);
          $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

          if ( isset($atts['layout']) && $atts['layout'] == 'minimal' ) {
            $html .= SharedFilesPublicFileCardMinimal::fileListItem($c, $imagefile, $hide_description, 2, $atts);
          } else {
            $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 2, $atts);
          }

        endwhile;

        wp_reset_postdata();

      else:
        $html .= '<div class="sf_error">' . esc_html__('File not found', 'shared-files') . '</div>';
      endif;

      $html .= '</ul>';

      $html .= '</div>';

      // .shared-files-main-container
      $html .= '</div>';

      return $html;

    } elseif (isset($atts['hide_file_list'])) {

      // .shared-files-main-container
      $html .= '</div>';

      return $html;

    } else {

      $layout = SharedFilesHelpers::getLayout($s, $atts);

      $type = 'basic';

      if (isset($atts['category'])) {
        $type = 'category';
      }

      $container_embed_id = '';

      if ($embed_id == 'default') {

        $container_embed_id = 'id="' . esc_attr( 'shared-files-default' ) . '"';

      } elseif ($embed_id) {

        $container_embed_id = 'id="' . esc_attr( $embed_id ) . '"';

      }

      $html .= '<div ' . $container_embed_id . ' class="shared-files-container shared-files-type-' . $type . ' ' . ($layout ? 'shared-files-' . esc_attr($layout) : '') . '">';
      $html .= '<div class="shared-files-search">';

      if (!isset($s['hide_search_form']) && !isset($atts['hide_search'])) {

        $html .= '<div class="shared-files-search-form-container"><form class="shared-files-ajax-form" onsubmit="return false;" data-elem-class="' . $elem_class . '">';

        if (!isset($atts['hide_search_for_all_files'])) {

          $extra_class = '';

          if (shared_files_fs()->is__premium_only()) {
            if (shared_files_fs()->can_use_premium_code()) {

              if (isset($s['search_input_targets_active_files'])) {
                $extra_class = ' shared-files-search-files-active-only';
              }

            }
          }

          $html .= '<div class="shared-files-search-input-container"><input type="text"  class="shared-files-search-files-input shared-files-search-files' . $extra_class . '" placeholder="' . esc_attr__('Search files...', 'shared-files') . '" value="" data-elem-class="' . $elem_class . '" /></div>';
        }

        $is_premium = 0;

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $is_premium = 1;

            $html .= '<input type="hidden" name="atts" value=\'' . json_encode($atts) . '\' />';

            if (wp_count_terms('shared-file-category') > 1) {

              $exclude_cat = [];

              if (isset($atts['exclude_cat'])) {
                $terms = explode(',', $atts['exclude_cat']);

                foreach ($terms as $term_slug) {
                  $term = get_term_by('slug', $term_slug, 'shared-file-category');
                  $exclude_cat []= intval( $term->term_id );
                }

              }

              if (isset($atts['category']) && $atts['category']) {

                $cat = get_term_by('slug', sanitize_title( $atts['category'] ), 'shared-file-category');

                if (!$cat) {
                  $html = '<div class="sf_error">' . esc_html__('Category not found:', 'shared-files') . ' ' . esc_html( $atts['category'] ) . '</div>';
                  return $html;
                }

                if ($cat) {
                  $terms = get_terms(array(
                    'taxonomy'    => 'shared-file-category',
                    'hide_empty'  => true,
                    'parent'      => intval( $cat->term_id ),
                    'exclude'     => $exclude_cat
                  ));
                }

                if (isset($terms) && !isset($atts['hide_category_dropdown']) && !isset($s['hide_category_dropdown']) && sizeof($terms) > 0) {

                  $html .= '<div class="shared-files-category-select-container">';

                  $html .= '<select name="sf_category" class="shared-files-category-select select_v2">';

                  $html .= '<option value="0">' . esc_html__('Choose category', 'shared-files') . '</option>';

                  foreach ($terms as $term) {
                    $html .= '<option value="' . sanitize_title( $term->slug ) . '" ' . (isset($_GET['c'] ) && $_GET['c'] == $term->slug ? 'selected' : '') . '>'. esc_html( $term->name ) .'</option>';
                  }

                  $html .= '</select>';

                  $html .= '</div>';

                } else {

                  $html .= '<input type="hidden" name="sf_category" value="' . esc_attr( $atts['category'] ) . '" />';

                }


              } elseif (!isset($atts['only_uploaded_files']) && !isset($atts['hide_category_dropdown']) && !isset($s['hide_category_dropdown'])) {

                $cat_selected = isset($_GET['sf_category']) ? sanitize_title( $_GET['sf_category'] ) : 0;

                $categories_orderby = '';
                $categories_order = 'ASC';

                if (isset($s['sort_categories_by']) && $s['sort_categories_by']) {
                  $categories_orderby = sanitize_title( $s['sort_categories_by'] );
                }

                $args = array(
                          'taxonomy'        => 'shared-file-category',
                          'name'            => 'sf_category',
                          'show_option_all' => esc_attr__('Choose category', 'shared-files'),
                          'hierarchical'    => true,
                          'class'           => 'shared-files-category-select select_v2',
                          'echo'            => false,
                          'value_field'     => 'slug',
                          'exclude'         => $exclude_cat,
                          'selected'        => $cat_selected,

                          'orderby'         => $categories_orderby,
                          'order'           => $categories_order,
                          'hide_if_empty'   => true

                        );

                $html .= '<div class="shared-files-category-select-container">';
                $html .= wp_dropdown_categories($args);
                $html .= '</div>';

              }

            }

          }
        }

        if (isset($s['show_tag_dropdown']) || isset($atts['show_tag_dropdown'])) {

          $tag_selected = isset($_GET['sf_tag']) ? sanitize_title( $_GET['sf_tag'] ) : '';

          $tags_orderby = '';
          $tags_order = 'ASC';

          if (isset($s['sort_tags_by']) && $s['sort_tags_by']) {
            $tags_orderby = sanitize_title( $s['sort_tags_by'] );
          }

          $tag_args = array(
                    'taxonomy'          => SHARED_FILES_TAG_SLUG,
                    'name'              => 'sf_tag',
                    'show_option_none'   => esc_attr__('Choose tag', 'shared-files'),
                    'hierarchical'      => true,
                    'class'             => 'shared-files-tag-select select_v2',
                    'echo'              => false,
                    'value_field'       => 'slug',
                    'selected'          => $tag_selected,
                    'option_none_value' => '',

                    'orderby'           => $tags_orderby,
                    'order'             => $tags_order,

                  );

          $html .= '<div class="shared-files-tag-select-container">';
          $html .= wp_dropdown_categories($tag_args);
          $html .= '</div>';

        }

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $is_premium = 1;

            $custom_fields_cnt = 0;

            if (isset($s['custom_fields_cnt'])) {
              $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
            } else {
              $custom_fields_cnt = 5 + 1;
            }

            $custom_fields_search_filters_active = 0;

            for ($n = 1; $n < $custom_fields_cnt; $n++) {

              if (isset($s['cf_' . $n . '_use_as_search_filter']) && $s['cf_' . $n . '_use_as_search_filter']) {
                $custom_fields_search_filters_active = 1;
              }

            }

            if ($custom_fields_search_filters_active) {

              $tax_query = ['relation' => 'AND'];

              if (isset($atts['categories__and']) && $atts['categories__and']) {

                $cat_slugs_and = explode(',', $atts['categories__and']);

                $tax_query []= array(
                  'taxonomy'          => 'shared-file-category',
                  'field'             => 'slug',
                  'terms'             => $cat_slugs_and,
                  'operator'          => 'AND',
                  'include_children'  => $include_children
                );

              } elseif (isset($atts['exclude_cat'])) {

                $terms = explode(',', $atts['exclude_cat']);

                $tax_query []= [
                  'taxonomy'  => 'shared-file-category',
                  'terms'     => $terms,
                  'field'     => 'slug',
                  'operator'  => 'NOT IN'
                ];

              }

              if (isset($atts['categories__or']) && $atts['categories__or']) {

                $cat_slugs_or = explode(',', $atts['categories__or']);

                $tax_query []= array(
                  'taxonomy'          => 'shared-file-category',
                  'field'             => 'slug',
                  'terms'             => $cat_slugs_or,
                  'operator'          => 'IN',
                  'include_children'  => $include_children
                );

              }

              if (isset($atts['tags__and']) && $atts['tags__and']) {

                $tag_slugs_and = explode(',', $atts['tags__and']);

                $tax_query []= array(
                  'taxonomy'          => SHARED_FILES_TAG_SLUG,
                  'field'             => 'slug',
                  'terms'             => $tag_slugs_and,
                  'operator'          => 'AND',
                  'include_children'  => $include_children
                );

              }

              if (isset($atts['tags__or']) && $atts['tags__or']) {

                $tag_slugs_or = explode(',', $atts['tags__or']);

                $tax_query []= array(
                  'taxonomy'          => SHARED_FILES_TAG_SLUG,
                  'field'             => 'slug',
                  'terms'             => $tag_slugs_or,
                  'operator'          => 'IN',
                  'include_children'  => $include_children
                );

              }

              $wp_query_for_filter = new WP_Query(array(

                'post_type'       => 'shared_file',
                'post_status'     => 'publish',
                'posts_per_page'  => -1,

                'orderby'     => SharedFilesHelpers::getOrderBy($atts),
                'order'       => SharedFilesHelpers::getOrder($atts),
                'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

                'tax_query'   => $tax_query,

                'meta_query'  => $meta_query_hide_not_public,

              ));

              $meta_query = array('relation' => 'AND');

              for ($n = 1; $n < $custom_fields_cnt; $n++) {

                if (isset($s['cf_' . $n . '_use_as_search_filter']) && $s['cf_' . $n . '_use_as_search_filter']) {

                  $field_name = 'cf_' . $n;

                  if (isset($_GET[$field_name]) && $_GET[$field_name]) {

                    $meta_query[] = array(
                      'key'		  => '_sf_file_upload_cf_' . $n,
                      'value'		=> sanitize_text_field( $_GET[$field_name] ),
                      'compare'	=> 'LIKE'
                    );


                  }

                  $values = [];

                  while ($wp_query_for_filter->have_posts()): $wp_query_for_filter->the_post();

                    $id = intval( get_the_id() );
                    $c = get_post_custom($id);

                    if (isset($c['_sf_file_upload_cf_' . $n][0]) && $c['_sf_file_upload_cf_' . $n][0] && !in_array($c['_sf_file_upload_cf_' . $n][0], $values)) {
                      $values []= sanitize_text_field( $c['_sf_file_upload_cf_' . $n][0] );
                    }

                  endwhile;

                  if (isset($values) && is_array($values)) {
                    sort($values);
                  }

                  $field_name = 'cf_' . $n;

                  $select_title = sanitize_text_field( __('Custom field', 'shared-files') ) . ' ' . $n;

                  if (isset($s['cf_' . $n . '_select_title']) && $s['cf_' . $n . '_select_title']) {

                    $select_title = sanitize_text_field( $s['cf_' . $n . '_select_title'] );

                  } elseif (isset($s['file_upload_custom_field_' . $n]) && $s['file_upload_custom_field_' . $n]) {

                    $select_title = sanitize_text_field( $s['file_upload_custom_field_' . $n] );

                  }

                  $html .= '<div class="shared-files-custom-field-select-container">';

                  $html .= '<select name="' . esc_attr( $field_name ) . '" class="shared-files-custom-field-select select_v2" data-select-value="' . $select_title . '" data-current-value="' . (isset($_GET[$field_name]) ? esc_attr( $_GET[$field_name] ) : '') . '">';

                  $html .= '<option value="">' . $select_title . '</option>';

                  if (isset($values) && is_array($values)) {

                    foreach ($values as $val) {
                      $html .= '<option value="' . esc_attr( $val ) . '" ' . (isset($_GET[$field_name]) && $_GET[$field_name] == $val ? 'selected="selected"' : '') . '>' . sanitize_text_field( $val ) . '</option>';
                    }

                  }

                  $html .= '</select>';

                  $html .= '</div>';

                  $custom_fields_active = 1;

                }

              }

            }

            $html .= '<hr class="clear" />';

          }
        }

        // .shared-files-search-form-container
        $html .= '</form>';

        // .shared-files-ajax-form
        $html .= '</div>';

      }


      if ($custom_fields_active) {

        $meta_query_full = array('relation' => 'AND');

        $meta_query_full []= $meta_query_hide_not_public;
        $meta_query_full []= $meta_query;


      } else {

        $meta_query_full = $meta_query_hide_not_public;

      }

      $taxonomy_query = ['relation' => 'AND'];

      if ($tag_slug) {

        $taxonomy_query []= array(
          'taxonomy'          => SHARED_FILES_TAG_SLUG,
          'field'             => 'slug',
          'terms'             => $tag_slug,
        );

      }

      if (isset($atts['category'])) {

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            $term_slug = sanitize_title($atts['category']);

            if ($term_slug) {

              $taxonomy_query []= array(
                'taxonomy'          => 'shared-file-category',
                'field'             => 'slug',
                'terms'             => $term_slug,
                'include_children'  => true
              );

            }

            $posts_per_page = isset($s['pagination']) && $s['pagination'] ? (int) $s['pagination'] : 20;

            $paged = 1;

            if ($pagination_active) {

              if (isset($_GET['_page']) && $_GET['_page']) {
                $paged = (int) $_GET['_page'];
              } elseif (get_query_var('paged')) {
                $paged = absint( get_query_var('paged') );
              }

            }

            if ($limit_posts) {
              $posts_per_page = $limit_posts;
            }

            $wpb_all_query = new WP_Query(array(
              'post_type'       => 'shared_file',
              'post_status'     => 'publish',

              'paged'           => $paged,
              'posts_per_page'  => $posts_per_page,

              'tax_query'       => $taxonomy_query,

              'orderby'     => SharedFilesHelpers::getOrderBy($atts),
              'order'       => SharedFilesHelpers::getOrder($atts),
              'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

              'meta_query'  => $meta_query_full,
            ));

            $wpb_all_query_all_files = new WP_Query(array(
              'post_type'       => 'shared_file',
              'post_status'     => 'publish',
              'posts_per_page'  => -1,

              'tax_query' => array(
                array (
                  'taxonomy'          => 'shared-file-category',
                  'field'             => 'slug',
                  'terms'             => $term_slug,
                  'include_children'  => true
                )
              ),

              'orderby'     => SharedFilesHelpers::getOrderBy($atts),
              'order'       => SharedFilesHelpers::getOrder($atts),
              'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

              'meta_query'  => $meta_query_hide_not_public,
            ));

          }
        }

        if (SharedFilesHelpers::isPremium() == 0) {
          $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
          return $html;
        }

      } else if (isset($_GET['sf_category']) && $_GET['sf_category'] != '0') {

        $term_slug = sanitize_title($_GET['sf_category']);

        if ($term_slug) {

          $taxonomy_query []= array(
            'taxonomy'          => 'shared-file-category',
            'field'             => 'slug',
            'terms'             => $term_slug,
            'include_children'  => true
          );

        }

        $wpb_all_query = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',
          'posts_per_page'  => -1,

          'tax_query'       => $taxonomy_query,

          'orderby'     => SharedFilesHelpers::getOrderBy($atts),
          'order'       => SharedFilesHelpers::getOrder($atts),
          'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'  => $meta_query_full,
        ));

        $wpb_all_query_all_files = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',
          'posts_per_page'  => -1,

          'tax_query'       => array(
            array(
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $term_slug,
              'include_children'  => true
            )
          ),

          'orderby'     => SharedFilesHelpers::getOrderBy($atts),
          'order'       => SharedFilesHelpers::getOrder($atts),
          'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'  => $meta_query_hide_not_public,
        ));

      } else if (isset($_GET['c']) && $_GET['c'] != 'all_files') {

        $term_slug = sanitize_title($_GET['c']);

        if ($term_slug) {

          $taxonomy_query []= array(
            'taxonomy'          => 'shared-file-category',
            'field'             => 'slug',
            'terms'             => $term_slug,
            'include_children'  => true
          );

        }

        $wpb_all_query = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',
          'posts_per_page'  => -1,

          'tax_query'       => $taxonomy_query,

          'orderby'     => SharedFilesHelpers::getOrderBy($atts),
          'order'       => SharedFilesHelpers::getOrder($atts),
          'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'  => $meta_query_full,
        ));

        $wpb_all_query_all_files = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',
          'posts_per_page'  => -1,

          'tax_query' => array(
            array(
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $term_slug,
              'include_children'  => true
            )
          ),

          'orderby'     => SharedFilesHelpers::getOrderBy($atts),
          'order'       => SharedFilesHelpers::getOrder($atts),
          'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'  => $meta_query_hide_not_public,
        ));

      } else {

        $paged = 1;

        if ($pagination_active) {

          if (isset($_GET['_page']) && $_GET['_page']) {
            $paged = (int) $_GET['_page'];
          } elseif (get_query_var('paged')) {
            $paged = absint( get_query_var('paged') );
          }

        }

        $posts_per_page = isset($s['pagination']) && $s['pagination'] ? (int) $s['pagination'] : 20;

        if ($limit_posts) {
          $posts_per_page = $limit_posts;
        }

        $tax_query = ['relation' => 'AND'];

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            if (isset($atts['categories__and']) && $atts['categories__and']) {

              $cat_slugs_and = explode(',', $atts['categories__and']);

              $tax_query []= array(
                'taxonomy'          => 'shared-file-category',
                'field'             => 'slug',
                'terms'             => $cat_slugs_and,
                'operator'          => 'AND',
                'include_children'  => $include_children
              );

            } elseif (isset($atts['exclude_cat'])) {

              $terms = explode(',', $atts['exclude_cat']);

              $tax_query []= [
                'taxonomy'  => 'shared-file-category',
                'terms'     => $terms,
                'field'     => 'slug',
                'operator'  => 'NOT IN'
              ];

            }

            if (isset($atts['categories__or']) && $atts['categories__or']) {

              $cat_slugs_or = explode(',', $atts['categories__or']);

              $tax_query []= array(
                'taxonomy'          => 'shared-file-category',
                'field'             => 'slug',
                'terms'             => $cat_slugs_or,
                'operator'          => 'IN',
                'include_children'  => $include_children
              );

            }

            if (isset($atts['tags__and']) && $atts['tags__and']) {

              $tag_slugs_and = explode(',', $atts['tags__and']);

              $tax_query []= array(
                'taxonomy'          => SHARED_FILES_TAG_SLUG,
                'field'             => 'slug',
                'terms'             => $tag_slugs_and,
                'operator'          => 'AND',
                'include_children'  => $include_children
              );

            }

            if (isset($atts['tags__or']) && $atts['tags__or']) {

              $tag_slugs_or = explode(',', $atts['tags__or']);

              $tax_query []= array(
                'taxonomy'          => SHARED_FILES_TAG_SLUG,
                'field'             => 'slug',
                'terms'             => $tag_slugs_or,
                'operator'          => 'IN',
                'include_children'  => $include_children
              );

            }

          }
        }

        if ( isset( $atts['upload_id'] ) ) {

          $upload_id = sanitize_text_field( $atts['upload_id'] );

          $meta_query_full = array('relation' => 'AND');

          $meta_query_full[] = array(
            'key'		  => '_sf_upload_id',
            'compare'	=> '=',
            'value'   => $upload_id
          );

          $meta_query_hide_not_public = array('relation' => 'AND');

          $meta_query_hide_not_public[] = array(
            'key'		  => '_sf_upload_id',
            'compare'	=> '=',
            'value'   => $upload_id
          );

        }

        if ($tag_slug) {

          $tax_query []= array(
            'taxonomy'          => SHARED_FILES_TAG_SLUG,
            'field'             => 'slug',
            'terms'             => $tag_slug,
          );

        }

        $wpb_all_query = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',

          'paged'           => $paged,
          'posts_per_page'  => $posts_per_page,

          'orderby'         => SharedFilesHelpers::getOrderBy($atts),
          'order'           => SharedFilesHelpers::getOrder($atts),
          'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'      => $meta_query_full,

          'tax_query'       => $tax_query
        ));

        $wpb_all_query_all_files = new WP_Query(array(
          'post_type'       => 'shared_file',
          'post_status'     => 'publish',
          'posts_per_page'  => -1,

          'orderby'         => SharedFilesHelpers::getOrderBy($atts),
          'order'           => SharedFilesHelpers::getOrder($atts),
          'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

          'meta_query'      => $meta_query_hide_not_public,

          'tax_query'       => $tax_query
        ));

      }

      $filetypes = SharedFilesHelpers::getFiletypes();
      $external_filetypes = SharedFilesHelpers::getExternalFiletypes();

      $html .= '<div class="shared-files-files-found"></div>';
      $html .= '<span class="shared-files-one-file-found">' . sanitize_text_field( __('file found.', 'shared-files') ) . '</span><span class="shared-files-more-than-one-file-found">' . sanitize_text_field( __('files found.', 'shared-files') ) . '</span>';

      $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

      /* CATEGORY PASSWORD START */
      if (shared_files_fs()->is__premium_only()) {
        if (shared_files_fs()->can_use_premium_code()) {
          if (isset($term_slug) && $term_slug) {

            $password_check_markup = SharedFilesPublicHelpers::checkCatPassword__premium_only($term_slug, 1);

            if ($password_check_markup) {
              $html .= $password_check_markup;

              // .shared-files-search
              $html .= '</div>';

              // .shared-files-container
              $html .= '</div>';

              // .shared-files-main-container
              $html .= '</div>';

              return $html;
            }

          }
        }
      }
      /* CATEGORY PASSWORD END */

      if (isset($wpb_all_query_all_files) && $wpb_all_query_all_files->have_posts()):

        if (shared_files_fs()->is__premium_only()) {
          if (shared_files_fs()->can_use_premium_code()) {

            if (is_user_logged_in() && isset($atts['edit'])) {

              $current_url = esc_url_raw( get_permalink() );

              while ($wpb_all_query_all_files->have_posts()): $wpb_all_query_all_files->the_post();

                $file_id = intval( get_the_id() );
                $html .= SharedFilesPublicHelpers::editFileModal__premium_only($file_id, $current_url);

              endwhile;

            }

          }
        }

        $html .= '<ul class="shared-files-main-file-list shared-files-ajax-list">';

        if ( isset($atts['hide_files_first']) ):

          // ...

        else:

          while ($wpb_all_query->have_posts()): $wpb_all_query->the_post();

            $id = intval( get_the_id() );
            $c = get_post_custom($id);

            $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
            $filetype = '';

            $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

            if (isset($atts['file_upload'])) {
              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 1, $atts);
            } elseif (isset($atts['category'])) {
              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);
            } else {
              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 1, $atts);
            }

          endwhile;

        endif;

        $html .= '</ul>';

      elseif (!isset($atts['file_upload'])):

        $html .= '<ul class="shared-files-main-file-list shared-files-ajax-list"><li>';
        $html .= '<div class="shared-files-files-not-found">' . sanitize_text_field( __('No files found.', 'shared-files') ) . '</div>';
        $html .= '</li></ul>';

      endif;

      if (!isset($s['hide_search_form']) && !isset($atts['hide_search_for_all_files'])) {

        $show_tags = 0;

        if (isset($s['show_tags_on_search_results'])) {
          $show_tags = 1;
        }

        $html .= '<ul class="shared-files-all-files shared-files-main-file-list">';

        if (isset($wpb_all_query_all_files) && $wpb_all_query_all_files->have_posts()):
          while ($wpb_all_query_all_files->have_posts()): $wpb_all_query_all_files->the_post();

            $id = intval( get_the_id() );
            $c = get_post_custom($id);

            $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
            $filetype = '';
            $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

            $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

            $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, $show_tags, $atts);

          endwhile;
        endif;

        $html .= '</ul>';

      }

      if ( !isset($atts['hide_files_first']) ) {

        if (!$limit_posts) {
          $html .= SharedFilesPublicPagination::getPagination($pagination_active, $wpb_all_query, $embed_id);
        }

      }

      $html .= '<div class="shared-files-nothing-found">';
      $html .= sanitize_text_field( __('No files found.', 'shared-files') );
      $html .= '</div>';

      // .shared-files-search
      $html .= '</div>';

      // .shared-files-container
      $html .= '</div>';

      // .shared-files-main-container
      $html .= '</div>';

      $html .= '<hr class="clear" />';

      wp_reset_postdata();

      return $html;
    }
  }

}
