<?php

class ShortcodeSharedFilesAccordion {

  public static function shared_files_accordion($atts = [], $content = null, $tag = '') {

    if (SharedFilesHelpers::isPremium() == 0) {
      $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
      return $html;
    } elseif (isset($atts['restricted']) && $atts['restricted'] && !is_user_logged_in()) {
      $html = '<div style="background: #fff; border: 1px solid #bbb; color: #000; padding: 10px 20px; border-radius: 5px;">' . esc_html__('Only logged in users can list these files.', 'shared-files') . '</div>';
      return $html;

    } elseif ( !SharedFilesHelpers::isMin2Pr() ) {

      $html = '';
      return $html;

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        $html = '';

        $current_url = esc_url_raw( get_permalink() );

        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        $embed_id = isset($atts['embed_id']) ? sanitize_title($atts['embed_id']) : 'default';

        if ( ( isset($atts['ask_for_email']) && $atts['ask_for_email'] == 1 ) || ( isset($atts['ask_for_contact_info']) && $atts['ask_for_contact_info'] == 1 ) ) {

          if ( is_super_admin() ) {

            $html .= SharedFilesPublicContacts::askForEmailInfo();

          } else {

            if ( isset($_POST['shared-files-add-contact']) ) {

              SharedFilesPublicContacts::saveEmail($embed_id, $atts);

            } else {

              $html = SharedFilesPublicContacts::askForEmail($embed_id, $atts);
              return $html;

            }

          }

        }

        $exclude_cat = [];

        if (isset($atts['exclude_cat'])) {
          $terms = explode(',', $atts['exclude_cat']);

          foreach ($terms as $term_slug) {
            $term = get_term_by('slug', $term_slug, 'shared-file-category');

            if ( isset( $term->term_id ) ) {
              $exclude_cat []= intval( $term->term_id );
            }
          }

        }

        $order_by_category_list = 'description';

        if (isset($s['order_by_category_list']) && $s['order_by_category_list']) {
          $order_by_category_list = sanitize_text_field( $s['order_by_category_list'] );
        }

        $layout = SharedFilesHelpers::getLayout($s, $atts);

        $include_cat = [];

        if (isset($atts['base_category'])) {

          $base_category_slug = sanitize_title( $atts['base_category'] );
          $base_category = get_term_by('slug', $base_category_slug, 'shared-file-category');

          if ( isset($base_category->term_id) && $base_category->term_id ) {

            $categories = get_terms(array(
              'taxonomy'    => 'shared-file-category',
              'hide_empty'  => true,
              'parent'      => $base_category->term_id,

              'orderby'     => $order_by_category_list,
              'order'       => 'ASC',

              'exclude'     => $exclude_cat

            ));

            foreach ($categories as $cat) {
              $include_cat []= $cat->slug;
            }

          }

        } elseif (isset($atts['categories'])) {

          $terms_temp = explode(',', $atts['categories']);

          foreach ($terms_temp as $term_slug) {
            $include_cat []= sanitize_title( $term_slug );
          }

        } else {

          $categories = get_terms(array(
            'taxonomy'    => 'shared-file-category',
            'hide_empty'  => true,
            'include'     => $include_cat,
            'parent'      => 0,

            'orderby'     => $order_by_category_list,
            'order'       => 'ASC',

            'exclude'     => $exclude_cat

          ));

          foreach ($categories as $cat) {
            $include_cat []= $cat->slug;
          }

        }

        if ( sizeof($include_cat) > 0 ) {

          $at_least_one_file_found = 0;

          $elem_class = SharedFilesHelpers::createElemClass();

          $html .= '<div class="' . $elem_class . ' shared-files-accordion-container">';

          $html .= '<div class="shared-files-accordion">';

          $html .= '<ul class="shared-files-accordion-list">';

          $row = 1;

          foreach ($include_cat as $cat_slug):

            $cat = get_term_by('slug', $cat_slug, 'shared-file-category');

            if ($cat) {

              $html .= '<li>';

              $html .= '<div>';

              $indent_class = '';
              $indent_markup = '';

              if ($cat->parent && !isset($atts['base_category'])) {
                $indent_class = 'sf-indent';
                $indent_markup = '<span class="shared-files-indent-markup">&gt;</span>';
              }

              $term_id = intval( $cat->term_id );

              $category_class = 'shared-files-accordion-category-closed';

              if ($row == 1 && isset($atts['first_category_open'])) {
                $category_class = 'shared-files-accordion-category-open';
              }

              $html .= '<div class="shared-files-accordion-category ' . $category_class . ' shared-files-accordion-category-' . sanitize_title( $cat_slug ) . ' shared-files-accordion-category-' . $term_id . ' ' . $indent_class . '" data-category-id="' . $term_id . '">';

              $html .= '<div class="shared-files-accordion-category-title-container" data-category-id="' . $term_id . '" data-elem-class="' . $elem_class . '">';
              $html .= '<div class="shared-files-accordion-category-title"><span>' . $indent_markup . esc_html( $cat->name ) . '</span></div>';
              $html .= '<div class="shared-files-accordion-category-icon"><img src="' . SHARED_FILES_URI . 'img/caret-down.svg" /></div>';
              $html .= '</div>';

              $html .= '<div class="shared-files-accordion-contents shared-files-accordion-contents-' . $term_id . '">';

              $cat = sanitize_title( $cat->slug );

              $parent_cat = get_term_by('slug', $cat, 'shared-file-category');

              $cat_password = SharedFilesTermMetadata::get_hierarchichal_term_metadata($parent_cat, '_sf_cat_password');
              $cat_password_protection_type = SharedFilesTermMetadata::get_hierarchichal_term_metadata($parent_cat, '_sf_cat_password_protection_type');

              $file_list_is_password_protected = 0;

              if ($cat_password_protection_type == 'cookie') {
                $file_list_is_password_protected = 1;
              }

              $given_password = '';

              if (isset($_POST['_sf_cat_password']) && $_POST['_sf_cat_password']) {
                $given_password = sanitize_text_field( $_POST['_sf_cat_password'] );
              } else if ($cat_password_protection_type == 'cookie' && isset($_COOKIE['_sf_cat_password']) && $_COOKIE['_sf_cat_password']) {
                $given_password = sanitize_text_field( $_COOKIE['_sf_cat_password'] );
              }

              if ($file_list_is_password_protected && (!$given_password || $given_password != $cat_password)) {
                $html = SharedFilesPublicHelpers::passwordProtectedMarkupForFileList__premium_only();
                return $html;
              }

              $html .= '<div class="shared-files-container shared-files-categories-container ' . ($layout ? 'shared-files-' . $layout : '') . '">';
              $html .= '<div class="shared-files-search">';

              $term_slug = sanitize_title($cat);

              $order_by = SharedFilesHelpers::getOrderBy($atts);

              $meta_query = [];

              if ( isset($atts['restricted']) && $atts['restricted'] ) {

                $logged_in_user_id = intval( get_current_user_id() );
                $user = wp_get_current_user();
                $user_roles = $user->roles;

                $meta_query_file_permissions = array('relation' => 'OR');

                $meta_query_file_permissions []= array(
                  'key'		  => '_sf_permission_user_id',
                  'compare'	=> 'REGEXP',
                  'value'   => "(^|,)$logged_in_user_id(,|$)"
                );

                if ( $user_roles && is_array($user_roles) ) {

                  foreach ( $user_roles as $logged_in_user_role ) {

                    $meta_query_file_permissions []= array(
                      'key'		  => '_sf_permission_user_role_' . sanitize_title( $logged_in_user_role ),
                      'compare'	=> '=',
                      'value'   => 1
                    );

                  }

                }

                $meta_query = $meta_query_file_permissions;

              }

              $subcategories = get_terms(array(
                'taxonomy'    => 'shared-file-category',
                'hide_empty'  => true,
                'parent'      => $term_id,

                'orderby'     => $order_by_category_list,
                'order'       => 'ASC',

                'exclude'     => $exclude_cat

              ));

              $all_subcategories = get_term_children( $term_id, 'shared-file-category' );

              $wp_query = new WP_Query(array(
                'post_type'       => 'shared_file',
                'post_status'     => 'publish',
                'posts_per_page'  => -1,

                'tax_query' => array(
                  array (
                    'taxonomy'          => 'shared-file-category',
                    'field'             => 'slug',
                    'terms'             => $term_slug,
                    'include_children'  => false
                  )
                ),

                'orderby'     => $order_by,
                'order'       => SharedFilesHelpers::getOrder($atts),
                'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

                'meta_query'  => $meta_query,

              ));

              $files_found_in_cat = 0;

              if ($wp_query->have_posts() || sizeof( $subcategories ) > 0):

                if (is_user_logged_in() && isset($atts['edit'])) {

                  while ($wp_query->have_posts()): $wp_query->the_post();

                    $file_id = intval( get_the_id() );
                    $html .= SharedFilesPublicHelpers::editFileModal__premium_only($file_id, $current_url);

                  endwhile;

                }

                $html .= '<ul class="shared-files-main-file-list">';

                $month = '';
                $month_prev = 'temp';

                while ($wp_query->have_posts()): $wp_query->the_post();

                  $at_least_one_file_found = 1;
                  $files_found_in_cat = 1;

                  $id = get_the_id();
                  $c = get_post_custom($id);

                  if (isset($atts['group_files_by_month'])) {

                    if ($order_by == 'post_date') {

                      $month = get_the_date('F Y');

                    } elseif (isset($atts['order_by']) && $atts['order_by'] == '_sf_main_date') {

                      $main_date = get_post_meta($id, '_sf_main_date', true);

                      if ($main_date instanceof DateTime) {

                        $main_date_formatted = $main_date->format('F Y');
                        $month = $main_date_formatted;

                      } else {

                        $month = get_the_date('F Y');

                      }

                    }

                    if ($month != $month_prev) {

                      $html .= '<div class="shared-files-month-title">' . ucfirst( $month ) . '</div>';

                    }

                  }

                  $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                  $filetype = '';
                  $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

                  $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);
                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);

                  $month_prev = $month;

                endwhile;

                if ( sizeof( $all_subcategories ) > 0 && !isset($atts['hide_subcategories']) ) {

                  foreach ($all_subcategories as $subcat_temp) {

                    $subcat = get_term($subcat_temp, 'shared-file-category');

                    $html .= '<li class="shared-files-accordion-subcategory-' . sanitize_title( $subcat->slug ) . '">';

                    $html .= '<div class="shared-files-accordion-subcategory-title">' . sanitize_text_field( $subcat->name ) . '</div>';

                    $html .= '<ul class="shared-files-main-file-list">';

                    $wp_query_sub = new WP_Query(array(
                      'post_type'       => 'shared_file',
                      'post_status'     => 'publish',
                      'posts_per_page'  => -1,

                      'tax_query' => array(
                        array (
                          'taxonomy'          => 'shared-file-category',
                          'field'             => 'slug',
                          'terms'             => $subcat->slug,
                          'include_children'  => false
                        )
                      ),

                      'orderby'     => $order_by,
                      'order'       => SharedFilesHelpers::getOrder($atts),
                      'meta_key'    => SharedFilesHelpers::getMetaKey($atts),

                      'meta_query'  => $meta_query,

                    ));

                    if ( $wp_query_sub->have_posts() ) {

                      if (is_user_logged_in() && isset($atts['edit'])) {

                        while ($wp_query_sub->have_posts()): $wp_query_sub->the_post();

                          $file_id = intval( get_the_id() );
                          $html .= SharedFilesPublicHelpers::editFileModal__premium_only($file_id, $current_url);

                        endwhile;

                      }

                      $month = '';
                      $month_prev = 'temp';

                      while ($wp_query_sub->have_posts()): $wp_query_sub->the_post();

                        $at_least_one_file_found = 1;
                        $files_found_in_cat = 1;

                        $id = get_the_id();
                        $c = get_post_custom($id);

                        if (isset($atts['group_files_by_month'])) {

                          if ($order_by == 'post_date') {

                            $month = get_the_date('F Y');

                          } elseif (isset($atts['order_by']) && $atts['order_by'] == '_sf_main_date') {

                            $main_date = get_post_meta($id, '_sf_main_date', true);

                            if ($main_date instanceof DateTime) {

                              $main_date_formatted = $main_date->format('F Y');
                              $month = $main_date_formatted;

                            } else {

                              $month = get_the_date('F Y');

                            }

                          }

                          if ($month != $month_prev) {

                            $html .= '<div class="shared-files-month-title">' . ucfirst( $month ) . '</div>';

                          }

                        }

                        $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                        $filetype = '';
                        $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

                        $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);
                        $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);

                        $month_prev = $month;

                      endwhile;

                    }

                    $html .= '</ul></li>';

                  }

                }

                $html .= '</ul>';

              endif;

              if ( !$files_found_in_cat ) {

                $html .= '<style>.shared-files-accordion-category-' . $term_id . ' { display: none !important; }</style>';

              }

              $html .= '</div></div><hr class="clear" />';


              $html .= '</div>';

              $html .= '</div>';

              $html .= '</div>';
              $html .= '</li>';

            }

            $row++;

          endforeach;

          $html .= '</ul>';

          $html .= '</div>';

          $html .= '</div>';

          if (!$at_least_one_file_found) {
            $html .= '<div>' . esc_html__('No files found.', 'shared-files') . '</div>';
          }

        }

        wp_reset_postdata();

        return $html;

      }

    }
  }

}
