<?php
  
class ShortcodeSharedFilesCategories {

  public static function shared_files_categories($atts = [], $content = null, $tag = '') {

    if (SharedFilesHelpers::isPremium() == 0) {
      $html = SharedFilesAdminHelpers::sfProFeatureMarkup();
      return $html;
    } elseif (isset($atts['restricted']) && $atts['restricted'] && !is_user_logged_in()) {
      $html = '<div style="background: #fff; border: 1px solid #bbb; color: #000; padding: 10px 20px; border-radius: 5px;">' . esc_html__('Only logged in users can list these files.', 'shared-files') . '</div>';
      return $html;
    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {
    
        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        $current_url = esc_url_raw( get_permalink() );

        $exclude_cat = [];
        
        if (isset($atts['exclude_cat'])) {
          $terms = explode(',', $atts['exclude_cat']);
          
          foreach ($terms as $term_slug) {
            $term = get_term_by('slug', $term_slug, 'shared-file-category');
            
            if ( isset( $term->term_id ) ) {
              $exclude_cat []= intval( $term->term_id );
            }
          }
        
        }
    
        $order_by_category_list = 'description';
    
        if (isset($s['order_by_category_list']) && $s['order_by_category_list']) {
          $order_by_category_list = sanitize_text_field( $s['order_by_category_list'] );
        }
    
        $layout = '';
        
        if (isset($atts['layout'])) {
          $layout = sanitize_text_field( $atts['layout'] );
        } elseif (isset($s['layout']) && $s['layout']) {
          $layout = sanitize_text_field( $s['layout'] );
        }
      
        $html = '';

        if (isset($_GET) && isset($_GET['shared-files-update'])) {
          $html .= '<div class="shared-files-upload-complete">' . esc_html__('File successfully updated.', 'shared-files') . '</div>';
        } elseif (isset($_GET) && isset($_GET['_sf_delete_editable_file']) && isset($_GET['sc'])) {
          $html .= '<div class="shared-files-file-deleted">' . esc_html__('File successfully deleted.', 'shared-files') . '</div>';      
        }
    
        $category_slug = isset($_GET['cat']) ? $_GET['cat'] : '';
    
        if (isset($atts['category']) && !$category_slug) {
          $category_slug = sanitize_title($atts['category']);
        }
    
        if (isset($_GET['cat']) || isset($atts['category'])):

          $cat = '';
    
          if ( isset($_GET['cat']) ) {
            $cat = sanitize_text_field( $_GET['cat'] );
          } elseif ( isset($atts['category']) ) {
            $cat = sanitize_text_field( $atts['category'] );
          }
    
          $parent_cat = get_term_by('slug', $cat, 'shared-file-category');

          $cat_password = '';
          $cat_password_protection_type = '';

          if ( $parent_cat instanceof WP_Term ) {
            $cat_password = SharedFilesTermMetadata::get_hierarchichal_term_metadata($parent_cat, '_sf_cat_password');
            $cat_password_protection_type = SharedFilesTermMetadata::get_hierarchichal_term_metadata($parent_cat, '_sf_cat_password_protection_type');
          }
          
          $file_list_is_password_protected = 0;
    
          if ($cat_password_protection_type == 'cookie') {
            $file_list_is_password_protected = 1;
          }
          
          $given_password = '';
    
          if (isset($_POST['_sf_cat_password']) && $_POST['_sf_cat_password']) {
            $given_password = sanitize_text_field( $_POST['_sf_cat_password'] );
          } else if ($cat_password_protection_type == 'cookie' && isset($_COOKIE['_sf_cat_password']) && $_COOKIE['_sf_cat_password']) {
            $given_password = sanitize_text_field( $_COOKIE['_sf_cat_password'] );
          }
    
          if ($file_list_is_password_protected && (!$given_password || $given_password != $cat_password)) {
            $html = SharedFilesPublicHelpers::passwordProtectedMarkupForFileList__premium_only();
            return $html;
          }

          $term_id = 0;
          
          if ( isset( $parent_cat->term_id ) ) {
            $term_id = $parent_cat->term_id;
          }
      
          $subcategories = get_terms(array(
            'taxonomy'    => 'shared-file-category',
            'hide_empty'  => true,
            'parent'      => $term_id,
    
            'orderby'     => $order_by_category_list,
            'order'       => 'ASC',
            
            'exclude'     => $exclude_cat
    
          ));

          if ( isset($atts['category']) && !isset($_GET['cat']) ) {
            // ...
          } else {
            $html .='<a href="javascript:history.back()">' . (isset($s['back_link_title']) && $s['back_link_title'] ? sanitize_text_field( $s['back_link_title'] ) : sanitize_text_field( __('<< Back', 'shared-files') )) . '</a>';
          }
      
          $category = get_term_by('slug', $category_slug, 'shared-file-category');
    
          if ($category):
            $html .='<h3 class="shared-files-group-title">' . sanitize_text_field( $category->name ) . '</h3>';
          endif;

          if (sizeof($subcategories) > 0) {
            $html .= SharedFilesPublicHelpers::listCategories__premium_only($subcategories);
          }
    
          $html .= '<div class="shared-files-container shared-files-categories-container ' . ($layout ? 'shared-files-' . $layout : '') . '">';  
          $html .= '<div class="shared-files-search">';
          
          $term_slug = sanitize_title($cat);

          $meta_query = [];

          $meta_query_hide_uploaded = array('relation' => 'OR');
          
          $meta_query_hide_uploaded[] = array(
            'key'		  => '_sf_frontend_uploader',
            'compare'	=> '=',
            'value'   => '0'
          );
          
          $meta_query_hide_uploaded[] = array(
            'key'		  => '_sf_frontend_uploader',
            'compare'	=> 'NOT EXISTS',
          );

          if ( isset($atts['restricted']) && $atts['restricted'] ) {

            $logged_in_user_id = intval( get_current_user_id() );
            $user = wp_get_current_user();
            $user_roles = $user->roles;
            
            $meta_query_file_permissions = array('relation' => 'OR');
            
            $meta_query_file_permissions []= array(
              'key'		  => '_sf_permission_user_id',
              'compare'	=> 'REGEXP',
              'value'   => "(^|,)$logged_in_user_id(,|$)"
            );
            
            if ( $user_roles && is_array($user_roles) ) {
              
              foreach ( $user_roles as $logged_in_user_role ) {
            
                $meta_query_file_permissions []= array(
                  'key'		  => '_sf_permission_user_role_' . sanitize_title( $logged_in_user_role ),
                  'compare'	=> '=',
                  'value'   => 1
                );
                
              }
              
            }

            $meta_query = $meta_query_file_permissions;
            
          } elseif ( isset( $atts['exclude_files_uploaded_by_front_end_uploader'] ) ) {

            $meta_query = $meta_query_hide_uploaded;
            
          }
    
          $wpb_all_query = new WP_Query(array(
            'post_type'       => 'shared_file',
            'post_status'     => 'publish',
            'posts_per_page'  => -1,
            
            'tax_query' => array(
              array (
                'taxonomy'          => 'shared-file-category',
                'field'             => 'slug',
                'terms'             => $term_slug,
                'include_children'  => false
              )
            ),
            
            'orderby'   => SharedFilesHelpers::getOrderBy($atts),
            'order'     => SharedFilesHelpers::getOrder($atts),
            'meta_key'  => SharedFilesHelpers::getMetaKey($atts),

            'meta_query'  => $meta_query,
            
          ));
      
//          $filetypes = SharedFilesHelpers::getFiletypes();
//          $external_filetypes = SharedFilesHelpers::getExternalFiletypes();

          $show_files = 1;

          if (sizeof($subcategories) > 0 && !isset($atts['show_files_always'])) {
            $show_files = 0;
          }
        
          if ($show_files && $wpb_all_query->have_posts()):

            if (shared_files_fs()->is__premium_only()) {  
              if (shared_files_fs()->can_use_premium_code()) {
            
                if (is_user_logged_in() && isset($atts['edit'])) {
            
                  while ($wpb_all_query->have_posts()): $wpb_all_query->the_post();
            
                    $file_id = intval( get_the_id() );
                    $html .= SharedFilesPublicHelpers::editFileModal__premium_only($file_id, $current_url);
            
                  endwhile;
                  
                }
                
              }
            }
      
            $html .= '<ul class="shared-files-main-file-list">';
    
            while ($wpb_all_query->have_posts()): $wpb_all_query->the_post();
      
              $id = get_the_id();
              $c = get_post_custom($id);
      
              $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
              $filetype = '';
              $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';
      
              $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);                        
              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);
      
            endwhile;
      
            $html .= '</ul>';
    
          elseif ( sizeof($subcategories) == 0 ):
          
            $html .= '<p>' . sanitize_text_field( __('No files in this category.', 'shared-files') ) . '</p>';
    
          endif;
        
          $html .= '</div></div><hr class="clear" />';
    
        else:
              
          $category = get_term_by('slug', $category_slug, 'shared-file-category');
                  
          $terms = '';
      
          if (isset($atts['category'])) {
            $terms = sanitize_title($atts['category']);
          }
      
          $categories = get_terms(array(
            'taxonomy'    => 'shared-file-category',
            'hide_empty'  => true,
            'parent'      => isset($category->term_id) ? $category->term_id : 0,
            'terms'       => $terms,      
    
            'orderby'     => $order_by_category_list,
            'order'       => 'ASC',
            
            'exclude'     => $exclude_cat
        
          ));
        
          if (sizeof($categories) > 0):
            $html .= SharedFilesPublicHelpers::listCategories__premium_only($categories);
          endif;
          
        endif;
    
        wp_reset_postdata();
    
        return $html;
      }

    }
  }
  
}
