<?php

class ShortcodeSharedFilesExactSearch {

  public static function shared_files_exact_search($atts = [], $content = null, $tag = '') {

    if (SharedFilesHelpers::isPremium() == 0) {
      $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
      return $html;

    } elseif ( !SharedFilesHelpers::isMin2Pr() ) {

      $html = '';
      return $html;

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        $elem_class = SharedFilesHelpers::createElemClass();

        $layout = '';

        if (isset($atts['layout'])) {
          $layout = sanitize_text_field( $atts['layout'] );
        } elseif (isset($s['layout']) && $s['layout']) {
          $layout = sanitize_text_field( $s['layout'] );
        }

        $_sf_search = '';

        if ( isset($_GET['_sf_search']) && $_GET['_sf_search'] ) {
          $_sf_search = sanitize_text_field( $_GET['_sf_search'] );
        }

        $min_chars = 3;

        if ( isset($s['exact_search_min_chars']) && $s['exact_search_min_chars'] ) {
          $min_chars = intval( $s['exact_search_min_chars'] );
        }

        $html = '';

        $html .= '<div class="' . $elem_class . ' shared-files-container ' . ($layout ? 'shared-files-' . $layout : '') . '">';
        $html .= '<div class="shared-files-search">';

        $html .= '<form method="GET" action="./">';

        $html .= '<div class="shared-files-search-form-container shared-files-search-form-container-all-files"><div class="shared-files-exact-search-input-container"><input name="_sf_search" type="text" class="shared-files-search-files-input shared-files-search-file-exact" value="' . esc_attr( $_sf_search ) . '" placeholder="' . esc_html__('Search files...', 'shared-files') . '" data-elem-class="' . $elem_class . '"><input type="submit" class="shared-files-exact-search-submit" value="' . sanitize_text_field( __('Search', 'shared-files') ) . '" /></div>';

        $html .= '</form>';

        $html .= '<hr class="clear" /></div>';

        if ( $_sf_search && strlen($_sf_search) >= $min_chars ) {

          // Search for post title START

          $meta_query_hide_not_public = array('relation' => 'OR');

          $meta_query_hide_not_public[] = array(
  			    'key'		  => '_sf_not_public',
  			    'compare'	=> '=',
  			    'value'   => ''
  		    );

          $meta_query_hide_not_public[] = array(
  			    'key'		  => '_sf_not_public',
  			    'compare'	=> 'NOT EXISTS',
  		    );

          add_filter( 'posts_where', ['ShortcodeSharedFilesExactSearch', 'shared_files_title_filter__premium_only'], 10, 2 );

          $wp_query_only_title = new WP_Query(array(

            'post_type'         => 'shared_file',
            'post_status'       => 'publish',
            'posts_per_page'    => -1,

            'search_title'      => $_sf_search,

            'orderby'    => SharedFilesHelpers::getOrderBy($atts),
            'order'      => SharedFilesHelpers::getOrder($atts),
            'meta_key'   => SharedFilesHelpers::getMetaKey($atts),

            'meta_query' => $meta_query_hide_not_public,

          ));

          remove_filter( 'posts_where', ['ShortcodeSharedFilesExactSearch', 'shared_files_title_filter__premium_only'], 10, 2 );

          // Search for post title END

          // Search for other fields START

          $search_more_fields = isset( $s['exact_search_more_fields'] ) ? 1 : 0;
          $search_more_fields_params_set = 0;

          if ( $search_more_fields ) {

            $meta_query = array('relation' => 'AND');

            $meta_query []= $meta_query_hide_not_public;

            $search_for = '';
            $compare = '';

            if ( isset( $s['exact_search_whole_words_only'] ) ) {
              $search_for = '[[:<:]]' . sanitize_text_field( $_sf_search ) . '[[:>:]]';
              $compare = 'REGEXP';
            } else {
              $search_for = sanitize_text_field( $_sf_search );
              $compare = 'LIKE';
            }

            $meta_query_search_for = array('relation' => 'OR');

            $custom_fields_cnt = 5 + 1;

            if (isset($s['custom_fields_cnt'])) {
              $custom_fields_cnt = intval( $s['custom_fields_cnt'] ) + 1;
            } else {
              $custom_fields_cnt = 5 + 1;
            }

            for ($n = 1; $n < $custom_fields_cnt; $n++) {

              if ( isset( $s['exact_search_custom_field_' . $n] ) ) {

                $meta_query_search_for[] = array(
                  'key'		  => '_sf_file_upload_cf_' . $n,
                  'value'		=> $search_for,
                  'compare'	=> $compare
                );

                $search_more_fields_params_set = 1;

              }

            }

            $meta_query []= $meta_query_search_for;

            $wp_query_only_meta = new WP_Query(array(

              'post_type'         => 'shared_file',
              'post_status'       => 'publish',
              'posts_per_page'    => -1,

              'orderby'    => SharedFilesHelpers::getOrderBy($atts),
              'order'      => SharedFilesHelpers::getOrder($atts),
              'meta_key'   => SharedFilesHelpers::getMetaKey($atts),

              'meta_query' => $meta_query,

            ));

          }

          // Search for other fields END

          if ( $search_more_fields && $search_more_fields_params_set ) {

            // Get post IDs from both queries
            $post_ids1 = wp_list_pluck($wp_query_only_title->posts, 'ID');
            $post_ids2 = wp_list_pluck($wp_query_only_meta->posts, 'ID');

            // Combine and deduplicate IDs
            $final_post_ids = array_unique(array_merge($post_ids1, $post_ids2));

          } else {

            $final_post_ids = wp_list_pluck($wp_query_only_title->posts, 'ID');

          }

          if ( is_array($final_post_ids) && sizeof($final_post_ids) > 0 ) {

            // New query with combined IDs
            $final_query_args = array(
              'post_type'       => 'shared_file',
              'post__in'        => $final_post_ids,
              'orderby'         => 'post__in',
              'posts_per_page'  => -1,
            );

            $final_query = new WP_Query($final_query_args);

            if ( $final_query->have_posts() ) {

              if ( $final_query->post_count == 1 ) {
                $html .= '<div>' . esc_html__('1 file found.', 'shared-files') . '</div>';
              } else {
                $html .= '<div>' . $final_query->post_count . ' ' . esc_html__('files found.', 'shared-files') . '</div>';
              }

              $html .= '<ul class="shared-files-all-files" style="display: block;">';

              if (isset($final_query) && $final_query->have_posts()):
                while ($final_query->have_posts()): $final_query->the_post();

                  $id = get_the_id();
                  $c = get_post_custom($id);

                  $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                  $filetype = '';
                  $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

                  $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);

                endwhile;
              endif;

              $html .= '</ul>';

            }

          } else {

            $html .= '<div>';
            $html .= esc_html__('No files found.', 'shared-files');
            $html .= '</div>';

          }

        } elseif ( $_sf_search && strlen($_sf_search) < $min_chars ) {

          $html .= '<div>';
          $html .= esc_html__('No files found.', 'shared-files');
          $html .= '</div>';

        }


        $html .= '</div></div>';

        wp_reset_postdata();

        return $html;

      }
    }

  }

  public static function shared_files_title_filter__premium_only( $where, $wp_query ){

    global $wpdb;
    $s = get_option('shared_files_settings');

    if ( $search_term = $wp_query->get( 'search_title' ) ) {

      if ( isset( $s['exact_search_whole_words_only'] ) ) {

        $where .= ' AND CONCAT(\' \', ' . $wpdb->posts . '.post_title, \' \')' .
                  ' LIKE \'% ' . esc_sql( like_escape( $search_term ) ) . ' %\'';

      } else {

        $where .= ' AND ' . $wpdb->posts . '.post_title LIKE \'%' . esc_sql( like_escape( $search_term ) ) . '%\'';

      }

    }

    return $where;

  }

}

