<?php

class ShortcodeSharedFilesFavorites {

  /**
   * Search view embeddable via shortcode.
   *
   * @since    1.0.0
   */
  public static function shared_files_favorites($atts = [], $content = null, $tag = '') {

    if (SharedFilesHelpers::isPremium() == 0) {
      $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
      return $html;
    }

    $html = '';

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        if ( is_user_logged_in() && !isset( $s['activate_favorite_files_for_logged_in'] ) ) {
          return '';
        }

        if ( !is_user_logged_in() && !isset( $s['activate_favorite_files_for_non_logged_in'] ) ) {
          return '';
        }

        $layout = SharedFilesHelpers::getLayout($s, $atts);
        $type = 'basic';

        $meta_query = [];
        $embed_id = isset($atts['embed_id']) ? sanitize_title($atts['embed_id']) : 'default';

        $current_favorites = '';
        $current_favorites_arr = [];

        if (is_user_logged_in()) {

          $user_id = intval( get_current_user_id() );

          $current_favorites = sanitize_text_field( get_user_meta( $user_id, 'shared_files_favorite_files', true ) );
          $current_favorites_arr = explode( ',', $current_favorites );

        } elseif ( isset( $_COOKIE['shared_files_favorite_files'] ) ) {

          $current_favorites = sanitize_text_field( $_COOKIE['shared_files_favorite_files'] );
          $current_favorites_arr = explode( ',', $current_favorites );

        }

//          var_dump( $current_favorites_arr );

        if (sizeof($current_favorites_arr) == 1 && ( $current_favorites_arr[0] == '0' || $current_favorites_arr[0] == '1' || $current_favorites_arr[0] == '' ) ) {
          $current_favorites_arr = [];
        }

        if (sizeof($current_favorites_arr) > 0) {

          $wp_query = new WP_Query(array(
            'post_type'       => 'shared_file',
            'post_status'     => 'publish',

            'posts_per_page'  => -1,

            'post__in'        => $current_favorites_arr,

            'orderby'         => SharedFilesHelpers::getOrderBy($atts),
            'order'           => SharedFilesHelpers::getOrder($atts),
            'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

            'meta_query'      => $meta_query,
          ));

          $container_embed_id = '';

          if ($embed_id == 'default') {

            $container_embed_id = 'id="' . esc_attr( 'shared-files-default' ) . '"';

          } elseif ($embed_id) {

            $container_embed_id = 'id="' . esc_attr( $embed_id ) . '"';

          }

          $html .= '<div ' . $container_embed_id . ' class="shared-files-container shared-files-type-' . $type . ' ' . ($layout ? 'shared-files-' . esc_attr($layout) : '') . '">';
          $html .= '<div class="shared-files-search">';

          if ( isset( $s['show_title_above_favorite_files'] ) ) {
            $html .= '<h3>' . SharedFilesHelpers::getText( 'favorite_files_title_text', __('Favorite files', 'shared-files') ) . '</h3>';
          }

          if ($wp_query->have_posts()) {

            $html .= '<ul class="shared-files-main-file-list shared-files-ajax-list">';

            while ($wp_query->have_posts()) {

              $wp_query->the_post();

              $id = intval( get_the_id() );
              $c = get_post_custom($id);

              $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
              $filetype = '';
              $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, 0, 1, $atts, 1);

            }

            $html .= '</ul>';

          }

          $html .= '</div>';
          $html .= '</div>';

          $html .= '<hr class="clear" />';

          wp_reset_postdata();

        } else {

          if ( isset( $s['show_title_above_favorite_files'] ) ) {
            $html .= '<h3>' . SharedFilesHelpers::getText( 'favorite_files_title_text', __('Favorite files', 'shared-files') ) . '</h3>';
          }

          $html .= sanitize_text_field( __('You haven\'t yet selected favorite files.', 'shared-files') );

        }

      }
    }

    return $html;

  }

}
