<?php

class ShortcodeSharedFilesRestricted {

  private static $custom_fields_active = 0;
  private static $meta_query = [];
  private static $meta_query_file_permissions = [];
  private static $meta_query_final = [];

  private static function setFinalMetaQuery() {
    self::$meta_query_final = array('relation' => 'AND');
    self::$meta_query_final []= self::$meta_query_file_permissions;
    self::$meta_query_final []= self::$meta_query;
  }

  public static function setMetaQuery( $value ) {
    self::$meta_query = $value;
  }

  public static function addToMetaQuery( $value ) {
    self::$meta_query []= $value;
  }

  public static function setFilePermissions( $value ) {
    self::$meta_query_file_permissions = $value;
  }

  public static function shared_files_restricted($atts = [], $content = null, $tag = '') {

    $className = get_called_class();

    if (SharedFilesHelpers::isPremium() == 0) {
      $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
      return $html;
    } elseif (!is_user_logged_in()) {
      $html = '<div style="background: #fff; border: 1px solid #bbb; color: #000; padding: 10px 20px; border-radius: 5px;">' . esc_html__('Only logged in users can list these files.', 'shared-files') . '</div>';
      return $html;

    } elseif ( !SharedFilesHelpers::isMin2Pr() ) {

      $html = '';
      return $html;

    }

    if (shared_files_fs()->is__premium_only()) {
      if (shared_files_fs()->can_use_premium_code()) {

        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        $current_url = esc_url_raw( get_permalink() );

        $html = '';

        $term_slug = '';

        $include_children = 0;

        if ( isset( $s['and_or_include_children'] ) ) {
          $include_children = 1;
        }

        if (isset($atts['category']) && $atts['category']) {

          $cat = get_term_by('slug', sanitize_title( $atts['category'] ), 'shared-file-category');

          if ($cat) {
            $term_slug = $cat->slug;
          } else {
            $html = '<div class="sf_error">' . esc_html__('Category not found:', 'shared-files') . ' ' . esc_html( $atts['category'] ) . '</div>';
            return $html;
          }

        } else if (isset($_GET['sf_category']) && $_GET['sf_category'] != '0') {

          $term_slug = sanitize_title( $_GET['sf_category'] );

        }


        /* CATEGORY PASSWORD START */
        if ($term_slug) {

          $password_check_markup = SharedFilesPublicHelpers::checkCatPassword__premium_only($term_slug, 1);

          if ($password_check_markup) {
            $html .= $password_check_markup;
            return $html;
          }

        }
        /* CATEGORY PASSWORD END */

        $elem_class = SharedFilesHelpers::createElemClass();

        $embed_id = isset($atts['embed_id']) ? sanitize_title($atts['embed_id']) : 'default';
        $pagination_active = 0;

        if (isset($_GET['_paged']) && $_GET['_paged'] == $embed_id) {
          $pagination_active = 1;
        }

        $tag_slug = '';

        if (isset($_GET['sf_tag']) && $_GET['sf_tag'] != '0') {
          $tag_slug = sanitize_title( $_GET['sf_tag'] );
        }

        $html .= '<div class="' . $elem_class . ' shared-files-main-container" data-elem-class="' . $elem_class . '">';

        if (isset($_GET) && isset($_GET['shared-files-update'])) {
          $html .= '<div class="shared-files-upload-complete">' . sanitize_text_field( __('File successfully updated.', 'shared-files') ) . '</div>';
        } elseif (isset($_GET) && isset($_GET['_sf_delete_editable_file']) && isset($_GET['sc'])) {
          $html .= '<div class="shared-files-file-deleted">' . sanitize_text_field( __('File successfully deleted.', 'shared-files') ) . '</div>';
        }

        if (isset($atts['file_upload']) && (is_user_logged_in() || !isset($s['only_logged_in_users_can_add_files']))) {
          $html .= SharedFilesFileUpload::fileUploadMarkup($atts, 1);
        }

        if (isset($atts['hide_file_list'])) {

          // .shared-files-main-container
          $html .= '</div>';

          return $html;

        } else {

          $layout = SharedFilesHelpers::getLayout($s, $atts);

          $type = 'basic';

          $container_embed_id = '';

          if ($embed_id == 'default') {

            $container_embed_id = 'id="' . esc_attr( 'shared-files-default' ) . '"';

          } elseif ($embed_id) {

            $container_embed_id = 'id="' . esc_attr( $embed_id ) . '"';

          }

          $html .= '<div ' . $container_embed_id . ' class="shared-files-container shared-files-type-' . $type . ' ' . ($layout ? 'shared-files-' . esc_attr($layout) : '') . '">';
          $html .= '<div class="shared-files-search">';

          if (!isset($s['hide_search_form']) && !isset($atts['hide_search'])) {

            $html .= '<div class="shared-files-search-form-container">';
            $html .= '<form class="shared-files-ajax-form" onsubmit="return false;" data-elem-class="' . $elem_class . '" data-restricted="1">';

            if (!isset($atts['hide_search_for_all_files'])) {
              $html .= '<div class="shared-files-search-input-container"><input type="text" class="shared-files-search-files-input shared-files-search-files" placeholder="' . esc_attr__('Search files...', 'shared-files') . '" value="" data-elem-class="' . $elem_class . '" /></div>';
            }

            $html .= '<input type="hidden" name="atts" value=\'' . json_encode($atts) . '\' />';

            if ( isset( $atts['show_filters'] ) ) {
              $html .= SharedFilesShortcodeFilters::getFilters( $className, $atts );
            }

            $html .= '<hr class="clear" />';

            // .shared-files-search-form-container
            $html .= '</form>';

            // .shared-files-ajax-form
            $html .= '</div>';

          }


          SharedFilesShortcodePermissions::setPermissions( $className );


          $paged = 1;

          if ($pagination_active) {

            if (isset($_GET['_page']) && $_GET['_page']) {
              $paged = (int) $_GET['_page'];
            } elseif (get_query_var('paged')) {
              $paged = absint( get_query_var('paged') );
            }

          }

          $posts_per_page = isset($s['pagination']) && $s['pagination'] ? (int) $s['pagination'] : 20;

          $tax_query = ['relation' => 'AND'];

          if ( $term_slug ) {

            $tax_query []= [
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $term_slug,
              'include_children'  => true
            ];

          }

          if (isset($atts['exclude_cat'])) {

            $terms = explode(',', $atts['exclude_cat']);

            $tax_query []= [
              'taxonomy'  => 'shared-file-category',
              'terms'     => $terms,
              'field'     => 'slug',
              'operator'  => 'NOT IN'
            ];

          }

          if (isset($atts['categories__or']) && $atts['categories__or']) {

            $cat_slugs_or = explode(',', $atts['categories__or']);

            $tax_query []= array(
              'taxonomy'          => 'shared-file-category',
              'field'             => 'slug',
              'terms'             => $cat_slugs_or,
              'operator'          => 'IN',
              'include_children'  => $include_children
            );

          }

          if ($tag_slug) {

            $tax_query []= array(
              'taxonomy'          => SHARED_FILES_TAG_SLUG,
              'field'             => 'slug',
              'terms'             => $tag_slug,
            );

          }

          self::setFinalMetaQuery();

          $wp_query = new WP_Query(array(
            'post_type'       => 'shared_file',
            'post_status'     => 'publish',

            'paged'           => $paged,
            'posts_per_page'  => $posts_per_page,

            'tax_query'       => $tax_query,

            'orderby'         => SharedFilesHelpers::getOrderBy($atts),
            'order'           => SharedFilesHelpers::getOrder($atts),
            'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

            'meta_query'      => self::$meta_query_final,

          ));

          $wp_query_all_files = new WP_Query(array(
            'post_type'       => 'shared_file',
            'post_status'     => 'publish',

            'posts_per_page'  => -1,

            'tax_query'       => $tax_query,

            'orderby'         => SharedFilesHelpers::getOrderBy($atts),
            'order'           => SharedFilesHelpers::getOrder($atts),
            'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

            'meta_query'      => self::$meta_query_final,

          ));

          $filetypes = SharedFilesHelpers::getFiletypes();
          $external_filetypes = SharedFilesHelpers::getExternalFiletypes();

          $html .= '<div class="shared-files-files-found"></div>';
          $html .= '<span class="shared-files-one-file-found">' . sanitize_text_field( __('file found.', 'shared-files') ) . '</span><span class="shared-files-more-than-one-file-found">' . sanitize_text_field( __('files found.', 'shared-files') ) . '</span>';

          $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

          if ($wp_query->have_posts()):

            if (is_user_logged_in() && isset($atts['edit'])) {

              while ($wp_query->have_posts()): $wp_query->the_post();

                $file_id = intval( get_the_id() );
                $html .= SharedFilesPublicHelpers::editFileModal__premium_only($file_id, $current_url);

              endwhile;

            }

            $html .= '<ul class="shared-files-main-file-list shared-files-ajax-list">';

            if ( isset($atts['hide_files_first']) ):

              // ...

            else:

              while ($wp_query->have_posts()): $wp_query->the_post();

                $id = intval( get_the_id() );
                $c = get_post_custom($id);

                $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                $filetype = '';

                $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

                if (isset($atts['file_upload'])) {
                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 1, $atts);
                } elseif (isset($atts['category'])) {
                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);
                } else {
                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 1, $atts);
                }

              endwhile;

            endif;

            $html .= '</ul>';

          elseif (!isset($atts['file_upload'])):

            $html .= '<ul class="shared-files-main-file-list shared-files-ajax-list"><li>';
            $html .= '<div class="shared-files-files-not-found">' . sanitize_text_field( __('No files found.', 'shared-files') ) . '</div>';
            $html .= '</li></ul>';

          endif;

          if (!isset($s['hide_search_form']) && !isset($atts['hide_search_for_all_files'])) {

            $show_tags = 0;

            if (isset($s['show_tags_on_search_results'])) {
              $show_tags = 1;
            }

            $html .= '<ul class="shared-files-all-files shared-files-main-file-list">';

            if (isset($wp_query_all_files) && $wp_query_all_files->have_posts()):
              while ($wp_query_all_files->have_posts()): $wp_query_all_files->the_post();

                $id = intval( get_the_id() );
                $c = get_post_custom($id);

                $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                $filetype = '';
                $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';

                $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);

                $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, $show_tags, $atts);

              endwhile;
            endif;

            $html .= '</ul>';

          }

          $html .= SharedFilesPublicPagination::getPagination($pagination_active, $wp_query, $embed_id);

          $html .= '<div class="shared-files-nothing-found">';
          $html .= sanitize_text_field( __('No files found.', 'shared-files') );
          $html .= '</div>';

          // .shared-files-search
          $html .= '</div>';

          // .shared-files-container
          $html .= '</div>';

          // .shared-files-main-container
          $html .= '</div>';

          $html .= '<hr class="clear" />';

          wp_reset_postdata();

          return $html;

        }

      }

    }

  }
}
