<?php
  
class ShortcodeSharedFilesSearch {

  public static function shared_files_search($atts = [], $content = null, $tag = '') {

    if (SharedFilesHelpers::isPremium() == 0) {  
      $html = SharedFilesPublicHelpers::proFeaturePublicMarkup();
      return $html;          
    }

    if (shared_files_fs()->is__premium_only()) {  
      if (shared_files_fs()->can_use_premium_code()) {

        // normalize attribute keys, lowercase
        $atts = array_change_key_case( (array) $atts, CASE_LOWER);
        $s = get_option('shared_files_settings');

        $elem_class = SharedFilesHelpers::createElemClass();

        $layout = '';
        
        if (isset($atts['layout'])) {
          $layout = sanitize_text_field( $atts['layout'] );
        } elseif (isset($s['layout']) && $s['layout']) {
          $layout = sanitize_text_field( $s['layout'] );
        }
      
        $html = '';
  
        if (isset($atts['not_sorted_by_categories'])) {

          $html .= '<div class="' . $elem_class . ' shared-files-container ' . ($layout ? 'shared-files-' . $layout : '') . '">';  
          $html .= '<div class="shared-files-search">';
    
          $html .= '<div class="shared-files-search-form-container shared-files-search-form-container-all-files"><div class="shared-files-search-input-container"><input type="text" class="shared-files-search-files-input shared-files-search-files-v2" placeholder="' . esc_html__('Search files...', 'shared-files') . '" data-elem-class="' . $elem_class . '"></div>';
          
          $html .= '<hr class="clear" /></div>';
    
          $filetypes = SharedFilesHelpers::getFiletypes();
          $external_filetypes = SharedFilesHelpers::getExternalFiletypes();
      
          $html .= '<div class="shared-files-files-found"></div>';
          $html .= '<span class="shared-files-one-file-found">' . esc_html__('file found.', 'shared-files') . '</span><span class="shared-files-more-than-one-file-found">' . esc_html__('files found.', 'shared-files') . '</span>';
    
          $html .= '<div class="shared-files-nothing-found">';
          $html .= esc_html__('No files found.', 'shared-files');
          $html .= '</div>';

          $meta_query_hide_not_public = array('relation' => 'OR');
      
          $meta_query_hide_not_public[] = array(
      			'key'		  => '_sf_not_public',
      			'compare'	=> '=',
      			'value'   => ''
      		);
      
          $meta_query_hide_not_public[] = array(
      			'key'		  => '_sf_not_public',
      			'compare'	=> 'NOT EXISTS',
      		);

          $wpb_all_query_all_files = new WP_Query(array(
            'post_type'       => 'shared_file',
            'post_status'     => 'publish',
            'posts_per_page'  => -1,

            'orderby'         => SharedFilesHelpers::getOrderBy($atts),
            'order'           => SharedFilesHelpers::getOrder($atts),
            'meta_key'        => SharedFilesHelpers::getMetaKey($atts),

            'meta_query'      => $meta_query_hide_not_public,
          ));
  
          $html .= '<ul class="shared-files-all-files shared-files-main-file-list">';
      
          if (isset($wpb_all_query_all_files) && $wpb_all_query_all_files->have_posts()):
            while ($wpb_all_query_all_files->have_posts()): $wpb_all_query_all_files->the_post();
      
              $id = get_the_id();
              $c = get_post_custom($id);
      
              $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
              $filetype = '';
              $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';
      
              $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);
  
              $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description, 0, $atts);
      
            endwhile;
          endif;
      
          $html .= '</ul>';

        } else {

          // Sorted by category

          $html .= '<div class="' . $elem_class . ' shared-files-container ' . ($layout ? 'shared-files-' . $layout : '') . '">';  
          $html .= '<div class="shared-files-search">';
    
          $html .= '<div class="shared-files-search-form-container shared-files-search-form-container-all-files"><div class="shared-files-search-input-container"><input type="text" class="shared-files-search-files-input shared-files-search-all-files" placeholder="' . esc_html__('Search files...', 'shared-files') . '" data-elem-class="' . $elem_class . '"></div>';
          
          $html .= '<hr class="clear" /></div>';
    
          $filetypes = SharedFilesHelpers::getFiletypes();
          $external_filetypes = SharedFilesHelpers::getExternalFiletypes();
      
          $html .= '<div class="shared-files-files-found"></div>';
          $html .= '<span class="shared-files-one-file-found">' . esc_html__('file found.', 'shared-files') . '</span><span class="shared-files-more-than-one-file-found">' . esc_html__('files found.', 'shared-files') . '</span>';
    
          $html .= '<div class="shared-files-nothing-found">';
          $html .= esc_html__('No files found.', 'shared-files');
          $html .= '</div>';
          
          $html .= '<ul class="shared-files-all-files-and-categories">';
    
          if (wp_count_terms('shared-file-category') > 1) {
    
            $terms = get_terms(array(
              'taxonomy'   => 'shared-file-category',
              'hide_empty' => true,
            ));
      
            foreach ($terms as $term) {
              $html .= '<li>';
              $html .= '<h4>' . sanitize_text_field( $term->name ) . '</h4>';
    
              $term_slug = sanitize_title( $term->slug );
        
              $wpb_all_query = new WP_Query(array(
                'post_type'       => 'shared_file',
                'post_status'     => 'publish',
                'posts_per_page'  => -1,
                'tax_query' => array(
                  array (
                    'taxonomy'          => 'shared-file-category',
                    'field'             => 'slug',
                    'terms'             => $term_slug,
                    'include_children'  => true
                  )
                ),

                'orderby'   => SharedFilesHelpers::getOrderBy($atts),
                'order'     => SharedFilesHelpers::getOrder($atts),
                'meta_key'  => SharedFilesHelpers::getMetaKey($atts),
                
              ));
    
              if (isset($wpb_all_query) && $wpb_all_query->have_posts()):
    
                $html .= '<ul class="shared-files-in-category shared-files-main-file-list">';
    
                while ($wpb_all_query->have_posts()): $wpb_all_query->the_post();
          
                  $id = intval( get_the_id() );
                  $c = get_post_custom($id);
          
                  $external_url = isset($c['_sf_external_url']) ? esc_url_raw( $c['_sf_external_url'][0] ) : '';
                  $filetype = '';
          
                  $imagefile = SharedFilesHelpers::getImageFile($id, $external_url);
                  $hide_description = isset($atts['hide_description']) ? sanitize_text_field( $atts['hide_description'] ) : '';
          
                  $html .= SharedFilesPublicFileCardDefault::fileListItem($c, $imagefile, $hide_description);
          
                endwhile;
    
                $html .= '</ul>';
    
              endif;
    
              $html .= '</li>';
    
            }
    
          }
    
          $html .= '</ul>';
          
        }
      
        $html .= '</div></div>';
  
        wp_reset_postdata();
    
        return $html;
        
      }
    }

  }

}
